########################################################
########################################################
#
# Validation #:           VALIDATION #14                                        
#                                                      
# Title:                  Simulated Bald Eagle Demography 
#                         in the NE, USA 1990-2018       
#                                                       
# Description:            This code tests whether demographic 
#                         parameters of Bald Eagles are recovered 
#                         by the combinatorial optimization 
#                         algorithm using a simulated time series 
#                         of the reproductive stage.  
#
# The Simulated Data:     A randomly generated set of
#                         parameter values as determined 
#                         by a random number generator. This
#                         set of parameter values is used 
#                         to simulated the time series data.
#
# Matrix Structure:       Complex
#
# Age At First Breeding:  Four
#
# Biological Assumptions: Constraint on Fledgling Survival
#                         Constraint on Fertility
#                         Constraint on Reaching Breeding Age
#                         Constraint on Life Expectancy
#                         Constraint on Initial Conditions
#                                                      
# Author:                 Brenda Hanley                                
# Date:                   October 2019                                 
# License:                MIT                                         
#                                                       
########################################################
########################################################

# CREATE A MOCK TIMESERIES FROM RANDOMLY GENERATED PARAMETER VALUES

set.seed(36)	# See "Starting seed" code

# Initial conditions
	A0=floor(runif(1,1,20))	# RANDOMLY SELECTED Number of SIII 
	S0=floor(runif(1,1,50))	# RANDOMLY SELECTED Number of SII
# Migration parameters
	AL.exact=runif(1,0,1) 		# RANDOMLY SELECTED Proportion of eagles that migrate out of the NE each year
	SL.exact=runif(1,0,1) 		# RANDOMLY SELECTED Proportion of non-breeding eagles that migrate out of the NE each year
	AA.exact=runif(1,0,1) 		# RANDOMLY SELECTED Proportion of eagles that migrate into the NE each year
	SA.exact=runif(1,0,1) 		# RANDOMLY SELECTED Proportion of non-breeding eagles that migrate into the NE each year 
# Dispersal parameters
	alpha1=runif(1,0,1) 		# RANDOMLY SELECTED Proportion of non-breeding eagles that disperse out of the NE each year 
	beta=runif(1,0,.2) 		# RANDOMLY SELECTED Proportion of breeding eagles that disperse out of the NE each year 
	alpha.star=runif(1,0,1) 	# RANDOMLY SELECTED Proportion of non-breeding eagles that disperse into the NE each year 
	beta.star=runif(1,0,.2) 	# RANDOMLY SELECTED Proportion of breeding eagles that disperse into the NE each year 
# Matrix parameters in the breeding period
   # |0   0   a13|
   # |0   a22 a23|
   # |0   a32 a33|
	a13=runif(1,.5,1.5)	# RANDOMLY SELECTED 
	a22=runif(1,.7,.75)	# RANDOMLY SELECTED 
	deathB2=runif(1,0,1-a22)	
	a32=1-a22-deathB2		# a32 is constrained by selection of a22
	a33=runif(1,.90,.99)	# RANDOMLY SELECTED 
	deathB3=runif(1,0,1-a33)
	a23=1-a33-deathB3		# a23 is constrained by selection of a33
# Matrix parameters in the non-breeding period in the NE
   # |0 0 0|
   # |a b c|
   # |0 d e|
	a=runif(1,.7,.75)		# RANDOMLY SELECTED 
	b=runif(1,.7,.75)		# RANDOMLY SELECTED 
	deathN2=runif(1,0,1-b)	
	d=1-b-deathN2		# d is constrained by selection of b
	e=runif(1,.90,.99)		# RANDOMLY SELECTED 
	deathN3=runif(1,0,1-e)	
	c=1-e-deathN3		# c is constrained by selection of e		
# Matrix parameters in the non-breeding period outside the NE
   # |0  0  0 |
   # |A  B  C |
   # |0  D  F |
	A=runif(1,.7,.75)		# RANDOMLY SELECTED 
	B=runif(1,.7,.75)		# RANDOMLY SELECTED 
	deathN2e=runif(1,0,1-B)	
	D=1-B-deathN2e		# D is constrained by selection of B
	F=runif(1,.90,.99)		# RANDOMLY SELECTED 
	deathN3e=runif(1,0,1-F)	
	C=1-F-deathN3e		# C is constrained by selection of F	
# GENERATE THE MOCK TIMESERIES FROM THESE PARAMETERS
	Nz=matrix(0,3,29+1)				
	NzH=matrix(0,3,29)
	NzHR=matrix(0,3,29)
	NzRDec=matrix(0,3,29)
	Nz[,1]=rbind(0,S0,A0)
	for (i in 1:29){							
	# ITERATE BIRDS THROUGH THE BREEDING PERIOD
		L=matrix(c(0,0,a13,0,a22,a23,0,a32,a33),3,3,byrow=TRUE)
		NzH[,i]=L%*%Nz[,i]					
	# PREPARE THE NUMBER OF RESIDENT DEPARTURES PER TIME STEP
		NAL=AL.exact*NzH[3,i]		
		NSL=SL.exact*NzH[2,i]		
	# REMOVE THE BIRDS THAT LEAVE
		NzHR[1,i]=NzH[1,i]
		NzHR[2,i]=NzH[2,i]-NSL					
		NzHR[3,i]=NzH[3,i]-NAL					
	# RUN YEAR-ROUND BIRDS THROUGH NON-BREEDING MATRIX IN SYSTEM A
		LNB=matrix(c(0,0,0,a,b,c,0,d,e),3,3,byrow=TRUE)
		NzRDec[,i]=LNB%*%NzHR[,i]
	# PREPARE THE NUMBER OF INCOMING MIGRANTS PER TIME STEP
		NAA=AA.exact*Nz[3,i]	# Number of incoming migrant adults
		NSA=SA.exact*Nz[2,i]	# Number of incoming migrant subadults
	# RUN INCOMING MIGRANTS THROUGH NON-BREEDING MATRIX IN SYSTEM A
		Migrants=matrix(c(0,NSA,NAA),3,1,byrow=FALSE)
		Migrantsurvivors=LNB%*%Migrants
	# RUN SYSTEM B BIRDS THROUGH THEIR NON-BREEDING MATRIX
		LNBE=matrix(c(0,0,0,A,B,C,0,D,F),3,3,byrow=TRUE)
		Elsewhere=matrix(c(0,NSL,NAL),3,1,byrow=FALSE)
		Elsewheresurvivors=LNBE%*%Elsewhere
	# PREPARE PURGE OF SURVIVORS
		NAP=beta*Elsewheresurvivors[3,1]		
		NSP=alpha1*Elsewheresurvivors[2,1]	
	# PREPARE ABSORPTION OF SURVIVORS
		NAAb=beta.star*Migrantsurvivors[3,1]		
		NSAb=alpha.star*Migrantsurvivors[2,1]	
	# RESIDENTS + RETURNING RESIDENTS - PURGE + ABSORB
		Nz[2,i+1]=NzRDec[2,i]+Elsewheresurvivors[2,1]-NSP+NSAb		
		Nz[3,i+1]=NzRDec[3,i]+Elsewheresurvivors[3,1]-NAP+NAAb	
	if (Nz[3,i+1]<0){Nz[3,i+1]=0}
	if (Nz[2,i+1]<0){Nz[2,i+1]=0}
	} # END LOOP TO GENERATE 29-STEP TIME SERIES FOR Z VECTOR
TIMESERIES=floor(Nz[3,1:29])

ADULTS_JUNE.EXACT=floor(NzH[3,1:29])
SUBADULTS_JAN.EXACT=floor(Nz[2,1:29])
SUBADULTS_JUNE.EXACT=floor(NzH[2,1:29])
JUVENILES_JUNE.EXACT=floor(NzH[1,1:29])

#####################################################
#####################################################
# ENSURE THAT THE MOCK TIME SERIES IS PLAUSIBLE FOR EAGLES
    Surv.EXACT2b=(4*a22)/3		# Trans Prob = 1/4
    Surv.EXACT1nb=a			# Trans Prob = 1
    Surv.EXACT2nb=(4*b)/3		# Trans Prob = 1/4
    Surv.EXACT1nbe=A			# Trans Prob = 1
    Surv.EXACT2nbe=(4*B)/3		# Trans Prob = 1/4
    Surv.EXACT2b=(4*a22)/3

    x3=1+(1/8)*(Surv.EXACT2b)-(1/2)*sqrt((16*Surv.EXACT2b+Surv.EXACT2b^2)/16)
    Surv.EXACT3b=a33/(1-x3)		# Trans Prob = x3

    xx3=1+(1/8)*(Surv.EXACT2nb)-(1/2)*sqrt((16*Surv.EXACT2nb+Surv.EXACT2nb^2)/16)
    Surv.EXACT3nb=e/(1-xx3)		# Trans Prob = xx3

    xxx3=1+(1/8)*(Surv.EXACT2nbe)-(1/2)*sqrt((16*Surv.EXACT2nbe+Surv.EXACT2nbe^2)/16)
    Surv.EXACT3nbe=F/(1-xxx3)	# Trans Prob = xxx3

if (Surv.EXACT3b>=1){Surv.EXACT3b=.999}
if (Surv.EXACT3nb>=1){Surv.EXACT3nb=.999}
if (Surv.EXACT3nbe>=1){Surv.EXACT3nbe=.999}

  Surv.EXACT1NB=Surv.EXACT1nb
  Surv.EXACT1NBE=Surv.EXACT1nbe
  Surv.EXACT2B=Surv.EXACT2b
  Surv.EXACT2NB=Surv.EXACT2nb
  Surv.EXACT2NBE=Surv.EXACT2nbe
  Surv.EXACT3B=Surv.EXACT3b
  Surv.EXACT3NB=Surv.EXACT3nb
  Surv.EXACT3NBE=Surv.EXACT3nbe
  
  #################################
  #################################
    P.EXACT1=
      (Surv.EXACT1NB+Surv.EXACT1NBE)/(2^1)
  
  #################################
  #################################
  
    P.EXACT2=
      # LIVE TO END OF YEAR 2
      (
        Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE+
          
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE
      )/(2^2)

  #################################
  #################################

    P.EXACT3=
      # LIVE TO END OF YEAR 3
      (
        Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE+
          
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT4=
      # LIVE TO END OF YEAR 4
      (
        Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE+
          
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NB*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE+
          Surv.EXACT1NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE*Surv.EXACT2B*Surv.EXACT2NBE
      )/(2^4)

  #################################
  #################################

    P.EXACT5=
      (
        # LIVE TO END OF YEAR 5 BUT SP.EXACTEND 5TH YEAR IN STAGE II
        P.EXACT4*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT4*Surv.EXACT2B*Surv.EXACT2NBE+
          
          # LIVE TO END OF YEAR 5 BUT SP.EXACTEND 5TH YEAR IN STAGE III
          P.EXACT4*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT4*Surv.EXACT3B*Surv.EXACT3NBE+
          
          #LIVE TO END OF YEAR 5 BUT SP.EXACTEND 1/2 5TH YEAR IN STAGE II AND 1/2 IN STAGE III
          P.EXACT4*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT4*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT4*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT4*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################
  
    P.EXACT6=
      (
        # LIVE TO END OF YEAR 6 BUT SP.EXACTEND 5TH YEAR IN STAGE II
        P.EXACT5*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT5*Surv.EXACT2B*Surv.EXACT2NBE+
          
          # LIVE TO END OF YEAR 6 BUT SP.EXACTEND 5TH YEAR IN STAGE III
          P.EXACT5*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT5*Surv.EXACT3B*Surv.EXACT3NBE+
          
          #LIVE TO END OF YEAR 6 BUT SP.EXACTEND 1/2 5TH YEAR IN STAGE II AND 1/2 IN STAGE III
          P.EXACT5*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT5*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT5*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT5*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT7=
      (
        P.EXACT6*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT6*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT6*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT6*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT6*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT6*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT6*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT6*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT8=
      (
        P.EXACT7*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT7*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT7*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT7*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT7*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT7*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT7*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT7*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT9=
      (
        P.EXACT8*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT8*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT8*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT8*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT8*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT8*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT8*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT8*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT10=
      (
        P.EXACT9*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT9*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT9*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT9*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT9*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT9*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT9*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT9*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT11=
      (
        P.EXACT10*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT10*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT10*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT10*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT10*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT10*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT10*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT10*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT12=
      (
        P.EXACT11*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT11*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT11*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT11*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT11*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT11*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT11*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT11*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT13=
      (
        P.EXACT12*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT12*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT12*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT12*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT12*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT12*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT12*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT12*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT14=
      (
        P.EXACT13*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT13*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT13*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT13*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT13*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT13*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT13*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT13*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT15=
      (
        P.EXACT14*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT14*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT14*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT14*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT14*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT14*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT14*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT14*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT16=
      (
        P.EXACT15*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT15*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT15*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT15*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT15*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT15*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT15*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT15*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT17=
      (
        P.EXACT16*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT16*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT16*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT16*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT16*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT16*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT16*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT16*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT18=
      (
        P.EXACT17*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT17*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT17*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT17*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT17*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT17*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT17*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT17*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT19=
      (
        P.EXACT18*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT18*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT18*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT18*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT18*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT18*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT18*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT18*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT20=
      (
        P.EXACT19*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT19*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT19*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT19*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT19*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT19*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT19*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT19*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT21=
      (
        P.EXACT20*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT20*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT20*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT20*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT20*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT20*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT20*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT20*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT22=
      (
        P.EXACT21*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT21*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT21*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT21*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT21*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT21*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT21*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT21*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT23=
      (
        P.EXACT22*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT22*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT22*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT22*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT22*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT22*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT22*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT22*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT24=
      (
        P.EXACT23*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT23*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT23*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT23*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT23*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT23*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT23*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT23*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT25=
      (
        P.EXACT24*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT24*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT24*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT24*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT24*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT24*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT24*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT24*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT26=
      (
          P.EXACT25*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT25*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT25*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT25*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT25*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT25*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT25*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT25*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT27=
      (
        P.EXACT26*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT26*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT26*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT26*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT26*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT26*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT26*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT26*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT28=
      (
        P.EXACT27*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT27*Surv.EXACT2B*Surv.EXACT2NBE+
          
          P.EXACT27*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT27*Surv.EXACT3B*Surv.EXACT3NBE+
          
          P.EXACT27*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT27*Surv.EXACT3B*Surv.EXACT2NBE+
          
          P.EXACT27*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT27*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)

  #################################
  #################################

    P.EXACT29=
      (
          P.EXACT28*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT28*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT28*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT28*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT28*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT28*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT28*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT28*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  #################################
  #################################

    P.EXACT30=
      (
          P.EXACT29*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT29*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT29*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT29*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT29*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT29*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT29*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT29*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT31=
      (
          P.EXACT30*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT30*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT30*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT30*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT30*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT30*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT30*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT30*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT32=
      (
          P.EXACT31*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT31*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT31*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT31*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT31*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT31*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT31*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT31*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT33=
      (
          P.EXACT32*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT32*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT32*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT32*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT32*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT32*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT32*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT32*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT34=
      (
          P.EXACT33*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT33*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT33*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT33*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT33*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT33*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT33*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT33*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT35=
      (
          P.EXACT34*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT34*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT34*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT34*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT34*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT34*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT34*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT34*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT36=
      (
          P.EXACT35*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT35*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT35*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT35*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT35*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT35*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT35*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT35*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT37=
      (
          P.EXACT36*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT36*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT36*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT36*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT36*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT36*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT36*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT36*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT38=
      (
          P.EXACT37*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT37*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT37*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT37*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT37*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT37*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT37*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT37*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT39=
      (
          P.EXACT38*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT38*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT38*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT38*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT38*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT38*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT38*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT38*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT40=
      (
          P.EXACT39*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT39*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT39*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT39*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT39*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT39*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT39*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT39*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT41=
      (
          P.EXACT40*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT40*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT40*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT40*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT40*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT40*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT40*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT40*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT42=
      (
          P.EXACT41*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT41*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT41*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT41*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT41*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT41*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT41*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT41*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT43=
      (
          P.EXACT42*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT42*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT42*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT42*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT42*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT42*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT42*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT42*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
 
  #################################
  #################################

    P.EXACT44=
      (
          P.EXACT43*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT43*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT43*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT43*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT43*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT43*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT43*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT43*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT45=
      (
          P.EXACT44*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT44*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT44*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT44*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT44*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT44*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT44*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT44*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT46=
      (
          P.EXACT45*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT45*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT45*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT45*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT45*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT45*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT45*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT45*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT47=
      (
          P.EXACT46*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT46*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT46*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT46*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT46*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT46*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT46*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT46*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT48=
      (
          P.EXACT47*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT47*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT47*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT47*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT47*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT47*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT47*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT47*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT49=
      (
          P.EXACT48*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT48*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT48*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT48*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT48*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT48*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT48*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT48*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
  #################################
  #################################

    P.EXACT50=
      (
          P.EXACT49*Surv.EXACT2B*Surv.EXACT2NB+
          P.EXACT49*Surv.EXACT2B*Surv.EXACT2NBE+
          P.EXACT49*Surv.EXACT3B*Surv.EXACT3NB+
          P.EXACT49*Surv.EXACT3B*Surv.EXACT3NBE+
          P.EXACT49*Surv.EXACT3B*Surv.EXACT2NB+
          P.EXACT49*Surv.EXACT3B*Surv.EXACT2NBE+
          P.EXACT49*Surv.EXACT2B*Surv.EXACT3NB+
          P.EXACT49*Surv.EXACT2B*Surv.EXACT3NBE
      )/(2^3)
  
	TOTAL.EXACT=
	P.EXACT1+P.EXACT2+P.EXACT3+P.EXACT4+P.EXACT5+P.EXACT6+P.EXACT7+P.EXACT8+P.EXACT9+P.EXACT10+
	P.EXACT11+P.EXACT12+P.EXACT13+P.EXACT14+P.EXACT15+P.EXACT16+P.EXACT17+P.EXACT18+P.EXACT19+P.EXACT20+
	P.EXACT21+P.EXACT22+P.EXACT23+P.EXACT24+P.EXACT25+P.EXACT26+P.EXACT27+P.EXACT28+P.EXACT29+P.EXACT30+
	P.EXACT31+P.EXACT32+P.EXACT33+P.EXACT34+P.EXACT35+P.EXACT36+P.EXACT37+P.EXACT38+P.EXACT39+P.EXACT40+
	P.EXACT41+P.EXACT42+P.EXACT43+P.EXACT44+P.EXACT45+P.EXACT46+P.EXACT47+P.EXACT48+P.EXACT49+P.EXACT50

	E.EXACT=1*P.EXACT1/TOTAL.EXACT+2*P.EXACT2/TOTAL.EXACT+3*P.EXACT3/TOTAL.EXACT+4*P.EXACT4/TOTAL.EXACT+5*P.EXACT5/TOTAL.EXACT+
	6*P.EXACT6/TOTAL.EXACT+7*P.EXACT7/TOTAL.EXACT+8*P.EXACT8/TOTAL.EXACT+9*P.EXACT9/TOTAL.EXACT+10*P.EXACT10/TOTAL.EXACT+
	11*P.EXACT11/TOTAL.EXACT+12*P.EXACT12/TOTAL.EXACT+13*P.EXACT13/TOTAL.EXACT+14*P.EXACT14/TOTAL.EXACT+15*P.EXACT15/TOTAL.EXACT+
	16*P.EXACT16/TOTAL.EXACT+17*P.EXACT17/TOTAL.EXACT+18*P.EXACT18/TOTAL.EXACT+19*P.EXACT19/TOTAL.EXACT+20*P.EXACT20/TOTAL.EXACT+
	21*P.EXACT21/TOTAL.EXACT+22*P.EXACT22/TOTAL.EXACT+23*P.EXACT23/TOTAL.EXACT+24*P.EXACT24/TOTAL.EXACT+25*P.EXACT25/TOTAL.EXACT+
	26*P.EXACT26/TOTAL.EXACT+27*P.EXACT27/TOTAL.EXACT+28*P.EXACT28/TOTAL.EXACT+29*P.EXACT29/TOTAL.EXACT+30*P.EXACT30/TOTAL.EXACT+
	31*P.EXACT31/TOTAL.EXACT+32*P.EXACT32/TOTAL.EXACT+33*P.EXACT33/TOTAL.EXACT+34*P.EXACT34/TOTAL.EXACT+35*P.EXACT35/TOTAL.EXACT+
	36*P.EXACT36/TOTAL.EXACT+37*P.EXACT37/TOTAL.EXACT+38*P.EXACT38/TOTAL.EXACT+39*P.EXACT39/TOTAL.EXACT+40*P.EXACT40/TOTAL.EXACT+
	41*P.EXACT41/TOTAL.EXACT+42*P.EXACT42/TOTAL.EXACT+43*P.EXACT43/TOTAL.EXACT+44*P.EXACT44/TOTAL.EXACT+45*P.EXACT45/TOTAL.EXACT+
	46*P.EXACT46/TOTAL.EXACT+47*P.EXACT47/TOTAL.EXACT+48*P.EXACT48/TOTAL.EXACT+49*P.EXACT49/TOTAL.EXACT+50*P.EXACT50/TOTAL.EXACT
	

	Living.to.breeding.rrr.EXACT=(a)^2*((4*b)/3)^2
	Living.to.breeding.mmm.EXACT=(a)^2*((4*B)/3)^2
	Living.to.breeding.rrm.EXACT=(a)^2*((4*b)/3)*((4*B)/3)
	Living.to.breeding.rmm.EXACT=(a)^2*((4*b)/3)*((4*B)/3)

index=c()
# PARING DOWN MODELS FOR REASONABLE LIFE EXPECTANCY TO BREEDING AGE
  if (.35<=Living.to.breeding.rrr.EXACT & Living.to.breeding.rrr.EXACT<.65){
    if (.35<=Living.to.breeding.rrm.EXACT & Living.to.breeding.rrm.EXACT<.65){
      if (.35<=Living.to.breeding.rmm.EXACT & Living.to.breeding.rmm.EXACT<.65){
        if (.35<=Living.to.breeding.mmm.EXACT & Living.to.breeding.mmm.EXACT<.65){
            if (a>=.63){
              if (A>=.63){
                if (E.EXACT>10){
                  index=c(index,i)}}}}}}}
index

# YR RESIDENTS
    top11=c(0,0,a13)
    mid11=c(0,a22,a23)
    bot11=c(0,a32,a33)
    AB=rbind(top11,mid11,bot11)
    top1=c(0,0,0)
    mid1=c(a,b,c)
    bot1=c(0,d,e)
    ANB=rbind(top1,mid1,bot1)
	L=ANB%*%AB
	e.YR.exact=eigen(L)$values[1]
    e.vector.YR.exact=eigen(L)$vector[,1]
	e.vector.YR.exact1=e.vector.YR.exact[2]/sum(e.vector.YR.exact)
	e.vector.YR.exact2=e.vector.YR.exact[3]/sum(e.vector.YR.exact)

    e.vectorR.YR.exact=eigen(t(L))$vector[,1]
	e.vectorR.YR.exact1=e.vectorR.YR.exact[2]/sum(e.vectorR.YR.exact)
	e.vectorR.YR.exact2=e.vectorR.YR.exact[3]/sum(e.vectorR.YR.exact)

    Ww=numeric(3);Vv=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
        Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
    S.R.TWO.TWO.EXACT=Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
    S.R.TWO.THREE.EXACT=Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
    S.R.THREE.TWO.EXACT=Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
    S.R.THREE.THREE.EXACT=Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))

    E.R.TWO.TWO.EXACT=Re(L[2,2]/e.YR.exact)*Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
    E.R.TWO.THREE.EXACT=Re(L[2,3]/e.YR.exact)*Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
    E.R.THREE.TWO.EXACT=Re(L[3,2]/e.YR.exact)*Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
    E.R.THREE.THREE.EXACT=Re(L[3,3]/e.YR.exact)*Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))

	DAMP.R.EXACT=e.YR.exact/sqrt(Re(eigen(L)$values[2])^2+Im(eigen(L)$values[2])^2)

  library(popdemo)
  Initial=matrix(0,2,1)
    Initial[1,1]=SUBADULTS_JAN.EXACT[1]
    Initial[2,1]=TIMESERIES[1]
    Annual=L[2:3,2:3]
    InertiaR.EXACT=inertia(Annual,vector=Initial[,1])
    ReactR.EXACT=reac(Annual,vector=Initial[,1])
    MaxAmpR.EXACT=maxamp(Annual,vector=Initial[,1])
    MaxAttR.EXACT=maxatt(Annual,vector=Initial[,1])

# PY RESIDENTS
    top11=c(0,0,a13)
    mid11=c(0,a22,a23)
    bot11=c(0,a32,a33)
    ABb=rbind(top11,mid11,bot11)
    top1=c(0,0,0)
    mid1=c(A,B,C)
    bot1=c(0,D,F)
    ANBb=rbind(top1,mid1,bot1)
	Lb=ANBb%*%ABb
	e.PY.exact=eigen(Lb)$values[1]
    e.vector.PY.exact=eigen(Lb)$vector[,1]
	e.vector.PY.exact1=e.vector.PY.exact[2]/sum(e.vector.PY.exact)
	e.vector.PY.exact2=e.vector.PY.exact[3]/sum(e.vector.PY.exact)

    e.vectorR.PY.exact=eigen(t(Lb))$vector[,1]
	e.vectorR.PY.exact1=e.vectorR.PY.exact[2]/sum(e.vectorR.PY.exact)
	e.vectorR.PY.exact2=e.vectorR.PY.exact[3]/sum(e.vectorR.PY.exact)

    Ww=numeric(3);Vv=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        Vv[k]=eigen(t(Lb))$vector[k,1]/eigen(t(Lb))$vector[2,1]
        Ww[j]=eigen(Lb)$vector[j,1]/(eigen(Lb)$vector[2,1]+eigen(Lb)$vector[3,1])}}
    S.M.TWO.TWO.EXACT=Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
    S.M.TWO.THREE.EXACT=Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
    S.M.THREE.TWO.EXACT=Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
    S.M.THREE.THREE.EXACT=Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))

    E.M.TWO.TWO.EXACT=Re(Lb[2,2]/e.PY.exact)*Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
    E.M.TWO.THREE.EXACT=Re(Lb[2,3]/e.PY.exact)*Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
    E.M.THREE.TWO.EXACT=Re(Lb[3,2]/e.PY.exact)*Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
    E.M.THREE.THREE.EXACT=Re(Lb[3,3]/e.PY.exact)*Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))

	DAMP.M.EXACT=e.PY.exact/sqrt(Re(eigen(Lb)$values[2])^2+Im(eigen(Lb)$values[2])^2)

  library(popdemo)
  Initial=matrix(0,2,1)
    Initial[1,1]=SUBADULTS_JAN.EXACT[1]
    Initial[2,1]=TIMESERIES[1]
    Annual=Lb[2:3,2:3]
    InertiaM.EXACT=inertia(Annual,vector=Initial[,1])
    ReactM.EXACT=reac(Annual,vector=Initial[,1])
    MaxAmpM.EXACT=maxamp(Annual,vector=Initial[,1])
    MaxAttM.EXACT=maxatt(Annual,vector=Initial[,1])

# ENTIRE MATRIX

    Total=TIMESERIES+SUBADULTS_JAN.EXACT
    CUM.EXACT=Total/Total[1]

    Ne.EXACT=1/((1/29)*sum(1/TIMESERIES[1:29]))
    Nbar.EXACT=(1/29)*sum(TIMESERIES[1:29])

	SGR.EXACT=numeric(29)
	TPGR.EXACT=numeric(29)
	LGD.EXACT=numeric(29)
    	for (j in 1:29){
      SGR.EXACT[j]=exp((1/(j))*log(TIMESERIES[j]/TIMESERIES[1]))
      TPGR.EXACT[j]=log(TIMESERIES[j+1]/TIMESERIES[j])
      LGD.EXACT[j]=(1-(1/(2*Ne.EXACT)))^j}

#####################################################
#####################################################

# PREPARE THE ALGORITHM

# SPECIFY THE NUMBER OF ITERATIONS
	num.tests=1000000

 # PREPARE THE FIRST ALGORITHM
	set.seed(155)			# For reproducibility

  # INITIALIZE GLOBAL VARIABLES	
	THRESHOLD=300			# An initial distance threshold to find top distance
	num.tests=num.tests		# Initialize number of iterations
	constraint.time.series=TIMESERIES
	names=c("Nat","Nst",		# Initialize variables in optimization vector
	"Nat1","Nstl","AL","SL",
	"a13","a21","a22","a23",
	"a32","a33",
	"a","b","c","d","e",
	"A","B","C","D","E",
	"alpha","beta","alphastar",
	"betastar","SA","AA")	
	Candid=matrix(0,1,28)		# Initialize storage for best models
	Nzlowest=matrix(0,3,29+1)	# Initialize lowest time series
	zlowest=matrix(0,1,28)		# Initialize lowest vector
	Distlowest=999999			# Initialize lowest distance
	AdultPercentLowest=9999		# Initialize lowest adult resident migration
	SubadultPercentLowest=9999	# Initialize lowest subadult resident migration
	AdultMPercentLowest=9999	# Initialize lowest incoming adult migration
	SubadultMPercentLowest=9999	# Initialize lowest incoming subadult migration
	AlphaLowest=9999			# Initial lowest subadult purge
	BetaLowest=9999			# Initial lowest adult purge
	AlphaStarLowest=9999		# Initial lowest subadult absorption
	BetaStarLowest=9999		# Initial lowest adult absorption

	Dist1=9999				# Initialize distance measurement
	TRAJECTORY_ADULTS_JAN=matrix(0,1,29+1)	  # To gather adult trajectory in January 
	TRAJECTORY_SUBADULTS_JAN=matrix(0,1,29+1)   # To gather subadult trajectory in January
	TRAJECTORY_JUVENILES_JUNE=matrix(0,1,29)    # To gather juvenile trajectory in June
	TRAJECTORY_SUBADULTS_JUNE=matrix(0,1,29)    # To gather subadults trajectory in June
	TRAJECTORY_ADULTS_JUNE=matrix(0,1,29)   	  # To gather adults trajectory in June
	PA=1					# % of Adults that migrate
	PS=1					# % of Subadults that migrate
	alphaS=1				# % of Subadults that purge
	betaA=1				# % of Adults that purge
	alphastar=1				# % of Subadults to absorb
	betastar=1				# % of Adults to absorb
	SA=1					# # Subadults that arrive after the breeding season
	AA=1					# # Adults that arrive after the breeding season

  # INITIALIZE THE Z VECTOR TO BE OPTIMIZED
	z=numeric(length(names))	# Candidate vector 1
	znew=numeric(length(names))	# Candidate vector 2
	Nz=matrix(0,3,29+1)		# January time series vector 1

 # INITIALIZE VALUES IN THE Z VECTOR (WITH A "GOOD" FIRST GUESS)

   # INITIAL CONDITIONS (abundances for adults and subadults)
	z[1]=TIMESERIES[1]			#At (from known time series)
	z[2]=sample(1:(3*TIMESERIES[1]),1)	#St may be between 0 and 3At (unknown)

   # PLACEHOLDERS FOR ABUNDANCES IN NEXT STEP
	z[3]=0				#Placeholder for next time step
	z[4]=0				#Placeholder for next time step

   # PERFECT MIGRATION VARIABLES
	AdultsLeftPercentage=.2				#Resident exit starts at 20% of total adults
	SubadultsLeftPercentage=.2			#Resident exit starts at 20% of total subadults
	AdultsArrivePercentage=.2			#Migrants arrive starts at 20% of total adults
	SubadultsArrivePercentage=.2			#Migrants arrive starts at 20% of total animals
	SubadultsPurge=.2					#Purge starts at 20% of total migrant subadults
	AdultsPurge=.2					#Purge starts at 20% of total migrant adults
	SubadultsAbsorb=.2				#Absorption starts at 20% of total migrant subadults
	AdultsAbsorb=.2					#Absorption at 20% of total migrant adults
	z[5]=AdultsLeftPercentage*TIMESERIES[1]	#Resident adults that migrate away
	z[6]=SubadultsLeftPercentage*z[2]		#Resident subadults that migrate away
	z[27]=SubadultsArrivePercentage*z[2]	#Subadult migrants that arrive for non-breeding period
	z[28]=AdultsArrivePercentage*TIMESERIES[1]#Adult migrants that arrive for non-breeding period

   # IMPERFECT MIGRATION VARIABLES 
	z[23]=z[6]*SubadultsPurge		#Number of Subadults purged (limited by the number of migrants)
	z[24]=z[5]*AdultsPurge			#Number of Adults purged (limited by the number of migrants)
	z[25]=z[27]*SubadultsAbsorb		#Number of Subadults absorbed (limited by number of arrivals)
	z[26]=z[28]*AdultsAbsorb		#Number of Adults absorbed (limited by number of arrivals)

   # MODEL MATRIX FOR BREEDING PERIOD IN SYSTEM A:
   # |0   0   a13|
   # |a21 a22 a23|
   # |0   a32 a33|	
	z[7]=runif(1,.5,1.5)		#a13 is normal(1.5,.5) and free to vary
	z[8]=0				#a21 is always 0
	z[9]=.99				#a22 has an original guess, otherwise 
						# reverts to uninformative uniform and 
						# free to vary
	deathB2=runif(1,0,1-z[9])	#a32 is constrained by selection of a22	
	z[11]=1-z[9]-deathB2		#a32 is constrained by selection of a22
	z[12]=.99				#a33 has an original guess, otherwise 
						# reverts to uninformative uniform and 
						# free to vary
	deathB3=runif(1,0,1-z[12])	#a23 is constrained by selection of a33
	z[10]=1-z[12]-deathB3		#a23 is constrained by selection of a33

   # MODEL MATRIX FOR NON-BREEDING PERIOD IN SYSTEM A:
   # |0 0 0|
   # |a b c|
   # |0 d e|
	z[13]=rbeta(1,1,1)		#a is uninformative, free to vary
	z[14]=.99				#b has an original guess, otherwise 
						# reverts to uninformative uniform and 
						# free to vary
	deathN2=runif(1,0,1-z[14])	#d is constrained by selection of b
	z[16]=1-z[14]-deathN2		#d is constrained by selection of b
	z[17]=.99				#e has an original guess, otherwise 
						# reverts to uninformative uniform and 
						# free to vary
	deathN3=runif(1,0,1-z[17])	#c is constrained by selection of e
	z[15]=1-z[17]-deathN3		#c is constrained by selection of e		

   # MODEL MATRIX FOR NON-BREEDING PERIOD IN SYSTEM B:
   # |0  0  0 |
   # |a* b* c*|
   # |0  d* e*|
	z[18]=rbeta(1,1,1)		#a* is uninformative and is free to vary
	z[19]=.99				#b* has an original guess, otherwise 
						# reverts to uninformative uniform and 
						# free to vary
	deathNB2=runif(1,0,1-z[19])	#d* is constrained by selection of b*
	z[21]=1-z[19]-deathNB2		#d* is constrained by selection of b*
	z[22]=.99				#e* has an original guess, otherwise 
						# reverts to uninformative uniform and 
						# free to vary
	deathNB3=runif(1,0,1-z[22])	#c* is constrained by selection of e*
	z[20]=1-z[22]-deathNB3		#c* is constrained by selection of e*	

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  # GENERATE THE TIME SERIES FOR THE Z VECTOR GIVEN THE INITIAL VECTOR
	Nz[,1]=rbind(0,z[2],z[1])					# Initial conditions for January census 
	NzH=matrix(0,3,29)
	NzHR=matrix(0,3,29)
	NzRDec=matrix(0,3,29)

	for (i in 1:29){							# Count of january census

	# ITERATE BIRDS THROUGH THE BREEDING PERIOD
		L=matrix(c(0,0,z[7],z[8],z[9],z[10],0,z[11],z[12]),3,3,byrow=TRUE)
		NzH[,i]=L%*%Nz[,i]					# Count at June census prior to migrations

	# PREPARE THE NUMBER OF RESIDENT DEPARTURES PER TIME STEP
		z[5]=AdultsLeftPercentage*NzH[3,i]		# Number of resident adults that leave after breeding period
		z[6]=SubadultsLeftPercentage*NzH[2,i]	# Number of resident subadults that leave after breeding period	

	# REMOVE THE BIRDS THAT LEAVE
		NzHR[1,i]=NzH[1,i]
		NzHR[2,i]=NzH[2,i]-z[6]					# Number of subadult residents left after some depart
		NzHR[3,i]=NzH[3,i]-z[5]					# Number of adult residents left after some depart

	# RUN YEAR-ROUND BIRDS THROUGH NON-BREEDING MATRIX IN SYSTEM A
		LNB=matrix(c(0,0,0,z[13],z[14],z[15],0,z[16],z[17]),3,3,byrow=TRUE)
		NzRDec[,i]=LNB%*%NzHR[,i]

	# PREPARE THE NUMBER OF INCOMING MIGRANTS PER TIME STEP
		z[28]=AdultsArrivePercentage*Nz[3,i]	# Number of incoming migrant adults
		z[27]=SubadultsArrivePercentage*Nz[2,i]	# Number of incoming migrant subadults

	# RUN INCOMING MIGRANTS THROUGH NON-BREEDING MATRIX IN SYSTEM A
		Migrants=matrix(c(0,z[27],z[28]),3,1,byrow=FALSE)
		Migrantsurvivors=LNB%*%Migrants
	
	# RUN SYSTEM B BIRDS THROUGH THEIR NON-BREEDING MATRIX
		LNBE=matrix(c(0,0,0,z[18],z[19],z[20],0,z[21],z[22]),3,3,byrow=TRUE)
		Elsewhere=matrix(c(0,z[6],z[5]),3,1,byrow=FALSE)
		Elsewheresurvivors=LNBE%*%Elsewhere

	# PREPARE PURGE OF SURVIVORS
		z[24]=AdultsPurge*Elsewheresurvivors[3,1]		# Limited by # of surviving migrating resident adults
		z[23]=SubadultsPurge*Elsewheresurvivors[2,1]	# Limited by # of surviving migrating resident subadults

	# PREPARE ABSORPTION OF SURVIVORS
		z[26]=AdultsAbsorb*Migrantsurvivors[3,1]		# Limited by # of surviving migrating adults
		z[25]=SubadultsAbsorb*Migrantsurvivors[2,1]	# Limited by # of surviving migrating subadults
	
	# RESIDENTS + RETURNING RESIDENTS - PURGE + ABSORB
		Nz[2,i+1]=NzRDec[2,i]+Elsewheresurvivors[2,1]-z[23]+z[25]	# The incoming migants were never actually added to the system	
		Nz[3,i+1]=NzRDec[3,i]+Elsewheresurvivors[3,1]-z[24]+z[26]	# The incoming migants were never actually added to the system
	
	if (Nz[3,i+1]<0){Nz[3,i+1]=0}
	if (Nz[2,i+1]<0){Nz[2,i+1]=0}
	} # END LOOP TO GENERATE 29-STEP TIME SERIES FOR Z VECTOR

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  # DETERMINE THE "DISTANCE VALUE" OF Z BASED ON THE CONSTRAINT. SEE
  # CODE HEADER FOR CONSTRAINT.  
	Distz=(sqrt(TIMESERIES[1])-sqrt(Nz[3,1]))^2+
		(sqrt(TIMESERIES[3])-sqrt(Nz[3,3]))^2+
		(sqrt(TIMESERIES[5])-sqrt(Nz[3,5]))^2+
		(sqrt(TIMESERIES[7])-sqrt(Nz[3,7]))^2+
		(sqrt(TIMESERIES[9])-sqrt(Nz[3,9]))^2+
		(sqrt(TIMESERIES[11])-sqrt(Nz[3,11]))^2+
		(sqrt(TIMESERIES[13])-sqrt(Nz[3,13]))^2+
		(sqrt(TIMESERIES[15])-sqrt(Nz[3,15]))^2+
		(sqrt(TIMESERIES[17])-sqrt(Nz[3,17]))^2+
		(sqrt(TIMESERIES[19])-sqrt(Nz[3,19]))^2+
		(sqrt(TIMESERIES[21])-sqrt(Nz[3,21]))^2+
		(sqrt(TIMESERIES[23])-sqrt(Nz[3,23]))^2+
		(sqrt(TIMESERIES[25])-sqrt(Nz[3,25]))^2+
		(sqrt(TIMESERIES[27])-sqrt(Nz[3,27]))^2+
		(sqrt(TIMESERIES[29])-sqrt(Nz[3,29]))^2+
		(sqrt(TIMESERIES[2])-sqrt(Nz[3,2]))^2+
		(sqrt(TIMESERIES[4])-sqrt(Nz[3,4]))^2+
		(sqrt(TIMESERIES[6])-sqrt(Nz[3,6]))^2+
		(sqrt(TIMESERIES[8])-sqrt(Nz[3,8]))^2+
		(sqrt(TIMESERIES[10])-sqrt(Nz[3,10]))^2+
		(sqrt(TIMESERIES[12])-sqrt(Nz[3,12]))^2+
		(sqrt(TIMESERIES[14])-sqrt(Nz[3,14]))^2+
		(sqrt(TIMESERIES[16])-sqrt(Nz[3,16]))^2+
		(sqrt(TIMESERIES[18])-sqrt(Nz[3,18]))^2+
		(sqrt(TIMESERIES[20])-sqrt(Nz[3,20]))^2+
		(sqrt(TIMESERIES[22])-sqrt(Nz[3,22]))^2+
		(sqrt(TIMESERIES[24])-sqrt(Nz[3,24]))^2+
		(sqrt(TIMESERIES[26])-sqrt(Nz[3,26]))^2+
		(sqrt(TIMESERIES[28])-sqrt(Nz[3,28]))^2
	
  # THE STARTING VECTOR HAS BEEN SET. WE NOW BEGIN THE MARKOV CHAIN
  # TO 1) GENERATE A NEW CANDIATE VECTOR, 2) COMPARE THE NEW CANDIDATE 
  # VECTOR TO THE ORIGINAL ONE, 3) MAKE A DECISION ON WHICH ONE TO KEEP, 
  # THEN REPEAT MANY TIMES.  THE RESULTING VECTOR WILL BE OPTIMIZED 
  # ACCORDING TO THE PREDETERMINED OPTIMIZATION CONSTRAINT.  

  # BEGIN THE MARKOV CHAIN!
	for (k in 1:num.tests){	
	 # RESET BOTH VECTORS TO BE THE SAME
		znew=z
		Nznew=Nz
		Distznew=Distz	
		AdultsLeftPercentageNew=AdultsLeftPercentage
		SubadultsLeftPercentageNew=SubadultsLeftPercentage
		AdultsArrivePercentageNew=AdultsArrivePercentage
		SubadultsArrivePercentageNew=SubadultsArrivePercentage	
		SubadultsPurgeNew=SubadultsPurge
		AdultsPurgeNew=AdultsPurge
		AdultsAbsorbNew=AdultsAbsorb
		SubadultsAbsorbNew=SubadultsAbsorb

       # RANDOMLY PICK AN INDEX TO FLIP (FROM THOSE FREE TO VARY)	
		b=sample(c(2,5,6,7,9,12,13,14,17,18,19,22,23,24,25,26,27,28),1)
	 # GENERATE A NEW VECTOR WITH BY MODIFYING THE VALUE IN THE BTH LOCATION
		if(b==2){znew[b]=sample(0:(3*znew[1]),1)}			# New Subadult initial conditions
		if(b==5){AdultsLeftPercentageNew=runif(1,0,1)}		# New % of adult migrants
		if(b==6){SubadultsLeftPercentageNew=runif(1,0,1)}	# New % of subadult migrants
		if(b==7){znew[b]=runif(1,.5,1.5)}				# New fertility
	# IF BREEDING PERIOD STAGE TWO CHANGES, 
	# MUST ALSO CHANGE ALL STAGE THREE EVERYTHING (12, 17, 22, 10, 15, 20)
		if(b==9){znew[b]=runif(1,0,3/4)				# New a22
			znew[11]=znew[9]/3					# Update a32 from a22		
			S2B=(znew[b]*4)/3						# Update new survival at stage II
			x3=1+(1/8)*(S2B)-(1/2)*sqrt((16*S2B+S2B^2)/(16))	# Update x3
			znew[12]=runif(1,0,1-x3) 				# Create a new a33
			znew[17]=runif(1,0,1-x3)				# Create a new e
			znew[22]=runif(1,0,1-x3)				# Create a new e*
			znew[10]=runif(1,0,znew[12]*x3)			# Fill in a23 from a33
			znew[15]=runif(1,0,znew[17]*x3)			# Fill in c from e
			znew[20]=runif(1,0,znew[22]*x3)			# Create a new c* from e*
			}				
		if(b==12){
			S2B=znew[11]*5
			x3=1+(1/8)*(S2B)-(1/2)*sqrt((16*S2B+S2B^2)/(16))
			znew[b]=runif(1,0,1-x3)}				# New a33
		if(b==13){znew[b]=rbeta(1,1,1)}				# New a
		if(b==14){znew[b]=runif(1,0,3/4)}				# New b 
		if(b==17){
			S2B=znew[11]*4
			x3=1+(1/8)*(S2B)-(1/2)*sqrt((16*S2B+S2B^2)/(16))
			znew[b]=runif(1,0,1-x3)}				# New e
		if(b==18){znew[b]=rbeta(1,1,1)}				# New a*
		if(b==19){znew[b]=runif(1,0,3/4)}				# New b*
		if(b==22){
			S2B=znew[11]*4
			x3=1+(1/8)*(S2B)-(1/2)*sqrt((16*S2B+S2B^2)/(16))
			znew[b]=runif(1,0,1-x3)}				# New e*
		if(b==23){SubadultsPurgeNew=runif(1,0,1)}			# New % of purged subadults
		if(b==24){AdultsPurgeNew=runif(1,0,.2)}			# New % of purged adults
		if(b==25){SubadultsAbsorbNew=runif(1,0,1)}		# New % of absorbed subadults
		if(b==26){AdultsAbsorbNew=runif(1,0,.2)}			# New % of absorbed adults
		if(b==27){SubadultsArrivePercentageNew=runif(1,0,1)}	# New % of arriving subadults
		if(b==28){AdultsArrivePercentageNew=runif(1,0,1)}	# New % of arriving adults

	 # UPDATE THE VALUES OF THE VARIABLES CONTINGENT ON THE ABOVE CHANGE
		if(b==12){znew[10]=runif(1,0,znew[12]*x3)}		# New a23
		if(b==14){znew[16]=znew[14]/3}				# New d
		if(b==17){znew[15]=runif(1,0,znew[17]*x3)}		# New c
		if(b==19){znew[21]=znew[19]/3}				# New d*
		if(b==22){znew[20]=runif(1,0,znew[22]*x3)}		# New c*

  # THE NEW CANDIDATE VECTOR HAS BEEN SET. AT THIS POINT, THE ALGORITHM WILL 
  # COMPARE THE PERFORMANCE OF THE NEW TIMES SERIES TO THE PERFORMANCE 
  # OF THE OLD TIME SERIES.

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
  # GENERATE THE TIME SERIES FOR THE Z VECTOR GIVEN THE INITIAL VECTOR
	Nznew[,1]=rbind(0,znew[2],znew[1])				# Initial conditions for January census 
	NzHnew=matrix(0,3,29)
	NzHRnew=matrix(0,3,29)
	NzRDecnew=matrix(0,3,29)

	for (i in 1:29){							# Count of january census

	# ITERATE BIRDS THROUGH THE BREEDING PERIOD
		Lnew=matrix(c(0,0,znew[7],znew[8],znew[9],znew[10],0,znew[11],znew[12]),3,3,byrow=TRUE)
		NzHnew[,i]=Lnew%*%Nznew[,i]				# Count at June census prior to migrations

	# PREPARE THE NUMBER OF RESIDENT DEPARTURES PER TIME STEP
		znew[5]=AdultsLeftPercentageNew*NzHnew[3,i]	# Number of resident adults that leave after breeding period
		znew[6]=SubadultsLeftPercentageNew*NzHnew[2,i]	# Number of resident subadults that leave after breeding period	

	# REMOVE THE BIRDS THAT LEAVE
		NzHRnew[1,i]=NzHnew[1,i]
		NzHRnew[2,i]=NzHnew[2,i]-znew[6]				# Number of subadult residents left after some depart
		NzHRnew[3,i]=NzHnew[3,i]-znew[5]				# Number of adult residents left after some depart

	# RUN SYSTEM YEAR ROUND BIRDS THROUGH NON-BREEDING MATRIX IN SYSTEM A
		LNBnew=matrix(c(0,0,0,znew[13],znew[14],znew[15],0,znew[16],znew[17]),3,3,byrow=TRUE)
		NzRDecnew[,i]=LNBnew%*%NzHRnew[,i]

	# PREPARE THE NUMBER OF INCOMING MIGRANTS PER TIME STEP
		znew[28]=AdultsArrivePercentageNew*Nznew[3,i]		# Number of incoming migrant adults
		znew[27]=SubadultsArrivePercentageNew*Nznew[2,i]	# Number of incoming migrant subadults

	# RUN INCOMING MIGRANTS THROUGH NON-BREEDING MATRIX IN SYSTEM A
		Migrantsnew=matrix(c(0,znew[27],znew[28]),3,1,byrow=FALSE)
		Migrantsurvivorsnew=LNBnew%*%Migrantsnew
	
	# RUN SYSTEM B BIRDS THROUGH THEIR NON-BREEDING MATRIX
		LNBEnew=matrix(c(0,0,0,znew[18],znew[19],znew[20],0,znew[21],znew[22]),3,3,byrow=TRUE)
		Elsewherenew=matrix(c(0,znew[6],znew[5]),3,1,byrow=FALSE)
		Elsewheresurvivorsnew=LNBEnew%*%Elsewherenew

	# PREPARE PURGE OF SURVIVORS
		znew[24]=AdultsPurgeNew*Elsewheresurvivorsnew[3,1]	# Limited by # of surviving migrating resident adults
		znew[23]=SubadultsPurgeNew*Elsewheresurvivorsnew[2,1] # Limited by # of surviving migrating resident subadults

	# PREPARE ABSORPTION OF SURVIVORS
		znew[26]=AdultsAbsorbNew*Migrantsurvivorsnew[3,1]	# Limited by # of surviving migrating adults
		znew[25]=SubadultsAbsorbNew*Migrantsurvivorsnew[2,1]	# Limited by # of surviving migrating subadults
	
	# RESIDENTS + RETURNING RESIDENTS - PURGE + ABSORB
		Nznew[2,i+1]=NzRDecnew[2,i]+Elsewheresurvivorsnew[2,1]-znew[23]+znew[25]	# The incoming migants were never actually added to the system	
		Nznew[3,i+1]=NzRDecnew[3,i]+Elsewheresurvivorsnew[3,1]-znew[24]+znew[26]	# The incoming migants were never actually added to the system
		
	if (Nznew[3,i+1]<0){Nznew[3,i+1]=0}
	if (Nznew[2,i+1]<0){Nznew[2,i+1]=0}
	} # END LOOP TO GENERATE 29-STEP TIME SERIES FOR ZNEW VECTOR

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

   # PLOT THE ADULT COMPARISONS SO WE CAN SEE THAT THE COMPUTER IS WORKING!
	plot(1:29,TIMESERIES,type="l",xlim=c(1,29),ylab="Abundances",xlab="Time",
	ylim=c(0,max(TIMESERIES)),col="green")
	points(1:29,Nz[3,1:29],type="l",xlim=c(1,29),ylab="Abundances",xlab="Time",
	ylim=c(0,max(TIMESERIES)))
	points(1:29,Nznew[3,1:29],type="l",xlim=c(1,29),ylab="Abundances",xlab="Time",
	ylim=c(0,max(TIMESERIES)))

   # CALCULATE THE DISTANCE FOR THE NEW VECTOR
	Distznew=(sqrt(TIMESERIES[1])-sqrt(Nznew[3,1]))^2+
		(sqrt(TIMESERIES[3])-sqrt(Nznew[3,3]))^2+
		(sqrt(TIMESERIES[5])-sqrt(Nznew[3,5]))^2+
		(sqrt(TIMESERIES[7])-sqrt(Nznew[3,7]))^2+
		(sqrt(TIMESERIES[9])-sqrt(Nznew[3,9]))^2+
		(sqrt(TIMESERIES[11])-sqrt(Nznew[3,11]))^2+
		(sqrt(TIMESERIES[13])-sqrt(Nznew[3,13]))^2+
		(sqrt(TIMESERIES[15])-sqrt(Nznew[3,15]))^2+
		(sqrt(TIMESERIES[17])-sqrt(Nznew[3,17]))^2+
		(sqrt(TIMESERIES[19])-sqrt(Nznew[3,19]))^2+
		(sqrt(TIMESERIES[21])-sqrt(Nznew[3,21]))^2+
		(sqrt(TIMESERIES[23])-sqrt(Nznew[3,23]))^2+
		(sqrt(TIMESERIES[25])-sqrt(Nznew[3,25]))^2+
		(sqrt(TIMESERIES[27])-sqrt(Nznew[3,27]))^2+
		(sqrt(TIMESERIES[29])-sqrt(Nznew[3,29]))^2+
		(sqrt(TIMESERIES[2])-sqrt(Nznew[3,2]))^2+
		(sqrt(TIMESERIES[4])-sqrt(Nznew[3,4]))^2+
		(sqrt(TIMESERIES[6])-sqrt(Nznew[3,6]))^2+
		(sqrt(TIMESERIES[8])-sqrt(Nznew[3,8]))^2+
		(sqrt(TIMESERIES[10])-sqrt(Nznew[3,10]))^2+
		(sqrt(TIMESERIES[12])-sqrt(Nznew[3,12]))^2+
		(sqrt(TIMESERIES[14])-sqrt(Nznew[3,14]))^2+
		(sqrt(TIMESERIES[16])-sqrt(Nznew[3,16]))^2+
		(sqrt(TIMESERIES[18])-sqrt(Nznew[3,18]))^2+
		(sqrt(TIMESERIES[20])-sqrt(Nznew[3,20]))^2+
		(sqrt(TIMESERIES[22])-sqrt(Nznew[3,22]))^2+
		(sqrt(TIMESERIES[24])-sqrt(Nznew[3,24]))^2+
		(sqrt(TIMESERIES[26])-sqrt(Nznew[3,26]))^2+
		(sqrt(TIMESERIES[28])-sqrt(Nznew[3,28]))^2

   # GATHER A BUNCH OF CANDIATE VECTORS WITH GOOD PREDICTIVE CAPACITY
	if (Distznew<=THRESHOLD){Candid=rbind(Candid,as.numeric(znew))

	TRAJECTORY_ADULTS_JAN=rbind(TRAJECTORY_ADULTS_JAN,Nznew[3,])
	TRAJECTORY_SUBADULTS_JAN=rbind(TRAJECTORY_SUBADULTS_JAN,Nznew[2,])
	TRAJECTORY_JUVENILES_JUNE=rbind(TRAJECTORY_JUVENILES_JUNE,NzHRnew[1,])
	TRAJECTORY_SUBADULTS_JUNE=rbind(TRAJECTORY_SUBADULTS_JUNE,NzHRnew[2,])
	TRAJECTORY_ADULTS_JUNE=rbind(TRAJECTORY_ADULTS_JUNE,NzHRnew[3,])

	PA=c(PA,AdultsLeftPercentageNew)
	PS=c(PS,SubadultsLeftPercentageNew)
	AA=c(AA,AdultsArrivePercentageNew)
	SA=c(SA,SubadultsArrivePercentageNew)
	betaA=c(betaA,AdultsPurgeNew)
	alphaS=c(alphaS,SubadultsPurgeNew)
	betastar=c(betastar,AdultsAbsorbNew)
	alphastar=c(alphastar,SubadultsAbsorbNew)}

   # GATHER THE GLOBAL LOWEST Z VECTOR AND TRAJECTORY
	if (Distznew==min(Dist1))
	{Distlowest=Distznew;Nzlowest=Nznew;zlowest=znew;
	AdultPercentLowest=AdultsLeftPercentageNew
	SubadultPercentLowest=SubadultsLeftPercentageNew
	AdultMPercentLowest=AdultsArrivePercentageNew
	SubadultMPercentLowest=SubadultsArrivePercentageNew
	AlphaLowest=SubadultsPurgeNew
	BetaLowest=AdultsPurgeNew
	AlphaStarLowest=SubadultsAbsorbNew
	BetaStarLowest=AdultsAbsorbNew}
		
   # ACCEPT THE NEW VECTOR OR ACCEPT THE OLD VECTOR 
   # WITH PROBABILTY ALPHA
	alpha=runif(0,1,1)
	if (Distz>=Distznew)
	{z=znew;Nz=Nznew;Distz=Distznew
	AdultsArrivePercentage=AdultsArrivePercentageNew
	SubadultsArrivePercentage=SubadultsArrivePercentageNew
	SubadultsPurge=SubadultsPurgeNew
	AdultsPurge=AdultsPurgeNew
	AdultsAbsorb=AdultsAbsorbNew
	SubadultsAbsorb=SubadultsAbsorbNew
	AdultsLeftPercentage=AdultsLeftPercentageNew
	SubadultsLeftPercentage=SubadultsLeftPercentageNew}else{z=z;Nz=Nz;Distz=Distz
	AdultsArrivePercentage=AdultsArrivePercentage
	SubadultsArrivePercentage=SubadultsArrivePercentage
	SubadultsPurge=SubadultsPurge
	AdultsPurge=AdultsPurge
	AdultsAbsorb=AdultsAbsorb
	SubadultsAbsorb=SubadultsAbsorb
	AdultsLeftPercentage=AdultsLeftPercentage
	SubadultsLeftPercentage=SubadultsLeftPercentage}
	if (Distz<Distznew){
	if (runif(1)<.01){z=znew;Nz=Nznew;Distz=Distznew
	AdultsArrivePercentage=AdultsArrivePercentageNew
	SubadultsArrivePercentage=SubadultsArrivePercentageNew
	SubadultsPurge=SubadultsPurgeNew
	AdultsPurge=AdultsPurgeNew
	AdultsAbsorb=AdultsAbsorbNew
	SubadultsAbsorb=SubadultsAbsorbNew
	AdultsLeftPercentage=AdultsLeftPercentageNew
	SubadultsLeftPercentage=SubadultsLeftPercentageNew}
	}
   # UPDATE THE OPTIMIZATION OF DISTANCE
	Dist1=c(Dist1,Distz)

} # END THE MARKOV CHAIN


##################################################################
##################################################################
	TRAJECTORY_ADULTS_JAN=TRAJECTORY_ADULTS_JAN[-1,]
	TRAJECTORY_SUBADULTS_JAN=TRAJECTORY_SUBADULTS_JAN[-1,]
	TRAJECTORY_ADULTS_JUNE=TRAJECTORY_ADULTS_JUNE[-1,]
	TRAJECTORY_SUBADULTS_JUNE=TRAJECTORY_SUBADULTS_JUNE[-1,]
	TRAJECTORY_JUVENILES_JUNE=TRAJECTORY_JUVENILES_JUNE[-1,]

##################################################################
##################################################################
# RESULT TRAJECTORY PLOT 1: OPTIMAL TRAJECTORIES PLUS ERROR

	par(mfrow=c(1,1))
	year=seq(1990,2018,1)
	plot(1:29,TIMESERIES,type="l",xlim=c(1,29),xaxt="n",ylim=c(0,max(TIMESERIES)),
	main="Algorithm-predicted trajectories of female resident eagles in NORTHEAST United States",col="green",
	lwd=2,xlab="Breeding periods",ylab="Resident breeding pairs")
	axis(1, at=1:29, labels=year)
	points(1:29,Nzlowest[3,1:29],type="l",xlim=c(1,29),
	ylim=c(0,max(TIMESERIES)),lwd=2)
	points(1:29,Nzlowest[2,1:29],type="l",xlim=c(1,29),
	ylim=c(0,max(TIMESERIES)),lwd=2, col="blue")

	for (i in 1:length(TRAJECTORY_ADULTS_JAN[,1])){
	points(1:29,TRAJECTORY_ADULTS_JAN[i,1:29],type="l",col="grey")
	points(1:29,TRAJECTORY_SUBADULTS_JAN[i,1:29],type="l",col="skyblue")}
	# REDRAW THE GLOBAL BEST MODEL OVER THE ALTERNATIVES
		points(1:29,TIMESERIES,type="l",xlim=c(1,29),ylim=c(0,max(TIMESERIES)),
		main="",col="green",lwd=2,xlab="",ylab="")
		points(1:29,Nzlowest[2,1:29],type="l",xlim=c(1,29),
		col="blue",ylim=c(0,max(TIMESERIES)),lwd=2)
		points(1:29,Nzlowest[3,1:29],type="l",
		xlim="",ylim="",lwd=2)
		legend(.5,max(TIMESERIES), lwd=c(2,2,2,2),col=c("green","black","blue",
		"grey","skyblue"), 
		c("Mock breeding adult females",
		"Predicted breeding adult females in global best model",
		"Predicted non-breeding females in global best model",
		"Predicted breeding adult females in top set of best models",
		"Predicted non-breeding females in top set of best models"))

##################################################################
##################################################################

# STORE THE TOP BEST MODELS AND TIMESERIES
	Candidates=Candid[-1,]
	write.table(Candidates,"NORTHEAST.txt")
	write.table(TRAJECTORY_ADULTS_JAN,"Adults_January_NORTHEAST.txt")
	write.table(TRAJECTORY_ADULTS_JUNE,"Adults_June_NORTHEAST.txt")
	write.table(TRAJECTORY_SUBADULTS_JAN,"Subadults_January_NORTHEAST.txt")
	write.table(TRAJECTORY_SUBADULTS_JUNE,"Subadults_June_NORTHEAST.txt")
	write.table(TRAJECTORY_JUVENILES_JUNE,"Juveniles_June_NORTHEAST.txt")
	write.table(PA,"PA_NORTHEAST.txt")
	write.table(PS,"PS_NORTHEAST.txt")
	write.table(AA,"AA_NORTHEAST.txt")
	write.table(SA,"SA_NORTHEAST.txt")
	write.table(TIMESERIES,"TIMESERIES_NORTHEAST.txt")
	write.table(alphaS,"SubadultsPurgePercent_NORTHEAST.txt")
	write.table(betaA,"AdultsPurgePercent_NORTHEAST.txt")
	write.table(alphastar,"SubadultsAbsorbPercent_NORTHEAST.txt")
	write.table(betastar,"AdultsAbsorbPercent_NORTHEAST.txt")

# PARING DOWN THE MODELS ACCORDING TO BALD EAGLE LIFE HISTORY TRAITS
# GATHER THE PREVIOUSLY SAVED "GOOD" MODELS
		MODEL=read.table("NORTHEAST.txt")
	# GATHER THE PREVIOUSLY SAVED EMPIRICAL TIME SERIES
		TIMESERIES.1=read.table("TIMESERIES_NORTHEAST.txt")
	# PREPARE THE FORMAT OF THE TIME SERIES
		TIMESERIES=TIMESERIES.1[["x"]]
	# GATHER THE PREVIOUSLY SAVED MIGATION PERCENTAGES
		PA1=read.table("PA_NORTHEAST.txt")
		PS1=read.table("PS_NORTHEAST.txt")
		AA1=read.table("AA_NORTHEAST.txt")
		SA1=read.table("SA_NORTHEAST.txt")
		PurgeA1=read.table("AdultsPurgePercent_NORTHEAST.txt")
		PurgeS1=read.table("SubadultsPurgePercent_NORTHEAST.txt")
		AbsorbA1=read.table("AdultsAbsorbPercent_NORTHEAST.txt")
		AbsorbS1=read.table("SubadultsAbsorbPercent_NORTHEAST.txt")
	# GATHER THE PREVIOUSLY SAVED TIME SERIES TRAJECTORIES
		TRAJECTORY_ADULTS_JAN=read.table("Adults_January_NORTHEAST.txt")
		TRAJECTORY_ADULTS_JUNE=read.table("Adults_June_NORTHEAST.txt")
		TRAJECTORY_SUBADULTS_JAN=read.table("Subadults_January_NORTHEAST.txt")
		TRAJECTORY_SUBADULTS_JUNE=read.table("Subadults_June_NORTHEAST.txt")
		TRAJECTORY_JUVENILES_JUNE=read.table("Juveniles_June_NORTHEAST.txt")
	# PREPARE THE FORMAT OF THE MIGRATION PERCENTAGES
		PA2=PA1[["x"]];PA=PA2[-1]
		PS2=PS1[["x"]];PS=PS2[-1] 
		AA2=AA1[["x"]];AA=AA2[-1]
		SA2=SA1[["x"]];SA=SA2[-1] 
		PurgeA2=PurgeA1[["x"]];PurgeA=PurgeA2[-1]
		PurgeS2=PurgeS1[["x"]];PurgeS=PurgeS2[-1]
		AbsorbA2=AbsorbA1[["x"]];AbsorbA=AbsorbA2[-1]
		AbsorbS2=AbsorbS1[["x"]];AbsorbS=AbsorbS2[-1]

E=numeric(length(MODEL[,1]))

# INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN BREEDING PERIODS
  Surv2b=numeric(length(MODEL[,1]))
  Surv3b=numeric(length(MODEL[,1]))
  # INITALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING PERIODS
  Surv1nb=numeric(length(MODEL[,1]))
  Surv2nb=numeric(length(MODEL[,1]))
  Surv3nb=numeric(length(MODEL[,1]))
  # INITIALIZE STORAGE FOR SURVIVAL OF EACH STAGE IN NON-BREEDING OTHER
  Surv1nbe=numeric(length(MODEL[,1]))
  Surv2nbe=numeric(length(MODEL[,1]))
  Surv3nbe=numeric(length(MODEL[,1]))
  # REMOVE THE TRANSITION PROBABILITIES FROM MATRIX ELEMENTS
  # TO LEAVE ONLY THE SURVIVAL IN EACH STAGE 

# ENSURE THAT THE MOCK TIME SERIES IS PLAUSIBLE FOR EAGLES
 for (iii in 1:length(MODEL[,1])){
    Surv2b[iii]=(4*MODEL[iii,9])/3		# Trans Prob = 1/4
    Surv1nb[iii]=MODEL[iii,13]			# Trans Prob = 1
    Surv2nb[iii]=(4*MODEL[iii,14])/3		# Trans Prob = 1/4
    Surv1nbe[iii]=MODEL[iii,18]			# Trans Prob = 1
    Surv2nbe[iii]=(4*MODEL[iii,19])/3		# Trans Prob = 1/4
    Surv2b[iii]=(4*MODEL[iii,19])/3

    x3[iii]=1+(1/8)*(Surv2b[iii])-(1/2)*sqrt((16*Surv2b[iii]+Surv2b[iii]^2)/16)
    Surv3b[iii]=MODEL[iii,12]/(1-x3[iii])		# Trans Prob = x3

    xx3[iii]=1+(1/8)*(Surv2nb[iii])-(1/2)*sqrt((16*Surv2nb[iii]+Surv2nb[iii]^2)/16)
    Surv3nb[iii]=MODEL[iii,17]/(1-xx3[iii])	# Trans Prob = xx3

    xxx3[iii]=1+(1/8)*(Surv2nbe[iii])-(1/2)*sqrt((16*Surv2nbe[iii]+Surv2nbe[iii]^2)/16)
    Surv3nbe[iii]=MODEL[iii,22]/(1-xxx3[iii])	# Trans Prob = xxx3
  }
if (Surv3b[iii]>=1){Surv3b[iii]=.999}
if (Surv3nb[iii]>=1){Surv3nb[iii]=.999}
if (Surv3nbe[iii]>=1){Surv3nbe[iii]=.999}
  
  # XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  Surv1NB=Surv1nb
  Surv1NBE=Surv1nbe
  Surv2B=Surv2b
  Surv2NB=Surv2nb
  Surv2NBE=Surv2nbe
  Surv3B=Surv3b
  Surv3NB=Surv3nb
  Surv3NBE=Surv3nbe
  
  P1=numeric(length(MODEL[,1]))
  P2=numeric(length(MODEL[,1]))
  P3=numeric(length(MODEL[,1]))
  P4=numeric(length(MODEL[,1]))
  P5=numeric(length(MODEL[,1]))
  P6=numeric(length(MODEL[,1]))
  P7=numeric(length(MODEL[,1]))
  P8=numeric(length(MODEL[,1]))
  P9=numeric(length(MODEL[,1]))
  P10=numeric(length(MODEL[,1]))
  P11=numeric(length(MODEL[,1]))
  P12=numeric(length(MODEL[,1]))
  P13=numeric(length(MODEL[,1]))
  P13=numeric(length(MODEL[,1]))
  P14=numeric(length(MODEL[,1]))
  P15=numeric(length(MODEL[,1]))
  P16=numeric(length(MODEL[,1]))
  P17=numeric(length(MODEL[,1]))
  P18=numeric(length(MODEL[,1]))
  P19=numeric(length(MODEL[,1]))
  P20=numeric(length(MODEL[,1]))
  P21=numeric(length(MODEL[,1]))
  P22=numeric(length(MODEL[,1]))
  P23=numeric(length(MODEL[,1]))
  P24=numeric(length(MODEL[,1]))
  P25=numeric(length(MODEL[,1]))
  P26=numeric(length(MODEL[,1]))
  P27=numeric(length(MODEL[,1]))
  P28=numeric(length(MODEL[,1]))
  P29=numeric(length(MODEL[,1]))
  P30=numeric(length(MODEL[,1]))
  P31=numeric(length(MODEL[,1]))
  P32=numeric(length(MODEL[,1]))
  P33=numeric(length(MODEL[,1]))
  P33=numeric(length(MODEL[,1]))
  P34=numeric(length(MODEL[,1]))
  P35=numeric(length(MODEL[,1]))
  P36=numeric(length(MODEL[,1]))
  P37=numeric(length(MODEL[,1]))
  P38=numeric(length(MODEL[,1]))
  P39=numeric(length(MODEL[,1]))
  P40=numeric(length(MODEL[,1]))
  P41=numeric(length(MODEL[,1]))
  P42=numeric(length(MODEL[,1]))
  P43=numeric(length(MODEL[,1]))
  P44=numeric(length(MODEL[,1]))
  P45=numeric(length(MODEL[,1]))
  P46=numeric(length(MODEL[,1]))
  P47=numeric(length(MODEL[,1]))
  P48=numeric(length(MODEL[,1]))
  P49=numeric(length(MODEL[,1]))
  P50=numeric(length(MODEL[,1]))

  #################################
  #################################
  for (i in 1:length(MODEL[,1])){
    P1[i]=
      (Surv1NB[i]+Surv1NBE[i])/(2^1)
  }
  
  #################################
  #################################
  
  for (i in 1:length(MODEL[,1])){
    P2[i]=
      # LIVE TO END OF YEAR 2
      (
        Surv1NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]+
          
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]
      )/(2^2)
  }
  
  #################################
  #################################
  
  for (i in 1:length(MODEL[,1])){
    P3[i]=
      # LIVE TO END OF YEAR 3
      (
        Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
          
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  for (i in 1:length(MODEL[,1])){
    P4[i]=
      # LIVE TO END OF YEAR 4
      (
        Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
          
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NB[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]+
          Surv1NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]*Surv2B[i]*Surv2NBE[i]
      )/(2^4)
  }
  
  #################################
  #################################
  
  # P5
  for (i in 1:length(MODEL[,1])){
    P5[i]=
      (
        # LIVE TO END OF YEAR 5 BUT SPEND 5TH YEAR IN STAGE II
        P4[i]*Surv2B[i]*Surv2NB[i]+
          P4[i]*Surv2B[i]*Surv2NBE[i]+
          
          # LIVE TO END OF YEAR 5 BUT SPEND 5TH YEAR IN STAGE III
          P4[i]*Surv3B[i]*Surv3NB[i]+
          P4[i]*Surv3B[i]*Surv3NBE[i]+
          
          #LIVE TO END OF YEAR 5 BUT SPEND 1/2 5TH YEAR IN STAGE II AND 1/2 IN STAGE III
          P4[i]*Surv3B[i]*Surv2NB[i]+
          P4[i]*Surv3B[i]*Surv2NBE[i]+
          
          P4[i]*Surv2B[i]*Surv3NB[i]+
          P4[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P6
  for (i in 1:length(MODEL[,1])){
    P6[i]=
      (
        # LIVE TO END OF YEAR 6 BUT SPEND 5TH YEAR IN STAGE II
        P5[i]*Surv2B[i]*Surv2NB[i]+
          P5[i]*Surv2B[i]*Surv2NBE[i]+
          
          # LIVE TO END OF YEAR 6 BUT SPEND 5TH YEAR IN STAGE III
          P5[i]*Surv3B[i]*Surv3NB[i]+
          P5[i]*Surv3B[i]*Surv3NBE[i]+
          
          #LIVE TO END OF YEAR 6 BUT SPEND 1/2 5TH YEAR IN STAGE II AND 1/2 IN STAGE III
          P5[i]*Surv3B[i]*Surv2NB[i]+
          P5[i]*Surv3B[i]*Surv2NBE[i]+
          
          P5[i]*Surv2B[i]*Surv3NB[i]+
          P5[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P7
  for (i in 1:length(MODEL[,1])){
    P7[i]=
      (
        P6[i]*Surv2B[i]*Surv2NB[i]+
          P6[i]*Surv2B[i]*Surv2NBE[i]+
          
          P6[i]*Surv3B[i]*Surv3NB[i]+
          P6[i]*Surv3B[i]*Surv3NBE[i]+
          
          P6[i]*Surv3B[i]*Surv2NB[i]+
          P6[i]*Surv3B[i]*Surv2NBE[i]+
          
          P6[i]*Surv2B[i]*Surv3NB[i]+
          P6[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P8
  for (i in 1:length(MODEL[,1])){
    P8[i]=
      (
        P7[i]*Surv2B[i]*Surv2NB[i]+
          P7[i]*Surv2B[i]*Surv2NBE[i]+
          
          P7[i]*Surv3B[i]*Surv3NB[i]+
          P7[i]*Surv3B[i]*Surv3NBE[i]+
          
          P7[i]*Surv3B[i]*Surv2NB[i]+
          P7[i]*Surv3B[i]*Surv2NBE[i]+
          
          P7[i]*Surv2B[i]*Surv3NB[i]+
          P7[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P9
  for (i in 1:length(MODEL[,1])){
    P9[i]=
      (
        P8[i]*Surv2B[i]*Surv2NB[i]+
          P8[i]*Surv2B[i]*Surv2NBE[i]+
          
          P8[i]*Surv3B[i]*Surv3NB[i]+
          P8[i]*Surv3B[i]*Surv3NBE[i]+
          
          P8[i]*Surv3B[i]*Surv2NB[i]+
          P8[i]*Surv3B[i]*Surv2NBE[i]+
          
          P8[i]*Surv2B[i]*Surv3NB[i]+
          P8[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P10
  for (i in 1:length(MODEL[,1])){
    P10[i]=
      (
        P9[i]*Surv2B[i]*Surv2NB[i]+
          P9[i]*Surv2B[i]*Surv2NBE[i]+
          
          P9[i]*Surv3B[i]*Surv3NB[i]+
          P9[i]*Surv3B[i]*Surv3NBE[i]+
          
          P9[i]*Surv3B[i]*Surv2NB[i]+
          P9[i]*Surv3B[i]*Surv2NBE[i]+
          
          P9[i]*Surv2B[i]*Surv3NB[i]+
          P9[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P11
  for (i in 1:length(MODEL[,1])){
    P11[i]=
      (
        P10[i]*Surv2B[i]*Surv2NB[i]+
          P10[i]*Surv2B[i]*Surv2NBE[i]+
          
          P10[i]*Surv3B[i]*Surv3NB[i]+
          P10[i]*Surv3B[i]*Surv3NBE[i]+
          
          P10[i]*Surv3B[i]*Surv2NB[i]+
          P10[i]*Surv3B[i]*Surv2NBE[i]+
          
          P10[i]*Surv2B[i]*Surv3NB[i]+
          P10[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P12
  for (i in 1:length(MODEL[,1])){
    P12[i]=
      (
        P11[i]*Surv2B[i]*Surv2NB[i]+
          P11[i]*Surv2B[i]*Surv2NBE[i]+
          
          P11[i]*Surv3B[i]*Surv3NB[i]+
          P11[i]*Surv3B[i]*Surv3NBE[i]+
          
          P11[i]*Surv3B[i]*Surv2NB[i]+
          P11[i]*Surv3B[i]*Surv2NBE[i]+
          
          P11[i]*Surv2B[i]*Surv3NB[i]+
          P11[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P13
  for (i in 1:length(MODEL[,1])){
    P13[i]=
      (
        P12[i]*Surv2B[i]*Surv2NB[i]+
          P12[i]*Surv2B[i]*Surv2NBE[i]+
          
          P12[i]*Surv3B[i]*Surv3NB[i]+
          P12[i]*Surv3B[i]*Surv3NBE[i]+
          
          P12[i]*Surv3B[i]*Surv2NB[i]+
          P12[i]*Surv3B[i]*Surv2NBE[i]+
          
          P12[i]*Surv2B[i]*Surv3NB[i]+
          P12[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P14
  for (i in 1:length(MODEL[,1])){
    P14[i]=
      (
        P13[i]*Surv2B[i]*Surv2NB[i]+
          P13[i]*Surv2B[i]*Surv2NBE[i]+
          
          P13[i]*Surv3B[i]*Surv3NB[i]+
          P13[i]*Surv3B[i]*Surv3NBE[i]+
          
          P13[i]*Surv3B[i]*Surv2NB[i]+
          P13[i]*Surv3B[i]*Surv2NBE[i]+
          
          P13[i]*Surv2B[i]*Surv3NB[i]+
          P13[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P15
  for (i in 1:length(MODEL[,1])){
    P15[i]=
      (
        P14[i]*Surv2B[i]*Surv2NB[i]+
          P14[i]*Surv2B[i]*Surv2NBE[i]+
          
          P14[i]*Surv3B[i]*Surv3NB[i]+
          P14[i]*Surv3B[i]*Surv3NBE[i]+
          
          P14[i]*Surv3B[i]*Surv2NB[i]+
          P14[i]*Surv3B[i]*Surv2NBE[i]+
          
          P14[i]*Surv2B[i]*Surv3NB[i]+
          P14[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P16
  for (i in 1:length(MODEL[,1])){
    P16[i]=
      (
        P15[i]*Surv2B[i]*Surv2NB[i]+
          P15[i]*Surv2B[i]*Surv2NBE[i]+
          
          P15[i]*Surv3B[i]*Surv3NB[i]+
          P15[i]*Surv3B[i]*Surv3NBE[i]+
          
          P15[i]*Surv3B[i]*Surv2NB[i]+
          P15[i]*Surv3B[i]*Surv2NBE[i]+
          
          P15[i]*Surv2B[i]*Surv3NB[i]+
          P15[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P17
  for (i in 1:length(MODEL[,1])){
    P17[i]=
      (
        P16[i]*Surv2B[i]*Surv2NB[i]+
          P16[i]*Surv2B[i]*Surv2NBE[i]+
          
          P16[i]*Surv3B[i]*Surv3NB[i]+
          P16[i]*Surv3B[i]*Surv3NBE[i]+
          
          P16[i]*Surv3B[i]*Surv2NB[i]+
          P16[i]*Surv3B[i]*Surv2NBE[i]+
          
          P16[i]*Surv2B[i]*Surv3NB[i]+
          P16[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P18
  for (i in 1:length(MODEL[,1])){
    P18[i]=
      (
        P17[i]*Surv2B[i]*Surv2NB[i]+
          P17[i]*Surv2B[i]*Surv2NBE[i]+
          
          P17[i]*Surv3B[i]*Surv3NB[i]+
          P17[i]*Surv3B[i]*Surv3NBE[i]+
          
          P17[i]*Surv3B[i]*Surv2NB[i]+
          P17[i]*Surv3B[i]*Surv2NBE[i]+
          
          P17[i]*Surv2B[i]*Surv3NB[i]+
          P17[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P19
  for (i in 1:length(MODEL[,1])){
    P19[i]=
      (
        P18[i]*Surv2B[i]*Surv2NB[i]+
          P18[i]*Surv2B[i]*Surv2NBE[i]+
          
          P18[i]*Surv3B[i]*Surv3NB[i]+
          P18[i]*Surv3B[i]*Surv3NBE[i]+
          
          P18[i]*Surv3B[i]*Surv2NB[i]+
          P18[i]*Surv3B[i]*Surv2NBE[i]+
          
          P18[i]*Surv2B[i]*Surv3NB[i]+
          P18[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P20
  for (i in 1:length(MODEL[,1])){
    P20[i]=
      (
        P19[i]*Surv2B[i]*Surv2NB[i]+
          P19[i]*Surv2B[i]*Surv2NBE[i]+
          
          P19[i]*Surv3B[i]*Surv3NB[i]+
          P19[i]*Surv3B[i]*Surv3NBE[i]+
          
          P19[i]*Surv3B[i]*Surv2NB[i]+
          P19[i]*Surv3B[i]*Surv2NBE[i]+
          
          P19[i]*Surv2B[i]*Surv3NB[i]+
          P19[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P21
  for (i in 1:length(MODEL[,1])){
    P21[i]=
      (
        P20[i]*Surv2B[i]*Surv2NB[i]+
          P20[i]*Surv2B[i]*Surv2NBE[i]+
          
          P20[i]*Surv3B[i]*Surv3NB[i]+
          P20[i]*Surv3B[i]*Surv3NBE[i]+
          
          P20[i]*Surv3B[i]*Surv2NB[i]+
          P20[i]*Surv3B[i]*Surv2NBE[i]+
          
          P20[i]*Surv2B[i]*Surv3NB[i]+
          P20[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P22
  for (i in 1:length(MODEL[,1])){
    P22[i]=
      (
        P21[i]*Surv2B[i]*Surv2NB[i]+
          P21[i]*Surv2B[i]*Surv2NBE[i]+
          
          P21[i]*Surv3B[i]*Surv3NB[i]+
          P21[i]*Surv3B[i]*Surv3NBE[i]+
          
          P21[i]*Surv3B[i]*Surv2NB[i]+
          P21[i]*Surv3B[i]*Surv2NBE[i]+
          
          P21[i]*Surv2B[i]*Surv3NB[i]+
          P21[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P23
  for (i in 1:length(MODEL[,1])){
    P23[i]=
      (
        P22[i]*Surv2B[i]*Surv2NB[i]+
          P22[i]*Surv2B[i]*Surv2NBE[i]+
          
          P22[i]*Surv3B[i]*Surv3NB[i]+
          P22[i]*Surv3B[i]*Surv3NBE[i]+
          
          P22[i]*Surv3B[i]*Surv2NB[i]+
          P22[i]*Surv3B[i]*Surv2NBE[i]+
          
          P22[i]*Surv2B[i]*Surv3NB[i]+
          P22[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  
  #################################
  #################################
  
  # P24
  for (i in 1:length(MODEL[,1])){
    P24[i]=
      (
        P23[i]*Surv2B[i]*Surv2NB[i]+
          P23[i]*Surv2B[i]*Surv2NBE[i]+
          
          P23[i]*Surv3B[i]*Surv3NB[i]+
          P23[i]*Surv3B[i]*Surv3NBE[i]+
          
          P23[i]*Surv3B[i]*Surv2NB[i]+
          P23[i]*Surv3B[i]*Surv2NBE[i]+
          
          P23[i]*Surv2B[i]*Surv3NB[i]+
          P23[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P25
  for (i in 1:length(MODEL[,1])){
    P25[i]=
      (
        P24[i]*Surv2B[i]*Surv2NB[i]+
          P24[i]*Surv2B[i]*Surv2NBE[i]+
          
          P24[i]*Surv3B[i]*Surv3NB[i]+
          P24[i]*Surv3B[i]*Surv3NBE[i]+
          
          P24[i]*Surv3B[i]*Surv2NB[i]+
          P24[i]*Surv3B[i]*Surv2NBE[i]+
          
          P24[i]*Surv2B[i]*Surv3NB[i]+
          P24[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P26
  for (i in 1:length(MODEL[,1])){
    P26[i]=
      (
          P25[i]*Surv2B[i]*Surv2NB[i]+
          P25[i]*Surv2B[i]*Surv2NBE[i]+
          P25[i]*Surv3B[i]*Surv3NB[i]+
          P25[i]*Surv3B[i]*Surv3NBE[i]+
          
          P25[i]*Surv3B[i]*Surv2NB[i]+
          P25[i]*Surv3B[i]*Surv2NBE[i]+
          
          P25[i]*Surv2B[i]*Surv3NB[i]+
          P25[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P27
  for (i in 1:length(MODEL[,1])){
    P27[i]=
      (
        P26[i]*Surv2B[i]*Surv2NB[i]+
          P26[i]*Surv2B[i]*Surv2NBE[i]+
          
          P26[i]*Surv3B[i]*Surv3NB[i]+
          P26[i]*Surv3B[i]*Surv3NBE[i]+
          
          P26[i]*Surv3B[i]*Surv2NB[i]+
          P26[i]*Surv3B[i]*Surv2NBE[i]+
          
          P26[i]*Surv2B[i]*Surv3NB[i]+
          P26[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }

  #################################
  #################################
  
  # P28
  for (i in 1:length(MODEL[,1])){
    P28[i]=
      (
        P27[i]*Surv2B[i]*Surv2NB[i]+
          P27[i]*Surv2B[i]*Surv2NBE[i]+
          
          P27[i]*Surv3B[i]*Surv3NB[i]+
          P27[i]*Surv3B[i]*Surv3NBE[i]+
          
          P27[i]*Surv3B[i]*Surv2NB[i]+
          P27[i]*Surv3B[i]*Surv2NBE[i]+
          
          P27[i]*Surv2B[i]*Surv3NB[i]+
          P27[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }

  #################################
  #################################
  
  # P29
  for (i in 1:length(MODEL[,1])){
    P29[i]=
      (
          P28[i]*Surv2B[i]*Surv2NB[i]+
          P28[i]*Surv2B[i]*Surv2NBE[i]+
          P28[i]*Surv3B[i]*Surv3NB[i]+
          P28[i]*Surv3B[i]*Surv3NBE[i]+
          P28[i]*Surv3B[i]*Surv2NB[i]+
          P28[i]*Surv3B[i]*Surv2NBE[i]+
          P28[i]*Surv2B[i]*Surv3NB[i]+
          P28[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P30
  for (i in 1:length(MODEL[,1])){
    P30[i]=
      (
          P29[i]*Surv2B[i]*Surv2NB[i]+
          P29[i]*Surv2B[i]*Surv2NBE[i]+
          P29[i]*Surv3B[i]*Surv3NB[i]+
          P29[i]*Surv3B[i]*Surv3NBE[i]+
          P29[i]*Surv3B[i]*Surv2NB[i]+
          P29[i]*Surv3B[i]*Surv2NBE[i]+
          P29[i]*Surv2B[i]*Surv3NB[i]+
          P29[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P31
  for (i in 1:length(MODEL[,1])){
    P31[i]=
      (
          P30[i]*Surv2B[i]*Surv2NB[i]+
          P30[i]*Surv2B[i]*Surv2NBE[i]+
          P30[i]*Surv3B[i]*Surv3NB[i]+
          P30[i]*Surv3B[i]*Surv3NBE[i]+
          P30[i]*Surv3B[i]*Surv2NB[i]+
          P30[i]*Surv3B[i]*Surv2NBE[i]+
          P30[i]*Surv2B[i]*Surv3NB[i]+
          P30[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P32
  for (i in 1:length(MODEL[,1])){
    P32[i]=
      (
          P31[i]*Surv2B[i]*Surv2NB[i]+
          P31[i]*Surv2B[i]*Surv2NBE[i]+
          P31[i]*Surv3B[i]*Surv3NB[i]+
          P31[i]*Surv3B[i]*Surv3NBE[i]+
          P31[i]*Surv3B[i]*Surv2NB[i]+
          P31[i]*Surv3B[i]*Surv2NBE[i]+
          P31[i]*Surv2B[i]*Surv3NB[i]+
          P31[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P33
  for (i in 1:length(MODEL[,1])){
    P33[i]=
      (
          P32[i]*Surv2B[i]*Surv2NB[i]+
          P32[i]*Surv2B[i]*Surv2NBE[i]+
          P32[i]*Surv3B[i]*Surv3NB[i]+
          P32[i]*Surv3B[i]*Surv3NBE[i]+
          P32[i]*Surv3B[i]*Surv2NB[i]+
          P32[i]*Surv3B[i]*Surv2NBE[i]+
          P32[i]*Surv2B[i]*Surv3NB[i]+
          P32[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P34
  for (i in 1:length(MODEL[,1])){
    P34[i]=
      (
          P33[i]*Surv2B[i]*Surv2NB[i]+
          P33[i]*Surv2B[i]*Surv2NBE[i]+
          P33[i]*Surv3B[i]*Surv3NB[i]+
          P33[i]*Surv3B[i]*Surv3NBE[i]+
          P33[i]*Surv3B[i]*Surv2NB[i]+
          P33[i]*Surv3B[i]*Surv2NBE[i]+
          P33[i]*Surv2B[i]*Surv3NB[i]+
          P33[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P35
  for (i in 1:length(MODEL[,1])){
    P35[i]=
      (
          P34[i]*Surv2B[i]*Surv2NB[i]+
          P34[i]*Surv2B[i]*Surv2NBE[i]+
          P34[i]*Surv3B[i]*Surv3NB[i]+
          P34[i]*Surv3B[i]*Surv3NBE[i]+
          P34[i]*Surv3B[i]*Surv2NB[i]+
          P34[i]*Surv3B[i]*Surv2NBE[i]+
          P34[i]*Surv2B[i]*Surv3NB[i]+
          P34[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P36
  for (i in 1:length(MODEL[,1])){
    P36[i]=
      (
          P35[i]*Surv2B[i]*Surv2NB[i]+
          P35[i]*Surv2B[i]*Surv2NBE[i]+
          P35[i]*Surv3B[i]*Surv3NB[i]+
          P35[i]*Surv3B[i]*Surv3NBE[i]+
          P35[i]*Surv3B[i]*Surv2NB[i]+
          P35[i]*Surv3B[i]*Surv2NBE[i]+
          P35[i]*Surv2B[i]*Surv3NB[i]+
          P35[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P37
  for (i in 1:length(MODEL[,1])){
    P37[i]=
      (
          P36[i]*Surv2B[i]*Surv2NB[i]+
          P36[i]*Surv2B[i]*Surv2NBE[i]+
          P36[i]*Surv3B[i]*Surv3NB[i]+
          P36[i]*Surv3B[i]*Surv3NBE[i]+
          P36[i]*Surv3B[i]*Surv2NB[i]+
          P36[i]*Surv3B[i]*Surv2NBE[i]+
          P36[i]*Surv2B[i]*Surv3NB[i]+
          P36[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P38
  for (i in 1:length(MODEL[,1])){
    P38[i]=
      (
          P37[i]*Surv2B[i]*Surv2NB[i]+
          P37[i]*Surv2B[i]*Surv2NBE[i]+
          P37[i]*Surv3B[i]*Surv3NB[i]+
          P37[i]*Surv3B[i]*Surv3NBE[i]+
          P37[i]*Surv3B[i]*Surv2NB[i]+
          P37[i]*Surv3B[i]*Surv2NBE[i]+
          P37[i]*Surv2B[i]*Surv3NB[i]+
          P37[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P39
  for (i in 1:length(MODEL[,1])){
    P39[i]=
      (
          P38[i]*Surv2B[i]*Surv2NB[i]+
          P38[i]*Surv2B[i]*Surv2NBE[i]+
          P38[i]*Surv3B[i]*Surv3NB[i]+
          P38[i]*Surv3B[i]*Surv3NBE[i]+
          P38[i]*Surv3B[i]*Surv2NB[i]+
          P38[i]*Surv3B[i]*Surv2NBE[i]+
          P38[i]*Surv2B[i]*Surv3NB[i]+
          P38[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P40
  for (i in 1:length(MODEL[,1])){
    P40[i]=
      (
          P39[i]*Surv2B[i]*Surv2NB[i]+
          P39[i]*Surv2B[i]*Surv2NBE[i]+
          P39[i]*Surv3B[i]*Surv3NB[i]+
          P39[i]*Surv3B[i]*Surv3NBE[i]+
          P39[i]*Surv3B[i]*Surv2NB[i]+
          P39[i]*Surv3B[i]*Surv2NBE[i]+
          P39[i]*Surv2B[i]*Surv3NB[i]+
          P39[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P41
  for (i in 1:length(MODEL[,1])){
    P41[i]=
      (
          P40[i]*Surv2B[i]*Surv2NB[i]+
          P40[i]*Surv2B[i]*Surv2NBE[i]+
          P40[i]*Surv3B[i]*Surv3NB[i]+
          P40[i]*Surv3B[i]*Surv3NBE[i]+
          P40[i]*Surv3B[i]*Surv2NB[i]+
          P40[i]*Surv3B[i]*Surv2NBE[i]+
          P40[i]*Surv2B[i]*Surv3NB[i]+
          P40[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P42
  for (i in 1:length(MODEL[,1])){
    P42[i]=
      (
          P41[i]*Surv2B[i]*Surv2NB[i]+
          P41[i]*Surv2B[i]*Surv2NBE[i]+
          P41[i]*Surv3B[i]*Surv3NB[i]+
          P41[i]*Surv3B[i]*Surv3NBE[i]+
          P41[i]*Surv3B[i]*Surv2NB[i]+
          P41[i]*Surv3B[i]*Surv2NBE[i]+
          P41[i]*Surv2B[i]*Surv3NB[i]+
          P41[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P43
  for (i in 1:length(MODEL[,1])){
    P43[i]=
      (
          P42[i]*Surv2B[i]*Surv2NB[i]+
          P42[i]*Surv2B[i]*Surv2NBE[i]+
          P42[i]*Surv3B[i]*Surv3NB[i]+
          P42[i]*Surv3B[i]*Surv3NBE[i]+
          P42[i]*Surv3B[i]*Surv2NB[i]+
          P42[i]*Surv3B[i]*Surv2NBE[i]+
          P42[i]*Surv2B[i]*Surv3NB[i]+
          P42[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P44
  for (i in 1:length(MODEL[,1])){
    P44[i]=
      (
          P43[i]*Surv2B[i]*Surv2NB[i]+
          P43[i]*Surv2B[i]*Surv2NBE[i]+
          P43[i]*Surv3B[i]*Surv3NB[i]+
          P43[i]*Surv3B[i]*Surv3NBE[i]+
          P43[i]*Surv3B[i]*Surv2NB[i]+
          P43[i]*Surv3B[i]*Surv2NBE[i]+
          P43[i]*Surv2B[i]*Surv3NB[i]+
          P43[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P45
  for (i in 1:length(MODEL[,1])){
    P45[i]=
      (
          P44[i]*Surv2B[i]*Surv2NB[i]+
          P44[i]*Surv2B[i]*Surv2NBE[i]+
          P44[i]*Surv3B[i]*Surv3NB[i]+
          P44[i]*Surv3B[i]*Surv3NBE[i]+
          P44[i]*Surv3B[i]*Surv2NB[i]+
          P44[i]*Surv3B[i]*Surv2NBE[i]+
          P44[i]*Surv2B[i]*Surv3NB[i]+
          P44[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P46
  for (i in 1:length(MODEL[,1])){
    P46[i]=
      (
          P45[i]*Surv2B[i]*Surv2NB[i]+
          P45[i]*Surv2B[i]*Surv2NBE[i]+
          P45[i]*Surv3B[i]*Surv3NB[i]+
          P45[i]*Surv3B[i]*Surv3NBE[i]+
          P45[i]*Surv3B[i]*Surv2NB[i]+
          P45[i]*Surv3B[i]*Surv2NBE[i]+
          P45[i]*Surv2B[i]*Surv3NB[i]+
          P45[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P47
  for (i in 1:length(MODEL[,1])){
    P47[i]=
      (
          P46[i]*Surv2B[i]*Surv2NB[i]+
          P46[i]*Surv2B[i]*Surv2NBE[i]+
          P46[i]*Surv3B[i]*Surv3NB[i]+
          P46[i]*Surv3B[i]*Surv3NBE[i]+
          P46[i]*Surv3B[i]*Surv2NB[i]+
          P46[i]*Surv3B[i]*Surv2NBE[i]+
          P46[i]*Surv2B[i]*Surv3NB[i]+
          P46[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P48
  for (i in 1:length(MODEL[,1])){
    P48[i]=
      (
          P47[i]*Surv2B[i]*Surv2NB[i]+
          P47[i]*Surv2B[i]*Surv2NBE[i]+
          P47[i]*Surv3B[i]*Surv3NB[i]+
          P47[i]*Surv3B[i]*Surv3NBE[i]+
          P47[i]*Surv3B[i]*Surv2NB[i]+
          P47[i]*Surv3B[i]*Surv2NBE[i]+
          P47[i]*Surv2B[i]*Surv3NB[i]+
          P47[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P49
  for (i in 1:length(MODEL[,1])){
    P49[i]=
      (
          P48[i]*Surv2B[i]*Surv2NB[i]+
          P48[i]*Surv2B[i]*Surv2NBE[i]+
          P48[i]*Surv3B[i]*Surv3NB[i]+
          P48[i]*Surv3B[i]*Surv3NBE[i]+
          P48[i]*Surv3B[i]*Surv2NB[i]+
          P48[i]*Surv3B[i]*Surv2NBE[i]+
          P48[i]*Surv2B[i]*Surv3NB[i]+
          P48[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
  #################################
  #################################
  
  # P50
  for (i in 1:length(MODEL[,1])){
    P50[i]=
      (
          P49[i]*Surv2B[i]*Surv2NB[i]+
          P49[i]*Surv2B[i]*Surv2NBE[i]+
          P49[i]*Surv3B[i]*Surv3NB[i]+
          P49[i]*Surv3B[i]*Surv3NBE[i]+
          P49[i]*Surv3B[i]*Surv2NB[i]+
          P49[i]*Surv3B[i]*Surv2NBE[i]+
          P49[i]*Surv2B[i]*Surv3NB[i]+
          P49[i]*Surv2B[i]*Surv3NBE[i]
      )/(2^3)
  }
TOTAL=
P1+P2+P3+P4+P5+P6+P7+P8+P9+P10+
P11+P12+P13+P14+P15+P16+P17+P18+P19+P20+
P21+P22+P23+P24+P25+P26+P27+P28+P29+P30+
P31+P32+P33+P34+P35+P36+P37+P38+P39+P40+
P41+P42+P43+P44+P45+P46+P47+P48+P49+P50

E=1*P1/TOTAL+2*P2/TOTAL+3*P3/TOTAL+4*P4/TOTAL+5*P5/TOTAL+
6*P6/TOTAL+7*P7/TOTAL+8*P8/TOTAL+9*P9/TOTAL+10*P10/TOTAL+
11*P11/TOTAL+12*P12/TOTAL+13*P13/TOTAL+14*P14/TOTAL+15*P15/TOTAL+
16*P16/TOTAL+17*P17/TOTAL+18*P18/TOTAL+19*P19/TOTAL+20*P20/TOTAL+
21*P21/TOTAL+22*P22/TOTAL+23*P23/TOTAL+24*P24/TOTAL+25*P25/TOTAL+
26*P26/TOTAL+27*P27/TOTAL+28*P28/TOTAL+29*P29/TOTAL+30*P30/TOTAL+
31*P31/TOTAL+32*P32/TOTAL+33*P33/TOTAL+34*P34/TOTAL+35*P35/TOTAL+
36*P36/TOTAL+37*P37/TOTAL+38*P38/TOTAL+39*P39/TOTAL+40*P40/TOTAL+
41*P41/TOTAL+42*P42/TOTAL+43*P43/TOTAL+44*P44/TOTAL+45*P45/TOTAL+
46*P46/TOTAL+47*P47/TOTAL+48*P48/TOTAL+49*P49/TOTAL+50*P50/TOTAL

hist(E)

##################################################################
	
	# FIND THE DISTANCES
	Distance=numeric(length(MODEL[,1]))
	for (i in 1:length(MODEL[,1])){
		Distance[i]=(sqrt(TIMESERIES[1])-sqrt(TRAJECTORY_ADULTS_JAN[i,1]))^2+
		(sqrt(TIMESERIES[3])-sqrt(TRAJECTORY_ADULTS_JAN[i,3]))^2+
		(sqrt(TIMESERIES[5])-sqrt(TRAJECTORY_ADULTS_JAN[i,5]))^2+
		(sqrt(TIMESERIES[7])-sqrt(TRAJECTORY_ADULTS_JAN[i,7]))^2+
		(sqrt(TIMESERIES[9])-sqrt(TRAJECTORY_ADULTS_JAN[i,9]))^2+
		(sqrt(TIMESERIES[11])-sqrt(TRAJECTORY_ADULTS_JAN[i,11]))^2+
		(sqrt(TIMESERIES[13])-sqrt(TRAJECTORY_ADULTS_JAN[i,13]))^2+
		(sqrt(TIMESERIES[15])-sqrt(TRAJECTORY_ADULTS_JAN[i,15]))^2+
		(sqrt(TIMESERIES[17])-sqrt(TRAJECTORY_ADULTS_JAN[i,17]))^2+
		(sqrt(TIMESERIES[19])-sqrt(TRAJECTORY_ADULTS_JAN[i,19]))^2+
		(sqrt(TIMESERIES[21])-sqrt(TRAJECTORY_ADULTS_JAN[i,21]))^2+
		(sqrt(TIMESERIES[23])-sqrt(TRAJECTORY_ADULTS_JAN[i,23]))^2+
		(sqrt(TIMESERIES[25])-sqrt(TRAJECTORY_ADULTS_JAN[i,25]))^2+
		(sqrt(TIMESERIES[27])-sqrt(TRAJECTORY_ADULTS_JAN[i,27]))^2+
		(sqrt(TIMESERIES[29])-sqrt(TRAJECTORY_ADULTS_JAN[i,29]))^2+
		(sqrt(TIMESERIES[2])-sqrt(TRAJECTORY_ADULTS_JAN[i,2]))^2+
		(sqrt(TIMESERIES[4])-sqrt(TRAJECTORY_ADULTS_JAN[i,4]))^2+
		(sqrt(TIMESERIES[6])-sqrt(TRAJECTORY_ADULTS_JAN[i,6]))^2+
		(sqrt(TIMESERIES[8])-sqrt(TRAJECTORY_ADULTS_JAN[i,8]))^2+
		(sqrt(TIMESERIES[10])-sqrt(TRAJECTORY_ADULTS_JAN[i,10]))^2+
		(sqrt(TIMESERIES[12])-sqrt(TRAJECTORY_ADULTS_JAN[i,12]))^2+
		(sqrt(TIMESERIES[14])-sqrt(TRAJECTORY_ADULTS_JAN[i,14]))^2+
		(sqrt(TIMESERIES[16])-sqrt(TRAJECTORY_ADULTS_JAN[i,16]))^2+
		(sqrt(TIMESERIES[18])-sqrt(TRAJECTORY_ADULTS_JAN[i,18]))^2+
		(sqrt(TIMESERIES[20])-sqrt(TRAJECTORY_ADULTS_JAN[i,20]))^2+
		(sqrt(TIMESERIES[22])-sqrt(TRAJECTORY_ADULTS_JAN[i,22]))^2+
		(sqrt(TIMESERIES[24])-sqrt(TRAJECTORY_ADULTS_JAN[i,24]))^2+
		(sqrt(TIMESERIES[26])-sqrt(TRAJECTORY_ADULTS_JAN[i,26]))^2+
		(sqrt(TIMESERIES[28])-sqrt(TRAJECTORY_ADULTS_JAN[i,28]))^2}

##################################################################
	
# FIND THE PROBABILTY OF LIVING TO BREEDING AGE
Living.to.breeding.rrr=numeric(length(MODEL[,1]))
Living.to.breeding.mmm=numeric(length(MODEL[,1]))
Living.to.breeding.rrm=numeric(length(MODEL[,1]))
Living.to.breeding.rmm=numeric(length(MODEL[,1]))

for (i in 1:length(MODEL[,1])){
  Living.to.breeding.rrr[i]=(MODEL[i,13])^2*((4*MODEL[i,14])/3)^2
  Living.to.breeding.mmm[i]=(MODEL[i,13])^2*((4*MODEL[i,19])/3)^2
  Living.to.breeding.rrm[i]=(MODEL[i,13])^2*((4*MODEL[i,14])/3)*((4*MODEL[i,19])/3)
  Living.to.breeding.rmm[i]=(MODEL[i,13])^2*((4*MODEL[i,14])/3)*((4*MODEL[i,19])/3)
}

index=c()

# PARING DOWN MODELS FOR REASONABLE LIFE EXPECTANCY TO BREEDING AGE
for (i in 1:length(MODEL[,1])){
  if (.35<=Living.to.breeding.rrr[i] & Living.to.breeding.rrr[i]<.65){
    if (.35<=Living.to.breeding.rrm[i] & Living.to.breeding.rrm[i]<.65){
      if (.35<=Living.to.breeding.rmm[i] & Living.to.breeding.rmm[i]<.65){
        if (.35<=Living.to.breeding.mmm[i] & Living.to.breeding.mmm[i]<.65){
	     if (MODEL[i,13]>.63){
		  if (MODEL[i,18]>.63){
                if (E[i]>10){
                  index=c(index,i)}}}}}}}}

	NEW.MODELS=MODEL[index,]
	NEW.TRAJECTORY_ADULTS_JAN=TRAJECTORY_ADULTS_JAN[index,]
	NEW.TRAJECTORY_ADULTS_JUNE=TRAJECTORY_ADULTS_JUNE[index,]
	NEW.TRAJECTORY_SUBADULTS_JAN=TRAJECTORY_SUBADULTS_JAN[index,]
	NEW.TRAJECTORY_SUBADULTS_JUNE=TRAJECTORY_SUBADULTS_JUNE[index,]
	NEW.TRAJECTORY_JUVENILES_JUNE=TRAJECTORY_JUVENILES_JUNE[index,]
	NEW.PA=PA[index]
	NEW.PS=PS[index]
	NEW.AA=AA[index]
	NEW.SA=SA[index]
	NEW.PurgeA=PurgeA[index]
	NEW.PurgeS=PurgeS[index]
	NEW.AbsorbA=AbsorbA[index]
	NEW.AbsorbS=AbsorbS[index]
	NEW.Distances=Distance[index]

	NEW.P1=P1[index]
	NEW.P2=P2[index]
	NEW.P3=P3[index]
	NEW.P4=P4[index]
	NEW.P5=P5[index]
	NEW.P6=P6[index]
	NEW.P7=P7[index]
	NEW.P8=P8[index]
	NEW.P9=P9[index]

	NEW.P10=P10[index]
	NEW.P11=P11[index]
	NEW.P12=P12[index]
	NEW.P13=P13[index]
	NEW.P14=P14[index]
	NEW.P15=P15[index]
	NEW.P16=P16[index]
	NEW.P17=P17[index]
	NEW.P18=P18[index]
	NEW.P19=P19[index]

	NEW.P20=P20[index]
	NEW.P21=P21[index]
	NEW.P22=P22[index]
	NEW.P23=P23[index]
	NEW.P24=P24[index]
	NEW.P25=P25[index]
	NEW.P26=P26[index]
	NEW.P27=P27[index]
	NEW.P28=P28[index]
	NEW.P29=P29[index]

	NEW.P30=P30[index]
	NEW.P31=P31[index]
	NEW.P32=P32[index]
	NEW.P33=P33[index]
	NEW.P34=P34[index]
	NEW.P35=P35[index]
	NEW.P36=P36[index]
	NEW.P37=P37[index]
	NEW.P38=P38[index]
	NEW.P39=P39[index]

	NEW.P40=P40[index]
	NEW.P41=P41[index]
	NEW.P42=P42[index]
	NEW.P43=P43[index]
	NEW.P44=P44[index]
	NEW.P45=P45[index]
	NEW.P46=P46[index]
	NEW.P47=P47[index]
	NEW.P48=P48[index]
	NEW.P49=P49[index]

	NEW.P50=P50[index]

  NEW.Surv1nb=Surv1NB[index]
  NEW.Surv1nbe=Surv1NBE[index]
  NEW.Surv2b=Surv2B[index]
  NEW.Surv2nb=Surv2NB[index]
  NEW.Surv2nbe=Surv2NBE[index]
  NEW.Surv3b=Surv3B[index]
  NEW.Surv3nb=Surv3NB[index]
  NEW.Surv3nbe=Surv3NBE[index]
##################################################################
	
	# RESAVE THE BEST CANDIATE MODELS
	write.table(NEW.MODELS,"BestAlgorithmPredictedModelsNORTHEAST.txt")
	write.table(NEW.TRAJECTORY_ADULTS_JAN,"NEW_Adults_January_NORTHEAST.txt")
	write.table(NEW.TRAJECTORY_ADULTS_JUNE,"NEW_Adults_June_NORTHEAST.txt")
	write.table(NEW.TRAJECTORY_SUBADULTS_JAN,"NEW_Subadults_January_NORTHEAST.txt")
	write.table(NEW.TRAJECTORY_SUBADULTS_JUNE,"NEW_Subadults_June_NORTHEAST.txt")
	write.table(NEW.TRAJECTORY_JUVENILES_JUNE,"NEW_Juveniles_June_NORTHEAST.txt")
	write.table(NEW.PA,"NEW_PA_NORTHEAST.txt")
	write.table(NEW.PS,"NEW_PS_NORTHEAST.txt")
	write.table(NEW.AA,"NEW_AA_NORTHEAST.txt")
	write.table(NEW.SA,"NEW_SA_NORTHEAST.txt")
	write.table(NEW.PurgeS,"NEW_SubadultsPurgePercent_NORTHEAST.txt")
	write.table(NEW.PurgeA,"NEW_AdultsPurgePercent_NORTHEAST.txt")
	write.table(NEW.AbsorbS,"NEW_SubadultsAbsorbPercent_NORTHEAST.txt")
	write.table(NEW.AbsorbA,"NEW_AdultsAbsorbPercent_NORTHEAST.txt")
	write.table(TIMESERIES,"NEW_TIMESERIES_NORTHEAST.txt")

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# COMPARE THE OUTCOMES
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX


# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# ANNUAL PLOTS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
  TIMESERIES=TIMESERIES.1[["x"]]
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
  TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
  AnnualMean=matrix(0,2,29)	
  AnnualVar=matrix(0,2,29)		
  for (k in 1:29){
    AnnualMean[1,k]=mean(TRAJECTORY_SUBADULTS_JAN[,k])
    AnnualMean[2,k]=mean(TRAJECTORY_ADULTS_JAN[,k]);
    AnnualVar[1,k]=var(TRAJECTORY_SUBADULTS_JAN[,k])
    AnnualVar[2,k]=var(TRAJECTORY_ADULTS_JAN[,k])}
  # PLOT THE MEANS OF EACH TIME STEP
  plot(1:29,AnnualMean[1,],type="l",xlim=c(1,29),
       ylab="Algorithm-predicted abundances",xlab="Year",
       ylim=c(0,max(max(AnnualMean[1,]),
                    max(AnnualMean[2,]))),col="skyblue4",lwd=3,
       main="Algorithm-predicted female abundances for the mock trajectory",
       xaxt="n")
  year=seq(1990,2018,1)
  axis(1, at=seq(1,29,1), labels=year)
  points(1:29,AnnualMean[2,],type="l",xlim=c(1,29),
         ylab="",xlab="",ylim="",col="grey31",lwd=3)
  BOOT.UPPER.SUB=numeric(28);BOOT.LOWER.SUB=numeric(28);
  BOOT.UPPER.AD=numeric(28);BOOT.LOWER.AD=numeric(28);
  for (w in 1:29){
    VectorS=sort(TRAJECTORY_SUBADULTS_JAN[,w])
    VectorA=sort(TRAJECTORY_ADULTS_JAN[,w])
    Index=1
    BOOT.UPPER.SUB[w]=VectorS[(length(TRAJECTORY_SUBADULTS_JAN[,w]))]
    BOOT.LOWER.SUB[w]=VectorS[Index]
    BOOT.UPPER.AD[w]=VectorA[(length(TRAJECTORY_ADULTS_JAN[,w]))]
    BOOT.LOWER.AD[w]=VectorA[Index]}
  x=c(1:29,29:1)
  y=c(BOOT.LOWER.SUB,rev(BOOT.UPPER.SUB))
  polygon(x,y,col="skyblue",border="skyblue")
  yy=c(BOOT.LOWER.AD,rev(BOOT.UPPER.AD))
  polygon(x,yy,col="grey",border="grey")
  points(1:29,AnnualMean[1,],type="l",xlim="",ylab="",
         xlab="",lty=3,col="skyblue4",lwd=2)
  points(1:29,AnnualMean[2,],type="l",xlim="",ylab="",
         xlab="",lty=3,col="grey31",lwd=2)
  legend(0,max(max(AnnualMean[1,]),max(AnnualMean[2,])),
         box.lty = 0,lty=c(1,3,1,3,1),
         c("Mock breeding adult females",
           "Predicted mean of immature and non-breeding adult females",
           "Predicted range of immature and non-breeding adult females",
           "Predicted mean of breeding adult females","Predicted range of breeding adult females"),
         lwd=c(2,2,2,2,2),col=c("blue","skyblue4","skyblue", "grey31", "grey"))	
  points(1:29,TIMESERIES,type="l",lwd=4,col="blue")

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# BI-ANNUAL HATCHLING
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
  TIMESERIES=TIMESERIES.1[["x"]]

  ELONGATEDTIMESERIES=numeric(58)
  ELONGATEDTIMESERIES[1]=JUVENILES_JUNE.EXACT[1]
  loop=1
  for (u in 2:58){
    if (u%%2==0){
      ELONGATEDTIMESERIES[u]=JUVENILES_JUNE.EXACT[loop]}
    if (u%%2!=0){
      loop=loop+1
      ELONGATEDTIMESERIES[u]=-600}}

  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
  TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
  ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
  ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
  BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
  BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
  BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
  NzMeanH=matrix(0,3,29)		
  NzVarH=matrix(0,3,29)
  NzMean=matrix(0,2,29)		
  NzVar=matrix(0,2,29)
  for (k in 1:29){
    NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
    NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
    NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
    NzVar[2,k]=var(ANNUAL.ADULTS[,k])
    NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
    NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
    NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
    NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
    NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
    NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
  } # END AT EACH TIME LOOP [k]
  # AUXILLARY INFORMATION FROM THE STATE GOVERNMENT 
  NzJHlong=matrix(0,length(MODELS[,1]),58)
  NzSHlong=matrix(0,length(MODELS[,1]),58)
  NzAHlong=matrix(0,length(MODELS[,1]),58)
  ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
  ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
  BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
  BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
  BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
  for (j in 1:length(BIANNUAL.JUVENILES[,1])){
    NzJHlong[j,]=c(-500,BIANNUAL.JUVENILES[j,1],
                   -500,BIANNUAL.JUVENILES[j,2],
                   -500,BIANNUAL.JUVENILES[j,3],-500,BIANNUAL.JUVENILES[j,4],
                   -500,BIANNUAL.JUVENILES[j,5],
                   -500,BIANNUAL.JUVENILES[j,6],-500,BIANNUAL.JUVENILES[j,7],
                   -500,BIANNUAL.JUVENILES[j,8],
                   -500,BIANNUAL.JUVENILES[j,9],-500,BIANNUAL.JUVENILES[j,10],
                   -500,BIANNUAL.JUVENILES[j,11],-500,BIANNUAL.JUVENILES[j,12],
                   -500,BIANNUAL.JUVENILES[j,13],-500,BIANNUAL.JUVENILES[j,14],
                   -500,BIANNUAL.JUVENILES[j,15],-500,BIANNUAL.JUVENILES[j,16],
                   -500,BIANNUAL.JUVENILES[j,17],-500,BIANNUAL.JUVENILES[j,18],
                   -500,BIANNUAL.JUVENILES[j,19],-500,BIANNUAL.JUVENILES[j,20],
                   -500,BIANNUAL.JUVENILES[j,21],-500,BIANNUAL.JUVENILES[j,22],
                   -500,BIANNUAL.JUVENILES[j,23],-500,BIANNUAL.JUVENILES[j,24],
                   -500,BIANNUAL.JUVENILES[j,25],-500,BIANNUAL.JUVENILES[j,26],
                   -500,BIANNUAL.JUVENILES[j,27],-500,BIANNUAL.JUVENILES[j,28],
                   -500,BIANNUAL.JUVENILES[j,29])}
  for (k in 1:29){
    NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
    NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
    NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
    NzVar[2,k]=var(ANNUAL.ADULTS[,k])
    NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
    NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
    NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
    NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
    NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
    NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
  } # END AT EACH TIME LOOP [k]
  NzMeanHalfJ=numeric(58)
  NzMeanHalfJ=c(-500,NzMeanH[1,1],-500,NzMeanH[1,2],
                -500,NzMeanH[1,3],-500,NzMeanH[1,4],-500,NzMeanH[1,5],
                -500,NzMeanH[1,6],-500,NzMeanH[1,7],-500,NzMeanH[1,8],
                -500,NzMeanH[1,9],-500,NzMeanH[1,10],-500,NzMeanH[1,11],
                -500,NzMeanH[1,12],-500,NzMeanH[1,13],-500,NzMeanH[1,14],
                -500,NzMeanH[1,15],-500,NzMeanH[1,16],-500,NzMeanH[1,17],
                -500,NzMeanH[1,18],-500,NzMeanH[1,19],-500,NzMeanH[1,20],
                -500,NzMeanH[1,21],-500,NzMeanH[1,22],-500,NzMeanH[1,23],
                -500,NzMeanH[1,24],-500,NzMeanH[1,25],-500,NzMeanH[1,26],
                -500,NzMeanH[1,27],-500,NzMeanH[1,28],-500,NzMeanH[1,29])
  hhsBOOT.UPPER.JUV=numeric(58);hhsBOOT.LOWER.JUV=numeric(58);
  for (w in 1:58){
    Index=1
    VectorJH=sort(NzJHlong[,w])
    hhsBOOT.UPPER.JUV[w]=VectorJH[(length(NzJHlong[,w]))]
    hhsBOOT.LOWER.JUV[w]=VectorJH[Index]}
  for (b in 1:58){if (hhsBOOT.UPPER.JUV[b]<0){hhsBOOT.UPPER.JUV[b]=0}}
  for (b in 1:58){if (hhsBOOT.LOWER.JUV[b]<0){hhsBOOT.LOWER.JUV[b]=0}}
  plot(1:58,NzMeanHalfJ,type="p",xlim=c(1,58),
       ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
       ylim=c(0,max(hhsBOOT.UPPER.JUV)),
       col="darkcyan",lwd=1,lty=3,pch=20,
       main="Algorithm-predicted female abundances for the mock trajectory",xaxt="n")
  year=seq(1990,2018,1)
  axis(1,at=seq(1,57,2), labels=year)
  segments(2,hhsBOOT.LOWER.JUV[2],2,hhsBOOT.UPPER.JUV[2],lwd=3,col="darkcyan")
  segments(4,hhsBOOT.LOWER.JUV[4],4,hhsBOOT.UPPER.JUV[4],lwd=3,col="darkcyan")
  segments(6,hhsBOOT.LOWER.JUV[6],6,hhsBOOT.UPPER.JUV[6],lwd=3,col="darkcyan")
  segments(8,hhsBOOT.LOWER.JUV[8],8,hhsBOOT.UPPER.JUV[8],lwd=3,col="darkcyan")
  segments(10,hhsBOOT.LOWER.JUV[10],10,hhsBOOT.UPPER.JUV[10],lwd=3,col="darkcyan")
  segments(12,hhsBOOT.LOWER.JUV[12],12,hhsBOOT.UPPER.JUV[12],lwd=3,col="darkcyan")
  segments(14,hhsBOOT.LOWER.JUV[14],14,hhsBOOT.UPPER.JUV[14],lwd=3,col="darkcyan")
  segments(16,hhsBOOT.LOWER.JUV[16],16,hhsBOOT.UPPER.JUV[16],lwd=3,col="darkcyan")
  segments(18,hhsBOOT.LOWER.JUV[18],18,hhsBOOT.UPPER.JUV[18],lwd=3,col="darkcyan")
  segments(20,hhsBOOT.LOWER.JUV[20],20,hhsBOOT.UPPER.JUV[20],lwd=3,col="darkcyan")
  segments(22,hhsBOOT.LOWER.JUV[22],22,hhsBOOT.UPPER.JUV[22],lwd=3,col="darkcyan")
  segments(24,hhsBOOT.LOWER.JUV[24],24,hhsBOOT.UPPER.JUV[24],lwd=3,col="darkcyan")
  segments(26,hhsBOOT.LOWER.JUV[26],26,hhsBOOT.UPPER.JUV[26],lwd=3,col="darkcyan")
  segments(28,hhsBOOT.LOWER.JUV[28],28,hhsBOOT.UPPER.JUV[28],lwd=3,col="darkcyan")
  segments(30,hhsBOOT.LOWER.JUV[30],30,hhsBOOT.UPPER.JUV[30],lwd=3,col="darkcyan")
  segments(32,hhsBOOT.LOWER.JUV[32],32,hhsBOOT.UPPER.JUV[32],lwd=3,col="darkcyan")
  segments(34,hhsBOOT.LOWER.JUV[34],34,hhsBOOT.UPPER.JUV[34],lwd=3,col="darkcyan")
  segments(36,hhsBOOT.LOWER.JUV[36],36,hhsBOOT.UPPER.JUV[36],lwd=3,col="darkcyan")
  segments(38,hhsBOOT.LOWER.JUV[38],38,hhsBOOT.UPPER.JUV[38],lwd=3,col="darkcyan")
  segments(40,hhsBOOT.LOWER.JUV[40],40,hhsBOOT.UPPER.JUV[40],lwd=3,col="darkcyan")
  segments(42,hhsBOOT.LOWER.JUV[42],42,hhsBOOT.UPPER.JUV[42],lwd=3,col="darkcyan")
  segments(44,hhsBOOT.LOWER.JUV[44],44,hhsBOOT.UPPER.JUV[44],lwd=3,col="darkcyan")
  segments(46,hhsBOOT.LOWER.JUV[46],46,hhsBOOT.UPPER.JUV[46],lwd=3,col="darkcyan")
  segments(48,hhsBOOT.LOWER.JUV[48],48,hhsBOOT.UPPER.JUV[48],lwd=3,col="darkcyan")
  segments(50,hhsBOOT.LOWER.JUV[50],50,hhsBOOT.UPPER.JUV[50],lwd=3,col="darkcyan")
  segments(52,hhsBOOT.LOWER.JUV[52],52,hhsBOOT.UPPER.JUV[52],lwd=3,col="darkcyan")
  segments(54,hhsBOOT.LOWER.JUV[54],54,hhsBOOT.UPPER.JUV[54],lwd=3,col="darkcyan")
  segments(56,hhsBOOT.LOWER.JUV[56],56,hhsBOOT.UPPER.JUV[56],lwd=3,col="darkcyan")
  segments(58,hhsBOOT.LOWER.JUV[58],58,hhsBOOT.UPPER.JUV[58],lwd=3,col="darkcyan")
  points(1:58, ELONGATEDTIMESERIES,col="blue",pch=19)
  legend(0,max(max(hhsBOOT.UPPER.JUV)),
         c("Mock female hatchlings", 
           "Algorithm-predicted range for hatchling females"),
         box.lty = 0,lty=c(1,1),lwd=c(3,3),pch=c(19,20),
         col=c("blue","darkcyan"))	

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# BI-ANNUAL SUBADULT
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

 MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
  TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
  TIMESERIES=TIMESERIES.1[["x"]]

  ELONGATEDTIMESERIES=numeric(58)
  ELONGATEDTIMESERIES[1]=SUBADULTS_JAN.EXACT[1]
  loop=1
  for (u in 2:58){
    if (u%%2==0){
      ELONGATEDTIMESERIES[u]=SUBADULTS_JUNE.EXACT[loop]}
    if (u%%2!=0){
      loop=loop+1
      ELONGATEDTIMESERIES[u]=SUBADULTS_JAN.EXACT[loop]}}

  NzMeanH=matrix(0,3,29)		
  NzVarH=matrix(0,3,29)
  NzMean=matrix(0,2,29)		
  NzVar=matrix(0,2,29)
  ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
  ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
  BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
  BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
  BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
  for (k in 1:29){
    NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
    NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
    NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
    NzVar[2,k]=var(ANNUAL.ADULTS[,k])
    NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
    NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
    NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
    NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
    NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
    NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
  } 
  NzSlong=matrix(0,length(MODELS[,1]),58)
  NzAlong=matrix(0,length(MODELS[,1]),58)
  NzJHlong=matrix(0,length(MODELS[,1]),58)
  NzSHlong=matrix(0,length(MODELS[,1]),58)
  NzAHlong=matrix(0,length(MODELS[,1]),58)
  ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
  ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
  BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
  BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
  BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
  for (j in 1:length(BIANNUAL.JUVENILES[,1])){
    NzJHlong[j,]=c(-50,BIANNUAL.JUVENILES[j,1],
                   -50,BIANNUAL.JUVENILES[j,2],
                   -50,BIANNUAL.JUVENILES[j,3],-50,BIANNUAL.JUVENILES[j,4],
                   -50,BIANNUAL.JUVENILES[j,5],
                   -50,BIANNUAL.JUVENILES[j,6],-50,BIANNUAL.JUVENILES[j,7],
                   -50,BIANNUAL.JUVENILES[j,8],
                   -50,BIANNUAL.JUVENILES[j,9],-50,BIANNUAL.JUVENILES[j,10],
                   -50,BIANNUAL.JUVENILES[j,11],-50,BIANNUAL.JUVENILES[j,12],
                   -50,BIANNUAL.JUVENILES[j,13],-50,BIANNUAL.JUVENILES[j,14],
                   -50,BIANNUAL.JUVENILES[j,15],-50,BIANNUAL.JUVENILES[j,16],
                   -50,BIANNUAL.JUVENILES[j,17],-50,BIANNUAL.JUVENILES[j,18],
                   -50,BIANNUAL.JUVENILES[j,19],-50,BIANNUAL.JUVENILES[j,20],
                   -50,BIANNUAL.JUVENILES[j,21],-50,BIANNUAL.JUVENILES[j,22],
                   -50,BIANNUAL.JUVENILES[j,23],-50,BIANNUAL.JUVENILES[j,24],
                   -50,BIANNUAL.JUVENILES[j,25],-50,BIANNUAL.JUVENILES[j,26],
                   -50,BIANNUAL.JUVENILES[j,27],-50,BIANNUAL.JUVENILES[j,28],
                   -50,BIANNUAL.JUVENILES[j,29])}
  for (j in 1:length(BIANNUAL.SUBADULTS[,1])){
    NzSHlong[j,]=c(-50,BIANNUAL.SUBADULTS[j,1],-50,BIANNUAL.SUBADULTS[j,2],
                   -50,BIANNUAL.SUBADULTS[j,3],-50,BIANNUAL.SUBADULTS[j,4],-50,BIANNUAL.SUBADULTS[j,5],
                   -50,BIANNUAL.SUBADULTS[j,6],-50,BIANNUAL.SUBADULTS[j,7],-50,BIANNUAL.SUBADULTS[j,8],
                   -50,BIANNUAL.SUBADULTS[j,9],-50,BIANNUAL.SUBADULTS[j,10],-50,BIANNUAL.SUBADULTS[j,11],
                   -50,BIANNUAL.SUBADULTS[j,12],-50,BIANNUAL.SUBADULTS[j,13],-50,BIANNUAL.SUBADULTS[j,14],
                   -50,BIANNUAL.SUBADULTS[j,15],-50,BIANNUAL.SUBADULTS[j,16],-50,BIANNUAL.SUBADULTS[j,17],
                   -50,BIANNUAL.SUBADULTS[j,18],-50,BIANNUAL.SUBADULTS[j,19],-50,BIANNUAL.SUBADULTS[j,20],
                   -50,BIANNUAL.SUBADULTS[j,21],-50,BIANNUAL.SUBADULTS[j,22],-50,BIANNUAL.SUBADULTS[j,23],
                   -50,BIANNUAL.SUBADULTS[j,24],-50,BIANNUAL.SUBADULTS[j,25],-50,BIANNUAL.SUBADULTS[j,26],
                   -50,BIANNUAL.SUBADULTS[j,27],-50,BIANNUAL.SUBADULTS[j,28],-50,BIANNUAL.SUBADULTS[j,29])}
  for (j in 1:length(BIANNUAL.ADULTS[,1])){
    NzAHlong[j,]=c(-50,BIANNUAL.ADULTS[j,1],
                   -50,BIANNUAL.ADULTS[j,2],
                   -50,BIANNUAL.ADULTS[j,3],-50,BIANNUAL.ADULTS[j,4],
                   -50,BIANNUAL.ADULTS[j,5],-50,BIANNUAL.ADULTS[j,6],
                   -50,BIANNUAL.ADULTS[j,7],-50,BIANNUAL.ADULTS[j,8],
                   -50,BIANNUAL.ADULTS[j,9],-50,BIANNUAL.ADULTS[j,10],
                   -50,BIANNUAL.ADULTS[j,11],-50,BIANNUAL.ADULTS[j,12],
                   -50,BIANNUAL.ADULTS[j,13],-50,BIANNUAL.ADULTS[j,14],
                   -50,BIANNUAL.ADULTS[j,15],-50,BIANNUAL.ADULTS[j,16],
                   -50,BIANNUAL.ADULTS[j,17],-50,BIANNUAL.ADULTS[j,18],
                   -50,BIANNUAL.ADULTS[j,19],-50,BIANNUAL.ADULTS[j,20],
                   -50,BIANNUAL.ADULTS[j,21],-50,BIANNUAL.ADULTS[j,22],
                   -50,BIANNUAL.ADULTS[j,23],-50,BIANNUAL.ADULTS[j,24],
                   -50,BIANNUAL.ADULTS[j,25],-50,BIANNUAL.ADULTS[j,26],
                   -50,BIANNUAL.ADULTS[j,27],-50,BIANNUAL.ADULTS[j,28],
                   -50,BIANNUAL.ADULTS[j,29])}
  for (j in 1:length(ANNUAL.SUBADULTS[,1])){
    NzSlong[j,]=c(ANNUAL.SUBADULTS[j,1],BIANNUAL.SUBADULTS[j,1],
                  ANNUAL.SUBADULTS[j,2],BIANNUAL.SUBADULTS[j,2],ANNUAL.SUBADULTS[j,3],BIANNUAL.SUBADULTS[j,3],
                  ANNUAL.SUBADULTS[j,4],BIANNUAL.SUBADULTS[j,4],ANNUAL.SUBADULTS[j,5],BIANNUAL.SUBADULTS[j,5],
                  ANNUAL.SUBADULTS[j,6],BIANNUAL.SUBADULTS[j,6],ANNUAL.SUBADULTS[j,7],BIANNUAL.SUBADULTS[j,7],
                  ANNUAL.SUBADULTS[j,8],BIANNUAL.SUBADULTS[j,8],ANNUAL.SUBADULTS[j,9],BIANNUAL.SUBADULTS[j,9],
                  ANNUAL.SUBADULTS[j,10],BIANNUAL.SUBADULTS[j,10],ANNUAL.SUBADULTS[j,11],BIANNUAL.SUBADULTS[j,11],
                  ANNUAL.SUBADULTS[j,12],BIANNUAL.SUBADULTS[j,12],ANNUAL.SUBADULTS[j,13],BIANNUAL.SUBADULTS[j,13],
                  ANNUAL.SUBADULTS[j,14],BIANNUAL.SUBADULTS[j,14],ANNUAL.SUBADULTS[j,15],BIANNUAL.SUBADULTS[j,15],
                  ANNUAL.SUBADULTS[j,16],BIANNUAL.SUBADULTS[j,16],ANNUAL.SUBADULTS[j,17],BIANNUAL.SUBADULTS[j,17],
                  ANNUAL.SUBADULTS[j,18],BIANNUAL.SUBADULTS[j,18],ANNUAL.SUBADULTS[j,19],BIANNUAL.SUBADULTS[j,19],
                  ANNUAL.SUBADULTS[j,20],BIANNUAL.SUBADULTS[j,20],ANNUAL.SUBADULTS[j,21],BIANNUAL.SUBADULTS[j,21],
                  ANNUAL.SUBADULTS[j,22],BIANNUAL.SUBADULTS[j,22],ANNUAL.SUBADULTS[j,23],BIANNUAL.SUBADULTS[j,23],
                  ANNUAL.SUBADULTS[j,24],BIANNUAL.SUBADULTS[j,24],ANNUAL.SUBADULTS[j,25],BIANNUAL.SUBADULTS[j,25],
                  ANNUAL.SUBADULTS[j,26],BIANNUAL.SUBADULTS[j,26],ANNUAL.SUBADULTS[j,27],BIANNUAL.SUBADULTS[j,27],
                  ANNUAL.SUBADULTS[j,28],BIANNUAL.SUBADULTS[j,28],ANNUAL.SUBADULTS[j,29],BIANNUAL.SUBADULTS[j,29])}
  for (j in 1:length(BIANNUAL.ADULTS[,1])){
    NzAlong[j,]=c(ANNUAL.ADULTS[j,1],BIANNUAL.ADULTS[j,1],
                  ANNUAL.ADULTS[j,2],BIANNUAL.ADULTS[j,2],ANNUAL.ADULTS[j,3],BIANNUAL.ADULTS[j,3],
                  ANNUAL.ADULTS[j,4],BIANNUAL.ADULTS[j,4],ANNUAL.ADULTS[j,5],BIANNUAL.ADULTS[j,5],
                  ANNUAL.ADULTS[j,6],BIANNUAL.ADULTS[j,6],ANNUAL.ADULTS[j,7],BIANNUAL.ADULTS[j,7],
                  ANNUAL.ADULTS[j,8],BIANNUAL.ADULTS[j,8],ANNUAL.ADULTS[j,9],BIANNUAL.ADULTS[j,9],
                  ANNUAL.ADULTS[j,10],BIANNUAL.ADULTS[j,10],ANNUAL.ADULTS[j,11],BIANNUAL.ADULTS[j,11],
                  ANNUAL.ADULTS[j,12],BIANNUAL.ADULTS[j,12],ANNUAL.ADULTS[j,13],BIANNUAL.ADULTS[j,13],
                  ANNUAL.ADULTS[j,14],BIANNUAL.ADULTS[j,14],ANNUAL.ADULTS[j,15],BIANNUAL.ADULTS[j,15],
                  ANNUAL.ADULTS[j,16],BIANNUAL.ADULTS[j,16],ANNUAL.ADULTS[j,17],BIANNUAL.ADULTS[j,17],
                  ANNUAL.ADULTS[j,18],BIANNUAL.ADULTS[j,18],ANNUAL.ADULTS[j,19],BIANNUAL.ADULTS[j,19],
                  ANNUAL.ADULTS[j,20],BIANNUAL.ADULTS[j,20],ANNUAL.ADULTS[j,21],BIANNUAL.ADULTS[j,21],
                  ANNUAL.ADULTS[j,22],BIANNUAL.ADULTS[j,22],ANNUAL.ADULTS[j,23],BIANNUAL.ADULTS[j,23],
                  ANNUAL.ADULTS[j,24],BIANNUAL.ADULTS[j,24],ANNUAL.ADULTS[j,25],BIANNUAL.ADULTS[j,25],
                  ANNUAL.ADULTS[j,26],BIANNUAL.ADULTS[j,26],ANNUAL.ADULTS[j,27],BIANNUAL.ADULTS[j,27],
                  ANNUAL.ADULTS[j,28],BIANNUAL.ADULTS[j,28],ANNUAL.ADULTS[j,29],BIANNUAL.ADULTS[j,29])}
  NzMeanS=numeric(58)
  NzMeanS=c(NzMean[1,1],-5000,NzMean[1,2],-5000,NzMean[1,3],
            -5000,NzMean[1,4],-5000,NzMean[1,5],-5000,NzMean[1,6],
            -5000,NzMean[1,7],-5000,NzMean[1,8],-5000,NzMean[1,9],
            -5000,NzMean[1,10],-5000,NzMean[1,11],-5000,NzMean[1,12],
            -5000,NzMean[1,13],-5000,NzMean[1,14],-5000,NzMean[1,15],
            -5000,NzMean[1,16],-5000,NzMean[1,17],-5000,NzMean[1,18],
            -5000,NzMean[1,19],-5000,NzMean[1,20],-5000,NzMean[1,21],
            -5000,NzMean[1,22],-5000,NzMean[1,23],-5000,NzMean[1,24],
            -5000,NzMean[1,25],-5000,NzMean[1,26],-5000,NzMean[1,27],
            -5000,NzMean[1,28],-5000,NzMean[1,29],-5000)
  hsBOOT.UPPER.SUB=numeric(58);hsBOOT.LOWER.SUB=numeric(58);
  hhsBOOT.UPPER.SUB=numeric(58);hhsBOOT.LOWER.SUB=numeric(58);
  for (w in 1:58){
    VectorS=sort(NzSlong[,w])
    Index=1
    hsBOOT.UPPER.SUB[w]=VectorS[(length(NzSlong[,w]))]
    hsBOOT.LOWER.SUB[w]=VectorS[Index]
    VectorSH=sort(NzSHlong[,w])
    hhsBOOT.UPPER.SUB[w]=VectorSH[(length(NzSHlong[,w]))]
    hsBOOT.LOWER.SUB[w]=VectorSH[Index]}
  for (b in 1:58){if (hsBOOT.UPPER.SUB[b]<0){hsBOOT.UPPER.SUB[b]=0}}
  for (b in 1:58){if (hsBOOT.LOWER.SUB[b]<0){hsBOOT.LOWER.SUB[b]=0}}
  for (b in 1:58){if (hhsBOOT.UPPER.SUB[b]<0){hhsBOOT.UPPER.SUB[b]=0}}
  for (b in 1:58){if (hhsBOOT.LOWER.SUB[b]<0){hhsBOOT.LOWER.SUB[b]=0}}
  plot(1.2:58.2,NzMeanS,type="p",xlim=c(1,58),
       ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
       ylim=c(0,max(max(hhsBOOT.UPPER.SUB),max(hsBOOT.UPPER.SUB))),
       col="skyblue",lwd=1,lty=3,pch=20,
       main="Algorithm-predicted female abundances for the mock trajectory",xaxt="n")
  year=seq(1990,2018,1)
  axis(1,at=seq(1,57,2), labels=year)
  segments(2.2,hhsBOOT.LOWER.SUB[2],2.2,hhsBOOT.UPPER.SUB[2],lwd=3,col="skyblue")
  segments(4.2,hhsBOOT.LOWER.SUB[4],4.2,hhsBOOT.UPPER.SUB[4],lwd=3,col="skyblue")
  segments(6.2,hhsBOOT.LOWER.SUB[6],6.2,hhsBOOT.UPPER.SUB[6],lwd=3,col="skyblue")
  segments(8.2,hhsBOOT.LOWER.SUB[8],8.2,hhsBOOT.UPPER.SUB[8],lwd=3,col="skyblue")
  segments(10.2,hhsBOOT.LOWER.SUB[10],10.2,hhsBOOT.UPPER.SUB[10],lwd=3,col="skyblue")
  segments(12.2,hhsBOOT.LOWER.SUB[12],12.2,hhsBOOT.UPPER.SUB[12],lwd=3,col="skyblue")
  segments(14.2,hhsBOOT.LOWER.SUB[14],14.2,hhsBOOT.UPPER.SUB[14],lwd=3,col="skyblue")
  segments(16.2,hhsBOOT.LOWER.SUB[16],16.2,hhsBOOT.UPPER.SUB[16],lwd=3,col="skyblue")
  segments(18.2,hhsBOOT.LOWER.SUB[18],18.2,hhsBOOT.UPPER.SUB[18],lwd=3,col="skyblue")
  segments(20.2,hhsBOOT.LOWER.SUB[20],20.2,hhsBOOT.UPPER.SUB[20],lwd=3,col="skyblue")
  segments(22.2,hhsBOOT.LOWER.SUB[22],22.2,hhsBOOT.UPPER.SUB[22],lwd=3,col="skyblue")
  segments(24.2,hhsBOOT.LOWER.SUB[24],24.2,hhsBOOT.UPPER.SUB[24],lwd=3,col="skyblue")
  segments(26.2,hhsBOOT.LOWER.SUB[26],26.2,hhsBOOT.UPPER.SUB[26],lwd=3,col="skyblue")
  segments(28.2,hhsBOOT.LOWER.SUB[28],28.2,hhsBOOT.UPPER.SUB[28],lwd=3,col="skyblue")
  segments(30.2,hhsBOOT.LOWER.SUB[30],30.2,hhsBOOT.UPPER.SUB[30],lwd=3,col="skyblue")
  segments(32.2,hhsBOOT.LOWER.SUB[32],32.2,hhsBOOT.UPPER.SUB[32],lwd=3,col="skyblue")
  segments(34.2,hhsBOOT.LOWER.SUB[34],34.2,hhsBOOT.UPPER.SUB[34],lwd=3,col="skyblue")
  segments(36.2,hhsBOOT.LOWER.SUB[36],36.2,hhsBOOT.UPPER.SUB[36],lwd=3,col="skyblue")
  segments(38.2,hhsBOOT.LOWER.SUB[38],38.2,hhsBOOT.UPPER.SUB[38],lwd=3,col="skyblue")
  segments(40.2,hhsBOOT.LOWER.SUB[40],40.2,hhsBOOT.UPPER.SUB[40],lwd=3,col="skyblue")
  segments(42.2,hhsBOOT.LOWER.SUB[42],42.2,hhsBOOT.UPPER.SUB[42],lwd=3,col="skyblue")
  segments(44.2,hhsBOOT.LOWER.SUB[44],44.2,hhsBOOT.UPPER.SUB[44],lwd=3,col="skyblue")
  segments(46.2,hhsBOOT.LOWER.SUB[46],46.2,hhsBOOT.UPPER.SUB[46],lwd=3,col="skyblue")
  segments(48.2,hhsBOOT.LOWER.SUB[48],48.2,hhsBOOT.UPPER.SUB[48],lwd=3,col="skyblue")
  segments(50.2,hhsBOOT.LOWER.SUB[50],50.2,hhsBOOT.UPPER.SUB[50],lwd=3,col="skyblue")
  segments(52.2,hhsBOOT.LOWER.SUB[52],52.2,hhsBOOT.UPPER.SUB[52],lwd=3,col="skyblue")
  segments(54.2,hhsBOOT.LOWER.SUB[54],54.2,hhsBOOT.UPPER.SUB[54],lwd=3,col="skyblue")
  segments(56.2,hhsBOOT.LOWER.SUB[56],56.2,hhsBOOT.UPPER.SUB[56],lwd=3,col="skyblue")
  segments(58.2,hhsBOOT.LOWER.SUB[58],58.2,hhsBOOT.UPPER.SUB[58],lwd=3,col="skyblue")
  segments(1.2,hsBOOT.LOWER.SUB[1],1.2,hsBOOT.UPPER.SUB[1],lwd=3,col="skyblue")
  segments(3.2,hsBOOT.LOWER.SUB[3],3.2,hsBOOT.UPPER.SUB[3],lwd=3,col="skyblue")
  segments(5.2,hsBOOT.LOWER.SUB[5],5.2,hsBOOT.UPPER.SUB[5],lwd=3,col="skyblue")
  segments(7.2,hsBOOT.LOWER.SUB[7],7.2,hsBOOT.UPPER.SUB[7],lwd=3,col="skyblue")
  segments(9.2,hsBOOT.LOWER.SUB[9],9.2,hsBOOT.UPPER.SUB[9],lwd=3,col="skyblue")
  segments(11.2,hsBOOT.LOWER.SUB[11],11.2,hsBOOT.UPPER.SUB[11],lwd=3,col="skyblue")
  segments(13.2,hsBOOT.LOWER.SUB[13],13.2,hsBOOT.UPPER.SUB[13],lwd=3,col="skyblue")
  segments(15.2,hsBOOT.LOWER.SUB[15],15.2,hsBOOT.UPPER.SUB[15],lwd=3,col="skyblue")
  segments(17.2,hsBOOT.LOWER.SUB[17],17.2,hsBOOT.UPPER.SUB[17],lwd=3,col="skyblue")
  segments(19.2,hsBOOT.LOWER.SUB[19],19.2,hsBOOT.UPPER.SUB[19],lwd=3,col="skyblue")
  segments(21.2,hsBOOT.LOWER.SUB[21],21.2,hsBOOT.UPPER.SUB[21],lwd=3,col="skyblue")
  segments(23.2,hsBOOT.LOWER.SUB[23],23.2,hsBOOT.UPPER.SUB[23],lwd=3,col="skyblue")
  segments(25.2,hsBOOT.LOWER.SUB[25],25.2,hsBOOT.UPPER.SUB[25],lwd=3,col="skyblue")
  segments(27.2,hsBOOT.LOWER.SUB[27],27.2,hsBOOT.UPPER.SUB[27],lwd=3,col="skyblue")
  segments(29.2,hsBOOT.LOWER.SUB[29],29.2,hsBOOT.UPPER.SUB[29],lwd=3,col="skyblue")
  segments(31.2,hsBOOT.LOWER.SUB[31],31.2,hsBOOT.UPPER.SUB[31],lwd=3,col="skyblue")
  segments(33.2,hsBOOT.LOWER.SUB[33],33.2,hsBOOT.UPPER.SUB[33],lwd=3,col="skyblue")
  segments(35.2,hsBOOT.LOWER.SUB[35],35.2,hsBOOT.UPPER.SUB[35],lwd=3,col="skyblue")
  segments(37.2,hsBOOT.LOWER.SUB[37],37.2,hsBOOT.UPPER.SUB[37],lwd=3,col="skyblue")
  segments(39.2,hsBOOT.LOWER.SUB[39],39.2,hsBOOT.UPPER.SUB[39],lwd=3,col="skyblue")
  segments(41.2,hsBOOT.LOWER.SUB[41],41.2,hsBOOT.UPPER.SUB[41],lwd=3,col="skyblue")
  segments(43.2,hsBOOT.LOWER.SUB[43],43.2,hsBOOT.UPPER.SUB[43],lwd=3,col="skyblue")
  segments(45.2,hsBOOT.LOWER.SUB[45],45.2,hsBOOT.UPPER.SUB[45],lwd=3,col="skyblue")
  segments(47.2,hsBOOT.LOWER.SUB[47],47.2,hsBOOT.UPPER.SUB[47],lwd=3,col="skyblue")
  segments(49.2,hsBOOT.LOWER.SUB[49],49.2,hsBOOT.UPPER.SUB[49],lwd=3,col="skyblue")
  segments(51.2,hsBOOT.LOWER.SUB[51],51.2,hsBOOT.UPPER.SUB[51],lwd=3,col="skyblue")
  segments(53.2,hsBOOT.LOWER.SUB[53],53.2,hsBOOT.UPPER.SUB[53],lwd=3,col="skyblue")
  segments(55.2,hsBOOT.LOWER.SUB[55],55.2,hsBOOT.UPPER.SUB[55],lwd=3,col="skyblue")
  segments(57.2,hsBOOT.LOWER.SUB[57],57.2,hsBOOT.UPPER.SUB[57],lwd=3,col="skyblue")
  points(1.2:58.2, ELONGATEDTIMESERIES,col="blue",pch=19)
  legend(0,max(max(hhsBOOT.UPPER.SUB),max(hsBOOT.UPPER.SUB)),
         c("Mock immature females throughout the year", 
           "Algorithm-predicted range for immature and non-breeding adult females throughout the year"),
         box.lty = 0,lty=c(1,1),lwd=c(3,3),pch=c(19,20),col=c("blue","skyblue"))

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# BI-ANNUAL ADULT
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TIMESERIES.1=read.table("NEW_TIMESERIES_Northeast.txt")
  TIMESERIES=TIMESERIES.1[["x"]]
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_ADULTS_JUNE=read.table("NEW_Adults_June_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JUNE=read.table("NEW_Subadults_June_Northeast.txt")
  TRAJECTORY_JUVENILES_JUNE=read.table("NEW_Juveniles_June_Northeast.txt")
  NzSlong=matrix(0,length(MODELS[,1]),58)
  NzAlong=matrix(0,length(MODELS[,1]),58)
  NzJHlong=matrix(0,length(MODELS[,1]),58)
  NzSHlong=matrix(0,length(MODELS[,1]),58)
  NzAHlong=matrix(0,length(MODELS[,1]),58)
  ANNUAL.ADULTS=TRAJECTORY_ADULTS_JAN
  ANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JAN
  BIANNUAL.JUVENILES=TRAJECTORY_JUVENILES_JUNE
  BIANNUAL.SUBADULTS=TRAJECTORY_SUBADULTS_JUNE
  BIANNUAL.ADULTS=TRAJECTORY_ADULTS_JUNE
  NzMeanH=matrix(0,3,29)		
  NzVarH=matrix(0,3,29)
  NzMean=matrix(0,2,29)		
  NzVar=matrix(0,2,29)
  for (k in 1:29){
    NzMean[1,k]=mean(ANNUAL.SUBADULTS[,k])
    NzMean[2,k]=mean(ANNUAL.ADULTS[,k])
    NzVar[1,k]=var(ANNUAL.SUBADULTS[,k])
    NzVar[2,k]=var(ANNUAL.ADULTS[,k])
    NzMeanH[1,k]=mean(BIANNUAL.JUVENILES[,k])
    NzMeanH[2,k]=mean(BIANNUAL.SUBADULTS[,k])
    NzMeanH[3,k]=mean(BIANNUAL.ADULTS[,k])
    NzVarH[1,k]=var(BIANNUAL.JUVENILES[,k])
    NzVarH[2,k]=var(BIANNUAL.SUBADULTS[,k])
    NzVarH[3,k]=var(BIANNUAL.ADULTS[,k])
  } # END AT EACH TIME LOOP [k]
  NzMeanA=numeric(58)
  NzMeanA=c(NzMean[2,1],-5000,NzMean[2,2],-5000,NzMean[2,3],
            -5000,NzMean[2,4],-5000,NzMean[2,5],-5000,NzMean[2,6],
            -5000,NzMean[2,7],-5000,NzMean[2,8],-5000,NzMean[2,9],
            -5000,NzMean[2,10],-5000,NzMean[2,11],-5000,NzMean[2,12],
            -5000,NzMean[2,13],-5000,NzMean[2,14],-5000,NzMean[2,15],
            -5000,NzMean[2,16],-5000,NzMean[2,17],-5000,NzMean[2,18],
            -5000,NzMean[2,19],-5000,NzMean[2,20],-5000,NzMean[2,21],
            -5000,NzMean[2,22],-5000,NzMean[2,23],-5000,NzMean[2,24],
            -5000,NzMean[2,25],-5000,NzMean[2,26],-5000,NzMean[2,27],
            -5000,NzMean[2,28],-5000,NzMean[2,29],-5000)
  for (j in 1:length(BIANNUAL.JUVENILES[,1])){
    NzJHlong[j,]=c(-50,BIANNUAL.JUVENILES[j,1],
                   -50,BIANNUAL.JUVENILES[j,2],
                   -50,BIANNUAL.JUVENILES[j,3],-50,BIANNUAL.JUVENILES[j,4],
                   -50,BIANNUAL.JUVENILES[j,5],
                   -50,BIANNUAL.JUVENILES[j,6],-50,BIANNUAL.JUVENILES[j,7],
                   -50,BIANNUAL.JUVENILES[j,8],
                   -50,BIANNUAL.JUVENILES[j,9],-50,BIANNUAL.JUVENILES[j,10],
                   -50,BIANNUAL.JUVENILES[j,11],-50,BIANNUAL.JUVENILES[j,12],
                   -50,BIANNUAL.JUVENILES[j,13],-50,BIANNUAL.JUVENILES[j,14],
                   -50,BIANNUAL.JUVENILES[j,15],-50,BIANNUAL.JUVENILES[j,16],
                   -50,BIANNUAL.JUVENILES[j,17],-50,BIANNUAL.JUVENILES[j,18],
                   -50,BIANNUAL.JUVENILES[j,19],-50,BIANNUAL.JUVENILES[j,20],
                   -50,BIANNUAL.JUVENILES[j,21],-50,BIANNUAL.JUVENILES[j,22],
                   -50,BIANNUAL.JUVENILES[j,23],-50,BIANNUAL.JUVENILES[j,24],
                   -50,BIANNUAL.JUVENILES[j,25],-50,BIANNUAL.JUVENILES[j,26],
                   -50,BIANNUAL.JUVENILES[j,27],-50,BIANNUAL.JUVENILES[j,28],
                   -50,BIANNUAL.JUVENILES[j,29])}
  for (j in 1:length(BIANNUAL.SUBADULTS[,1])){
    NzSHlong[j,]=c(-50,BIANNUAL.SUBADULTS[j,1],-50,BIANNUAL.SUBADULTS[j,2],
                   -50,BIANNUAL.SUBADULTS[j,3],-50,BIANNUAL.SUBADULTS[j,4],-50,BIANNUAL.SUBADULTS[j,5],
                   -50,BIANNUAL.SUBADULTS[j,6],-50,BIANNUAL.SUBADULTS[j,7],-50,BIANNUAL.SUBADULTS[j,8],
                   -50,BIANNUAL.SUBADULTS[j,9],-50,BIANNUAL.SUBADULTS[j,10],-50,BIANNUAL.SUBADULTS[j,11],
                   -50,BIANNUAL.SUBADULTS[j,12],-50,BIANNUAL.SUBADULTS[j,13],-50,BIANNUAL.SUBADULTS[j,14],
                   -50,BIANNUAL.SUBADULTS[j,15],-50,BIANNUAL.SUBADULTS[j,16],-50,BIANNUAL.SUBADULTS[j,17],
                   -50,BIANNUAL.SUBADULTS[j,18],-50,BIANNUAL.SUBADULTS[j,19],-50,BIANNUAL.SUBADULTS[j,20],
                   -50,BIANNUAL.SUBADULTS[j,21],-50,BIANNUAL.SUBADULTS[j,22],-50,BIANNUAL.SUBADULTS[j,23],
                   -50,BIANNUAL.SUBADULTS[j,24],-50,BIANNUAL.SUBADULTS[j,25],-50,BIANNUAL.SUBADULTS[j,26],
                   -50,BIANNUAL.SUBADULTS[j,27],-50,BIANNUAL.SUBADULTS[j,28],-50,BIANNUAL.SUBADULTS[j,29])}
  for (j in 1:length(BIANNUAL.ADULTS[,1])){
    NzAHlong[j,]=c(-50,BIANNUAL.ADULTS[j,1],
                   -50,BIANNUAL.ADULTS[j,2],
                   -50,BIANNUAL.ADULTS[j,3],-50,BIANNUAL.ADULTS[j,4],
                   -50,BIANNUAL.ADULTS[j,5],-50,BIANNUAL.ADULTS[j,6],
                   -50,BIANNUAL.ADULTS[j,7],-50,BIANNUAL.ADULTS[j,8],
                   -50,BIANNUAL.ADULTS[j,9],-50,BIANNUAL.ADULTS[j,10],
                   -50,BIANNUAL.ADULTS[j,11],-50,BIANNUAL.ADULTS[j,12],
                   -50,BIANNUAL.ADULTS[j,13],-50,BIANNUAL.ADULTS[j,14],
                   -50,BIANNUAL.ADULTS[j,15],-50,BIANNUAL.ADULTS[j,16],
                   -50,BIANNUAL.ADULTS[j,17],-50,BIANNUAL.ADULTS[j,18],
                   -50,BIANNUAL.ADULTS[j,19],-50,BIANNUAL.ADULTS[j,20],
                   -50,BIANNUAL.ADULTS[j,21],-50,BIANNUAL.ADULTS[j,22],
                   -50,BIANNUAL.ADULTS[j,23],-50,BIANNUAL.ADULTS[j,24],
                   -50,BIANNUAL.ADULTS[j,25],-50,BIANNUAL.ADULTS[j,26],
                   -50,BIANNUAL.ADULTS[j,27],-50,BIANNUAL.ADULTS[j,28],
                   -50,BIANNUAL.ADULTS[j,29])}
  for (j in 1:length(ANNUAL.SUBADULTS[,1])){
    NzSlong[j,]=c(ANNUAL.SUBADULTS[j,1],BIANNUAL.SUBADULTS[j,1],
                  ANNUAL.SUBADULTS[j,2],BIANNUAL.SUBADULTS[j,2],ANNUAL.SUBADULTS[j,3],BIANNUAL.SUBADULTS[j,3],
                  ANNUAL.SUBADULTS[j,4],BIANNUAL.SUBADULTS[j,4],ANNUAL.SUBADULTS[j,5],BIANNUAL.SUBADULTS[j,5],
                  ANNUAL.SUBADULTS[j,6],BIANNUAL.SUBADULTS[j,6],ANNUAL.SUBADULTS[j,7],BIANNUAL.SUBADULTS[j,7],
                  ANNUAL.SUBADULTS[j,8],BIANNUAL.SUBADULTS[j,8],ANNUAL.SUBADULTS[j,9],BIANNUAL.SUBADULTS[j,9],
                  ANNUAL.SUBADULTS[j,10],BIANNUAL.SUBADULTS[j,10],ANNUAL.SUBADULTS[j,11],BIANNUAL.SUBADULTS[j,11],
                  ANNUAL.SUBADULTS[j,12],BIANNUAL.SUBADULTS[j,12],ANNUAL.SUBADULTS[j,13],BIANNUAL.SUBADULTS[j,13],
                  ANNUAL.SUBADULTS[j,14],BIANNUAL.SUBADULTS[j,14],ANNUAL.SUBADULTS[j,15],BIANNUAL.SUBADULTS[j,15],
                  ANNUAL.SUBADULTS[j,16],BIANNUAL.SUBADULTS[j,16],ANNUAL.SUBADULTS[j,17],BIANNUAL.SUBADULTS[j,17],
                  ANNUAL.SUBADULTS[j,18],BIANNUAL.SUBADULTS[j,18],ANNUAL.SUBADULTS[j,19],BIANNUAL.SUBADULTS[j,19],
                  ANNUAL.SUBADULTS[j,20],BIANNUAL.SUBADULTS[j,20],ANNUAL.SUBADULTS[j,21],BIANNUAL.SUBADULTS[j,21],
                  ANNUAL.SUBADULTS[j,22],BIANNUAL.SUBADULTS[j,22],ANNUAL.SUBADULTS[j,23],BIANNUAL.SUBADULTS[j,23],
                  ANNUAL.SUBADULTS[j,24],BIANNUAL.SUBADULTS[j,24],ANNUAL.SUBADULTS[j,25],BIANNUAL.SUBADULTS[j,25],
                  ANNUAL.SUBADULTS[j,26],BIANNUAL.SUBADULTS[j,26],ANNUAL.SUBADULTS[j,27],BIANNUAL.SUBADULTS[j,27],
                  ANNUAL.SUBADULTS[j,28],BIANNUAL.SUBADULTS[j,28],ANNUAL.SUBADULTS[j,29],BIANNUAL.SUBADULTS[j,29])}
  for (j in 1:length(BIANNUAL.ADULTS[,1])){
    NzAlong[j,]=c(ANNUAL.ADULTS[j,1],BIANNUAL.ADULTS[j,1],
                  ANNUAL.ADULTS[j,2],BIANNUAL.ADULTS[j,2],ANNUAL.ADULTS[j,3],BIANNUAL.ADULTS[j,3],
                  ANNUAL.ADULTS[j,4],BIANNUAL.ADULTS[j,4],ANNUAL.ADULTS[j,5],BIANNUAL.ADULTS[j,5],
                  ANNUAL.ADULTS[j,6],BIANNUAL.ADULTS[j,6],ANNUAL.ADULTS[j,7],BIANNUAL.ADULTS[j,7],
                  ANNUAL.ADULTS[j,8],BIANNUAL.ADULTS[j,8],ANNUAL.ADULTS[j,9],BIANNUAL.ADULTS[j,9],
                  ANNUAL.ADULTS[j,10],BIANNUAL.ADULTS[j,10],ANNUAL.ADULTS[j,11],BIANNUAL.ADULTS[j,11],
                  ANNUAL.ADULTS[j,12],BIANNUAL.ADULTS[j,12],ANNUAL.ADULTS[j,13],BIANNUAL.ADULTS[j,13],
                  ANNUAL.ADULTS[j,14],BIANNUAL.ADULTS[j,14],ANNUAL.ADULTS[j,15],BIANNUAL.ADULTS[j,15],
                  ANNUAL.ADULTS[j,16],BIANNUAL.ADULTS[j,16],ANNUAL.ADULTS[j,17],BIANNUAL.ADULTS[j,17],
                  ANNUAL.ADULTS[j,18],BIANNUAL.ADULTS[j,18],ANNUAL.ADULTS[j,19],BIANNUAL.ADULTS[j,19],
                  ANNUAL.ADULTS[j,20],BIANNUAL.ADULTS[j,20],ANNUAL.ADULTS[j,21],BIANNUAL.ADULTS[j,21],
                  ANNUAL.ADULTS[j,22],BIANNUAL.ADULTS[j,22],ANNUAL.ADULTS[j,23],BIANNUAL.ADULTS[j,23],
                  ANNUAL.ADULTS[j,24],BIANNUAL.ADULTS[j,24],ANNUAL.ADULTS[j,25],BIANNUAL.ADULTS[j,25],
                  ANNUAL.ADULTS[j,26],BIANNUAL.ADULTS[j,26],ANNUAL.ADULTS[j,27],BIANNUAL.ADULTS[j,27],
                  ANNUAL.ADULTS[j,28],BIANNUAL.ADULTS[j,28],ANNUAL.ADULTS[j,29],BIANNUAL.ADULTS[j,29])}
  ELONGATEDTIMESERIES=numeric(58)
  ELONGATEDTIMESERIES[1]=TIMESERIES[1]
  loop=1
  for (u in 2:58){
    if (u%%2==0){
      ELONGATEDTIMESERIES[u]=ADULTS_JUNE.EXACT[loop]}
    if (u%%2!=0){
      loop=loop+1
      ELONGATEDTIMESERIES[u]=TIMESERIES[loop]}}

  hsBOOT.UPPER.AD=numeric(58);hsBOOT.LOWER.AD=numeric(58);
  hhsBOOT.UPPER.AD=numeric(58);hhsBOOT.LOWER.AD=numeric(58);
  for (w in 1:58){
    VectorA=sort(NzAlong[,w])
    Index=1
    hsBOOT.UPPER.AD[w]=VectorA[(length(NzAlong[,w]))]
    hsBOOT.LOWER.AD[w]=VectorA[Index]
    VectorAH=sort(NzAHlong[,w])
    hhsBOOT.UPPER.AD[w]=VectorAH[(length(NzAHlong[,w]))]
    hhsBOOT.LOWER.AD[w]=VectorAH[Index]}
  for (b in 1:58){if (hsBOOT.UPPER.AD[b]==-50){hsBOOT.UPPER.AD[b]=0}}
  for (b in 1:58){if (hsBOOT.LOWER.AD[b]<0){hsBOOT.LOWER.AD[b]=0}}
  for (b in 1:58){if (hhsBOOT.UPPER.AD[b]==-50){hhsBOOT.UPPER.AD[b]=0}}
  for (b in 1:58){if (hhsBOOT.LOWER.AD[b]<0){hhsBOOT.LOWER.AD[b]=0}}
  plot(1:58,NzMeanA,type="p",xlim=c(1,58),
       ylab="Algorithm-predicted abundances",xlab="Bi-annual periods",
       ylim=c(0,max(max(hhsBOOT.UPPER.AD),max(hsBOOT.UPPER.AD))),
       col="grey",lwd=1,lty=3,pch=20,
       main="Algorithm-predicted female abundances for the mock trajectory",xaxt="n")
  year=seq(1990,2018,1)
  axis(1,at=seq(1,57,2), labels=year)
  segments(2,hhsBOOT.LOWER.AD[2],2,hhsBOOT.UPPER.AD[2],lwd=3,col="GREY")
  segments(4,hhsBOOT.LOWER.AD[4],4,hhsBOOT.UPPER.AD[4],lwd=3,col="GREY")
  segments(6,hhsBOOT.LOWER.AD[6],6,hhsBOOT.UPPER.AD[6],lwd=3,col="GREY")
  segments(8,hhsBOOT.LOWER.AD[8],8,hhsBOOT.UPPER.AD[8],lwd=3,col="GREY")
  segments(10,hhsBOOT.LOWER.AD[10],10,hhsBOOT.UPPER.AD[10],lwd=3,col="GREY")
  segments(12,hhsBOOT.LOWER.AD[12],12,hhsBOOT.UPPER.AD[12],lwd=3,col="GREY")
  segments(14,hhsBOOT.LOWER.AD[14],14,hhsBOOT.UPPER.AD[14],lwd=3,col="GREY")
  segments(16,hhsBOOT.LOWER.AD[16],16,hhsBOOT.UPPER.AD[16],lwd=3,col="GREY")
  segments(18,hhsBOOT.LOWER.AD[18],18,hhsBOOT.UPPER.AD[18],lwd=3,col="GREY")
  segments(20,hhsBOOT.LOWER.AD[20],20,hhsBOOT.UPPER.AD[20],lwd=3,col="GREY")
  segments(22,hhsBOOT.LOWER.AD[22],22,hhsBOOT.UPPER.AD[22],lwd=3,col="GREY")
  segments(24,hhsBOOT.LOWER.AD[24],24,hhsBOOT.UPPER.AD[24],lwd=3,col="GREY")
  segments(26,hhsBOOT.LOWER.AD[26],26,hhsBOOT.UPPER.AD[26],lwd=3,col="GREY")
  segments(28,hhsBOOT.LOWER.AD[28],28,hhsBOOT.UPPER.AD[28],lwd=3,col="GREY")
  segments(30,hhsBOOT.LOWER.AD[30],30,hhsBOOT.UPPER.AD[30],lwd=3,col="GREY")
  segments(32,hhsBOOT.LOWER.AD[32],32,hhsBOOT.UPPER.AD[32],lwd=3,col="GREY")
  segments(34,hhsBOOT.LOWER.AD[34],34,hhsBOOT.UPPER.AD[34],lwd=3,col="GREY")
  segments(36,hhsBOOT.LOWER.AD[36],36,hhsBOOT.UPPER.AD[36],lwd=3,col="GREY")
  segments(38,hhsBOOT.LOWER.AD[38],38,hhsBOOT.UPPER.AD[38],lwd=3,col="GREY")
  segments(40,hhsBOOT.LOWER.AD[40],40,hhsBOOT.UPPER.AD[40],lwd=3,col="GREY")
  segments(42,hhsBOOT.LOWER.AD[42],42,hhsBOOT.UPPER.AD[42],lwd=3,col="GREY")
  segments(44,hhsBOOT.LOWER.AD[44],44,hhsBOOT.UPPER.AD[44],lwd=3,col="GREY")
  segments(46,hhsBOOT.LOWER.AD[46],46,hhsBOOT.UPPER.AD[46],lwd=3,col="GREY")
  segments(48,hhsBOOT.LOWER.AD[48],48,hhsBOOT.UPPER.AD[48],lwd=3,col="GREY")
  segments(50,hhsBOOT.LOWER.AD[50],50,hhsBOOT.UPPER.AD[50],lwd=3,col="GREY")
  segments(52,hhsBOOT.LOWER.AD[52],52,hhsBOOT.UPPER.AD[52],lwd=3,col="GREY")
  segments(54,hhsBOOT.LOWER.AD[54],54,hhsBOOT.UPPER.AD[54],lwd=3,col="GREY")
  segments(56,hhsBOOT.LOWER.AD[56],56,hhsBOOT.UPPER.AD[56],lwd=3,col="GREY")
  segments(58,hhsBOOT.LOWER.AD[58],58,hhsBOOT.UPPER.AD[58],lwd=3,col="GREY")
  segments(1,hsBOOT.LOWER.AD[1],1,hsBOOT.UPPER.AD[1],lwd=3,col="GREY")
  segments(3,hsBOOT.LOWER.AD[3],3,hsBOOT.UPPER.AD[3],lwd=3,col="GREY")
  segments(5,hsBOOT.LOWER.AD[5],5,hsBOOT.UPPER.AD[5],lwd=3,col="GREY")
  segments(7,hsBOOT.LOWER.AD[7],7,hsBOOT.UPPER.AD[7],lwd=3,col="GREY")
  segments(9,hsBOOT.LOWER.AD[9],9,hsBOOT.UPPER.AD[9],lwd=3,col="GREY")
  segments(11,hsBOOT.LOWER.AD[11],11,hsBOOT.UPPER.AD[11],lwd=3,col="GREY")
  segments(13,hsBOOT.LOWER.AD[13],13,hsBOOT.UPPER.AD[13],lwd=3,col="GREY")
  segments(15,hsBOOT.LOWER.AD[15],15,hsBOOT.UPPER.AD[15],lwd=3,col="GREY")
  segments(17,hsBOOT.LOWER.AD[17],17,hsBOOT.UPPER.AD[17],lwd=3,col="GREY")
  segments(19,hsBOOT.LOWER.AD[19],19,hsBOOT.UPPER.AD[19],lwd=3,col="GREY")
  segments(21,hsBOOT.LOWER.AD[21],21,hsBOOT.UPPER.AD[21],lwd=3,col="GREY")
  segments(23,hsBOOT.LOWER.AD[23],23,hsBOOT.UPPER.AD[23],lwd=3,col="GREY")
  segments(25,hsBOOT.LOWER.AD[25],25,hsBOOT.UPPER.AD[25],lwd=3,col="GREY")
  segments(27,hsBOOT.LOWER.AD[27],27,hsBOOT.UPPER.AD[27],lwd=3,col="GREY")
  segments(29,hsBOOT.LOWER.AD[29],29,hsBOOT.UPPER.AD[29],lwd=3,col="GREY")
  segments(31,hsBOOT.LOWER.AD[31],31,hsBOOT.UPPER.AD[31],lwd=3,col="GREY")
  segments(33,hsBOOT.LOWER.AD[33],33,hsBOOT.UPPER.AD[33],lwd=3,col="GREY")
  segments(35,hsBOOT.LOWER.AD[35],35,hsBOOT.UPPER.AD[35],lwd=3,col="GREY")
  segments(37,hsBOOT.LOWER.AD[37],37,hsBOOT.UPPER.AD[37],lwd=3,col="GREY")
  segments(39,hsBOOT.LOWER.AD[39],39,hsBOOT.UPPER.AD[39],lwd=3,col="GREY")
  segments(41,hsBOOT.LOWER.AD[41],41,hsBOOT.UPPER.AD[41],lwd=3,col="GREY")
  segments(43,hsBOOT.LOWER.AD[43],43,hsBOOT.UPPER.AD[43],lwd=3,col="GREY")
  segments(45,hsBOOT.LOWER.AD[45],45,hsBOOT.UPPER.AD[45],lwd=3,col="GREY")
  segments(47,hsBOOT.LOWER.AD[47],47,hsBOOT.UPPER.AD[47],lwd=3,col="GREY")
  segments(49,hsBOOT.LOWER.AD[49],49,hsBOOT.UPPER.AD[49],lwd=3,col="GREY")
  segments(51,hsBOOT.LOWER.AD[51],51,hsBOOT.UPPER.AD[51],lwd=3,col="GREY")
  segments(53,hsBOOT.LOWER.AD[53],53,hsBOOT.UPPER.AD[53],lwd=3,col="GREY")
  segments(55,hsBOOT.LOWER.AD[55],55,hsBOOT.UPPER.AD[55],lwd=3,col="GREY")
  segments(57,hsBOOT.LOWER.AD[57],57,hsBOOT.UPPER.AD[57],lwd=3,col="GREY")
  points(1:58, ELONGATEDTIMESERIES,col="blue",pch=19)
  legend(0,max(max(hhsBOOT.UPPER.AD),max(hsBOOT.UPPER.AD)),
         c("Mock breeding adult females throughout the year", 
           "Algorithm-predicted range for breeding-adult females throughout the year"),
         box.lty = 0,lty=c(1,1),lwd=c(3,3),pch=c(19,20),col=c("blue","grey"))

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# SPRING MATRIX PARAMETERS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

par(mfrow=c(3,3))
x=1:100;y=1:100; z=1:100; zz=100:1

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

mtext("Population Matrix for the Breeding Period",cex=1.4,line=1,side=3)
boxplot(NEW.MODELS[,7],ylab="",cex.lab=1.4,ylim=c(.5,1.5),xlab="")
mtext("a13",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=a13,lty=2,col="blue",lwd=2)

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

boxplot(NEW.MODELS[,9],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("a22",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=a22,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,10],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("a23",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=a23,lty=2, col="blue",lwd=2)

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

boxplot(NEW.MODELS[,11],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("a32",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=a32,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,12],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("a33",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=a33,lty=2, col="blue",lwd=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# FALL NE MATRIX PARAMETERS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

par(mfrow=c(3,3))
x=1:100;y=1:100; z=1:100; zz=100:1

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

mtext("Population Matrix for the Non-Breeding Period",cex=1.4,line=1,side=3)

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

boxplot(NEW.MODELS[,13],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("a",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=a,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,14],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("b",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=b,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,15],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("c",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=c,lty=2, col="blue",lwd=2)

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

boxplot(NEW.MODELS[,16],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("d",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=d,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,17],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("e",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=e,lty=2, col="blue",lwd=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# FALL NON-NE MATRIX PARAMETERS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

par(mfrow=c(3,3))
x=1:100;y=1:100; z=1:100; zz=100:1

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

mtext("Population Matrix for the Non-Breeding Period Elsewhere",cex=1.4,line=1,side=3)

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

boxplot(NEW.MODELS[,18],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("a*",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=A,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,19],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("b*",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=B,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,20],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("c*",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=C,lty=2, col="blue",lwd=2)

plot(x,y,type="l",yaxt="n",xaxt="n",xlab="",ylab="")
points(z,zz,type="l")

boxplot(NEW.MODELS[,21],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("d*",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=D,lty=2, col="blue",lwd=2)

boxplot(NEW.MODELS[,22],ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("e*",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=F,lty=2, col="blue",lwd=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# MIGRATION PARAMETERS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

par(mfrow=c(2,2))
boxplot(NEW.SA,ylab="",ylim=c(0,1),cex.lab=1.4,xlab="")
mtext("Incoming % SII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=SA.exact,lty=2, col="blue",lwd=2)

boxplot(NEW.AA,ylab="",ylim=c(0,1),cex.lab=1.4,xlab="")
mtext("Incoming % SIII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=AA.exact,lty=2, col="blue",lwd=2)

mtext("Migration Parameters",cex=1.4,line=-2.5,side=3,outer=TRUE)

boxplot(NEW.PS,ylab="",ylim=c(0,1),cex.lab=1.4,xlab="")
mtext("Departing % SII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=SL.exact,lty=2, col="blue",lwd=2)

boxplot(NEW.PA,ylab="",ylim=c(0,1),cex.lab=1.4,xlab="")
mtext("Departing % SIII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=AL.exact,lty=2, col="blue",lwd=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# DISPERSAL PARAMETERS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

par(mfrow=c(2,2))

boxplot(NEW.AbsorbS,ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("Incoming % SII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=alpha.star,lty=2, col="blue",lwd=2)

boxplot(NEW.AbsorbA,ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("Incoming % SIII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=beta.star,lty=2, col="blue",lwd=2)

mtext("Dispersal Parameters",cex=1.4,line=-2.5,side=3,outer=TRUE)

boxplot(NEW.PurgeS,ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("Departing % SII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=alpha1,lty=2, col="blue",lwd=2)

boxplot(NEW.PurgeA,ylab="",cex.lab=1.4,ylim=c(0,1),xlab="")
mtext("Departing % SIII",side=2,line=2)
mtext("Algorithm-estimation",side=1,line=.5)
abline(h=beta,lty=2, col="blue",lwd=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# SURVIVAL
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  par(mfrow=c(3,1))
  type=c(rep("Stage II",length(NEW.Surv2b)),rep("Stage III",length(NEW.Surv2b)))
  boxplot(c(NEW.Surv2b,NEW.Surv3b)~type,main="Survival during the breeding period",ylim=c(.6,1))
  abline(v=1.5)
  segments(.5,Surv.EXACT2b,1.5,Surv.EXACT2b,col="blue",lty=2,lwd=2)
  segments(1.5,Surv.EXACT3b,2.5,Surv.EXACT3b,col="blue",lty=2,lwd=2)

  type=c(rep("Stage I",length(NEW.Surv2b)),rep("Stage II",length(NEW.Surv2b)),rep("Stage III",length(NEW.Surv2b)))
  boxplot(c(NEW.Surv1nb,NEW.Surv2nb,NEW.Surv3nb)~type,main="Survival during the non-breeding period",ylim=c(.6,1))
  abline(v=1.5)
  abline(v=2.5)
  segments(.5,Surv.EXACT1nb,1.5,Surv.EXACT1nb,col="blue",lty=2,lwd=2)
  segments(1.5,Surv.EXACT2nb,2.5,Surv.EXACT2nb,col="blue",lty=2,lwd=2)
  segments(2.5,Surv.EXACT3nb,3.5,Surv.EXACT3nb,col="blue",lty=2,lwd=2)

  type=c(rep("Stage I",length(NEW.Surv2b)),rep("Stage II",length(NEW.Surv2b)),rep("Stage III",length(NEW.Surv2b)))
  boxplot(c(NEW.Surv1nbe,NEW.Surv2nbe,NEW.Surv3nbe)~type,main="Survival during the non-breeding period elsewhere",ylim=c(.6,1))
  abline(v=1.5)
  abline(v=2.5)
  segments(.5,Surv.EXACT1nbe,1.5,Surv.EXACT1nbe,col="blue",lty=2,lwd=2)
  segments(1.5,Surv.EXACT2nbe,2.5,Surv.EXACT2nbe,col="blue",lty=2,lwd=2)
  segments(2.5,Surv.EXACT3nbe,3.5,Surv.EXACT3nbe,col="blue",lty=2,lwd=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# E-VALUES
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  # TULPURKAR CORRECTION FOR RESIDENTS AND MIGRANTS
  EVALUE.STAR.RESIDENTS=numeric(length(MODELS[,1]))
  EVALUE.STAR.MIGRANTS=numeric(length(MODELS[,1]))
  EVALUES=numeric(length(MODELS[,1]))
  EVALUESM=numeric(length(MODELS[,1]))
  ANNUAL.A22=numeric(length(MODELS[,1]))
  ANNUAL.A23=numeric(length(MODELS[,1]))
  ANNUAL.A32=numeric(length(MODELS[,1]))
  ANNUAL.A33=numeric(length(MODELS[,1]))
  M.ANNUAL.A22=numeric(length(MODELS[,1]))
  M.ANNUAL.A23=numeric(length(MODELS[,1]))
  M.ANNUAL.A32=numeric(length(MODELS[,1]))
  M.ANNUAL.A33=numeric(length(MODELS[,1]))
  # CALCULATE THE BI-ANNUAL MATRICES AND EIGENVALUES
  for (i in 1:length(MODELS[,1])){
    # THE SHARED BREEDING PERIOD
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    # THE SPLIT MIGRATION PERIOD
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    ANNUAL.A22[i]=Annual[2,2]
    ANNUAL.A23[i]=Annual[2,3]
    ANNUAL.A32[i]=Annual[3,2]
    ANNUAL.A33[i]=Annual[3,3]
    EVALUES[i]=c(eigen(Annual)$value[1])
    top2=c(0,0,0)
    mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot2=c(0,MODELS[i,21],MODELS[i,22])
    BNB=rbind(top2,mid2,bot2)
    AnnualM=BNB%*%AB
    M.ANNUAL.A22[i]=AnnualM[2,2]
    M.ANNUAL.A23[i]=AnnualM[2,3]
    M.ANNUAL.A32[i]=AnnualM[3,2]
    M.ANNUAL.A33[i]=AnnualM[3,3]
    EVALUESM[i]=c(eigen(AnnualM)$value[1])}
  # HERE IS THE CORRECTION FOR THE YEAR ROUND RESIDENTS
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    L=ANB%*%AB
    # GET SENSITIVITY MATRIX
    S=matrix(0,3,3)
    W=numeric(3)
    V=numeric(3)
    for (k in 1:3){
      for (j in 1:3){
        V[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
        W[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
    S[2,2]=Re((V[2]%*%W[2])/(V%*%W))
    S[2,3]=Re((V[2]%*%W[3])/(V%*%W))
    S[3,2]=Re((V[3]%*%W[2])/(V%*%W))
    S[3,3]=Re((V[3]%*%W[3])/(V%*%W))
    # GET COVARIANCE MATRIX
    a22=ANNUAL.A22
    a23=ANNUAL.A23
    a32=ANNUAL.A32
    a33=ANNUAL.A33
    Tau=
      (cov(a22,a22)*S[2,2]*S[2,2])+
      (cov(a22,a23)*S[2,2]*S[2,3])+
      (cov(a22,a32)*S[2,2]*S[3,2])+
      (cov(a22,a33)*S[2,2]*S[3,3])+
      (cov(a23,a22)*S[2,3]*S[2,2])+
      (cov(a23,a23)*S[2,3]*S[2,3])+
      (cov(a23,a32)*S[2,3]*S[3,2])+
      (cov(a23,a33)*S[2,3]*S[3,3])+
      (cov(a32,a22)*S[3,2]*S[2,2])+
      (cov(a32,a23)*S[3,2]*S[2,3])+
      (cov(a32,a32)*S[3,2]*S[3,2])+
      (cov(a32,a33)*S[3,2]*S[3,3])+
      (cov(a33,a22)*S[3,3]*S[2,2])+
      (cov(a33,a23)*S[3,3]*S[2,3])+
      (cov(a33,a32)*S[3,3]*S[3,2])+
      (cov(a33,a33)*S[3,3]*S[3,3])
    EVALUE.STAR.RESIDENTS[i]=exp(log(EVALUES[i])-(1/2)*(Tau/(EVALUES[i]^2)))}
  # HERE IS THE CORRECTION FOR THE MIGRATING RESIDENTS
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANBE=rbind(top1,mid1,bot1)
    LE=ANBE%*%AB
    # GET SENSITIVITY MATRIX
    S=matrix(0,3,3)
    W=numeric(3)
    V=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
        W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
    S[2,2]=Re((V[2]%*%W[2])/(V%*%W))
    S[2,3]=Re((V[2]%*%W[3])/(V%*%W))
    S[3,2]=Re((V[3]%*%W[2])/(V%*%W))
    S[3,3]=Re((V[3]%*%W[3])/(V%*%W))
    # GET COVARIANCE MATRIX
    a22=M.ANNUAL.A22
    a23=M.ANNUAL.A23
    a32=M.ANNUAL.A32
    a33=M.ANNUAL.A33
    Tau=
      (cov(a22,a22)*S[2,2]*S[2,2])+
      (cov(a22,a23)*S[2,2]*S[2,3])+
      (cov(a22,a32)*S[2,2]*S[3,2])+
      (cov(a22,a33)*S[2,2]*S[3,3])+
      (cov(a23,a22)*S[2,3]*S[2,2])+
      (cov(a23,a23)*S[2,3]*S[2,3])+
      (cov(a23,a32)*S[2,3]*S[3,2])+
      (cov(a23,a33)*S[2,3]*S[3,3])+
      (cov(a32,a22)*S[3,2]*S[2,2])+
      (cov(a32,a23)*S[3,2]*S[2,3])+
      (cov(a32,a32)*S[3,2]*S[3,2])+
      (cov(a32,a33)*S[3,2]*S[3,3])+
      (cov(a33,a22)*S[3,3]*S[2,2])+
      (cov(a33,a23)*S[3,3]*S[2,3])+
      (cov(a33,a32)*S[3,3]*S[3,2])+
      (cov(a33,a33)*S[3,3]*S[3,3])
    EVALUE.STAR.MIGRANTS[i]=exp(log(EVALUESM[i])-(1/2)*(Tau/(EVALUESM[i]^2)))}

  par(mfrow=c(2,2))
  boxplot(EVALUE.STAR.RESIDENTS,ylab="",xlab="",ylim=c(.70,1.25))
  abline(h=e.YR.exact,lty=2,col="blue",lwd=2)
  mtext("Algorithm-prediction",side=2,line=2)
  mtext("YR Eagles",side=1,line=1)
  hist(EVALUE.STAR.RESIDENTS,xlim=c(.70,1.25),
  ylab="Frequency",xlab="YR Eigenvalues",main="")
  abline(v=e.YR.exact,lty=2,col="blue",lwd=2)

  boxplot(EVALUE.STAR.MIGRANTS,ylab="",xlab="",ylim=c(.70,1.25))
  mtext("Algorithm-prediction",side=2,line=2)
  abline(h=e.PY.exact,lty=2,col="blue",lwd=2)
  mtext("PY Eagles",side=1,line=1)
  hist(EVALUE.STAR.MIGRANTS,xlim=c(.70,1.25),ylab="Frequency",
  xlab="PY Eigenvalues",main="")
  abline(v=e.PY.exact,lty=2,col="blue",lwd=2)
  mtext("Eigenvalues",cex.lab=1.3, line=-2,side=3,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# STABLE STAGE DISTRIBUTION
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  EVECTORS=matrix(0,3,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    EVECTORS[,i]=eigen(Annual)$vector[,1]}
  totalR=matrix(0,2,length(EVECTORS[1,]))
  proportionSR=numeric(length(EVECTORS[1,]))
  proportionAR=numeric(length(EVECTORS[1,]))
  for (k in 1:length(proportionSR)){
    totalR[k]=abs(sum(EVECTORS[,k]))
    proportionSR[k]=abs(EVECTORS[2,k])/totalR[k]
    proportionAR[k]=abs(EVECTORS[3,k])/totalR[k]} 

    EVECTORSM=matrix(0,3,length(MODELS[,1]))
    for (i in 1:length(MODELS[,1])){
    # THE SHARED BREEDING PERIOD
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top2=c(0,0,0)
    mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot2=c(0,MODELS[i,21],MODELS[i,22])
    BNB=rbind(top2,mid2,bot2)
    AnnualM=BNB%*%AB
    EVECTORSM[,i]=eigen(AnnualM)$vector[,1]}

    totalM=matrix(0,2,length(EVECTORSM[1,]))
    proportionSM=numeric(length(EVECTORSM[1,]))
    proportionAM=numeric(length(EVECTORSM[1,]))
    for (k in 1:length(proportionSM)){
    totalM[k]=abs(sum(EVECTORSM[,k]))
    proportionSM[k]=abs(EVECTORSM[2,k])/totalM[k]
    proportionAM[k]=abs(EVECTORSM[3,k])/totalM[k]}

  par(mfrow=c(2,2))
  	boxplot(proportionSR,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SII YR",side=1,line=1)
	abline(h=e.vector.YR.exact1,col="blue",lwd=2,lty=2)

  	boxplot(proportionAR,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SIII YR",side=1,line=1)
	abline(h=e.vector.YR.exact2,col="blue",lwd=2,lty=2)

   	boxplot(proportionSM,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SII PY",side=1,line=1)
	abline(h=e.vector.PY.exact1,col="blue",lwd=2,lty=2)

   	boxplot(proportionAM,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SIII PY",side=1,line=1)
	abline(h=e.vector.PY.exact2,col="blue",lwd=2,lty=2)
	mtext("Stable stage distribution",cex.lab=1.3, line=-2,side=3,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# REPRODUCTIVE VALUES
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

    MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
    EVECTORS=matrix(0,3,length(MODELS[,1]))
    for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    EVECTORS[,i]=eigen(t(Annual))$vector[,1]}
    totalR=matrix(0,2,length(EVECTORS[1,]))
    proportionSR=numeric(length(EVECTORS[1,]))
    proportionAR=numeric(length(EVECTORS[1,]))
    for (j in 1:length(EVECTORS[1,])){
    totalR[j]=abs(sum(EVECTORS[,j]))
    proportionSR[j]=abs(EVECTORS[2,j])/totalR[j]
    proportionAR[j]=abs(EVECTORS[3,j])/totalR[j]}
    EVECTORSM=matrix(0,3,length(MODELS[,1]))
    for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top2=c(0,0,0)
    mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot2=c(0,MODELS[i,21],MODELS[i,22])
    BNB=rbind(top2,mid2,bot2)
    AnnualM=BNB%*%AB
    EVECTORSM[,i]=eigen(t(AnnualM))$vector[,1]}
    totalM=matrix(0,2,length(EVECTORSM[1,]))
    proportionSM=numeric(length(EVECTORSM[1,]))
    proportionAM=numeric(length(EVECTORSM[1,]))
    for (j in 1:length(EVECTORSM[1,])){
    totalM[j]=abs(sum(EVECTORSM[,j]))
    proportionSM[j]=abs(EVECTORSM[2,j])/totalM[j]
    proportionAM[j]=abs(EVECTORSM[3,j])/totalM[j]}

      par(mfrow=c(2,2))
  	boxplot(proportionSR,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SII YR",side=1,line=1)
	abline(h=e.vectorR.YR.exact1,col="blue",lwd=2,lty=2)

  	boxplot(proportionAR,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SIII YR",side=1,line=1)
	abline(h=e.vectorR.YR.exact2,col="blue",lwd=2,lty=2)

   	boxplot(proportionSM,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SII PY",side=1,line=1)
	abline(h=e.vectorR.PY.exact1,col="blue",lwd=2,lty=2)

   	boxplot(proportionAM,ylim=c(0,1),xlab="",ylab="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("SIII PY",side=1,line=1)
	abline(h=e.vectorR.PY.exact2,col="blue",lwd=2,lty=2)
	mtext("Reproductive values",cex.lab=1.3, line=-2,side=3,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# SENSITIVITIES
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  S.R.TWO.TWO=numeric(length(MODELS[,1]))
  S.R.TWO.THREE=numeric(length(MODELS[,1]))
  S.R.THREE.THREE=numeric(length(MODELS[,1]))
  S.R.THREE.TWO=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top=c(0,0,0)
    mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top,mid,bot)
    L=ANB%*%AB
    W=numeric(3);V=numeric(3)
    Ww=numeric(3);Vv=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
        Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
    S.R.TWO.TWO[i]=Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
    S.R.TWO.THREE[i]=Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
    S.R.THREE.TWO[i]=Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
    S.R.THREE.THREE[i]=Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  S.M.TWO.TWO=numeric(length(MODELS[,1]))
  S.M.TWO.THREE=numeric(length(MODELS[,1]))
  S.M.THREE.THREE=numeric(length(MODELS[,1]))
  S.M.THREE.TWO=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANBE=rbind(top1,mid1,bot1)
    LE=ANBE%*%AB
    W=numeric(3);V=numeric(3)
    Ww=numeric(3);Vv=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
        W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
    S.M.TWO.TWO[i]=Re((V[2]%*%W[2])/(V%*%W))
    S.M.TWO.THREE[i]=Re((V[2]%*%W[3])/(V%*%W))
    S.M.THREE.TWO[i]=Re((V[3]%*%W[2])/(V%*%W))
    S.M.THREE.THREE[i]=Re((V[3]%*%W[3])/(V%*%W))}

  par(mfrow=c(2,2))
  boxplot(S.R.TWO.TWO,main="",ylim=c(0,1))
  abline(h=S.R.TWO.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a22 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(S.R.TWO.THREE,main="",ylim=c(0,1))
  abline(h=S.R.TWO.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a23 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(S.R.THREE.TWO,main="",ylim=c(0,1.5))
  abline(h=S.R.THREE.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a32 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(S.R.THREE.THREE,main="",ylim=c(0,1))
  abline(h=S.R.THREE.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a33 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  mtext("Sensitivities",cex.lab=1.3, line=-2,side=3,outer=TRUE)

  par(mfrow=c(2,2))
  boxplot(S.M.TWO.TWO,main="",ylim=c(0,1))
  abline(h=S.M.TWO.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a22 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(S.M.TWO.THREE,main="",ylim=c(0,1))
  abline(h=S.M.TWO.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a23 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(S.M.THREE.TWO,main="",ylim=c(0,1.5))
  abline(h=S.M.THREE.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a32 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(S.M.THREE.THREE,main="",ylim=c(0,1))
  abline(h=S.M.THREE.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a33 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  mtext("Sensitivities",cex.lab=1.3, line=-2,side=3,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# ELASTICITIES
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  E.R.TWO.TWO=numeric(length(MODELS[,1]))
  E.R.TWO.THREE=numeric(length(MODELS[,1]))
  E.R.THREE.THREE=numeric(length(MODELS[,1]))
  E.R.THREE.TWO=numeric(length(MODELS[,1]))
  EVALUES=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top=c(0,0,0)
    mid=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top,mid,bot)
    L=ANB%*%AB
    EVALUES[i]=c(eigen(L)$value[1])
    Ww=numeric(3);Vv=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        Vv[k]=eigen(t(L))$vector[k,1]/eigen(t(L))$vector[2,1]
        Ww[j]=eigen(L)$vector[j,1]/(eigen(L)$vector[2,1]+eigen(L)$vector[3,1])}}
    E.R.TWO.TWO[i]=Re(L[2,2]/EVALUES[i])*Re((Vv[2]%*%Ww[2])/(Vv%*%Ww))
    E.R.TWO.THREE[i]=Re(L[2,3]/EVALUES[i])*Re((Vv[2]%*%Ww[3])/(Vv%*%Ww))
    E.R.THREE.TWO[i]=Re(L[3,2]/EVALUES[i])*Re((Vv[3]%*%Ww[2])/(Vv%*%Ww))
    E.R.THREE.THREE[i]=Re(L[3,3]/EVALUES[i])*Re((Vv[3]%*%Ww[3])/(Vv%*%Ww))}
  E.M.TWO.TWO=numeric(length(MODELS[,1]))
  E.M.TWO.THREE=numeric(length(MODELS[,1]))
  E.M.THREE.THREE=numeric(length(MODELS[,1]))
  E.M.THREE.TWO=numeric(length(MODELS[,1]))
  EVALUESM=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANBE=rbind(top1,mid1,bot1)
    LE=ANBE%*%AB
    EVALUESM[i]=c(eigen(LE)$value[1])
    W=numeric(3);V=numeric(3)
    for (k in 2:3){
      for (j in 2:3){
        V[k]=eigen(t(LE))$vector[k,1]/eigen(t(LE))$vector[2,1]
        W[j]=eigen(LE)$vector[j,1]/(eigen(LE)$vector[2,1]+eigen(LE)$vector[3,1])}}
  E.M.TWO.TWO[i]=Re(LE[2,2]/EVALUESM[i])*Re((V[2]%*%W[2])/(V%*%W))
  E.M.TWO.THREE[i]=Re(LE[2,3]/EVALUESM[i])*Re((V[2]%*%W[3])/(V%*%W))
  E.M.THREE.TWO[i]=Re(LE[3,2]/EVALUESM[i])*Re((V[3]%*%W[2])/(V%*%W))
  E.M.THREE.THREE[i]=Re(LE[3,3]/EVALUESM[i])*Re((V[3]%*%W[3])/(V%*%W))}

  par(mfrow=c(2,2))
  boxplot(E.R.TWO.TWO,main="",ylim=c(0,1))
  abline(h=E.R.TWO.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a22 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(E.R.TWO.THREE,main="",ylim=c(0,1))
  abline(h=E.R.TWO.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a23 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(E.R.THREE.TWO,main="",ylim=c(0,1))
  abline(h=E.R.THREE.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a32 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(E.R.THREE.THREE,main="",ylim=c(0,1))
  abline(h=S.R.THREE.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a33 YR",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  mtext("Elasticities",cex.lab=1.3, line=-2,side=3,outer=TRUE)

  par(mfrow=c(2,2))
  boxplot(E.M.TWO.TWO,main="",ylim=c(0,1))
  abline(h=E.M.TWO.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a22 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(E.M.TWO.THREE,main="",ylim=c(0,1))
  abline(h=E.M.TWO.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a23 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(E.M.THREE.TWO,main="",ylim=c(0,1))
  abline(h=E.M.THREE.TWO.EXACT,lty=2,col="blue",lwd=2)
  mtext("a32 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  boxplot(E.M.THREE.THREE,main="",ylim=c(0,1))
  abline(h=E.M.THREE.THREE.EXACT,lty=2,col="blue",lwd=2)
  mtext("a33 PY",side=1,line=1)
  mtext("Algorithm-prediction",side=2,line=2)

  mtext("Elasticities",cex.lab=1.3, line=-2,side=3,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# DAMPING RATIOS
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

    MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
    EIGENVALUES.R.DOM=numeric(length(MODELS[,1]))
    EIGENVALUES.R.SUB=numeric(length(MODELS[,1]))
    EIGENVALUES.M.DOM=numeric(length(MODELS[,1]))
    EIGENVALUES.M.SUB=numeric(length(MODELS[,1]))
    DAMP.R=numeric(length(MODELS[,1]))
    DAMP.M=numeric(length(MODELS[,1]))
    for (i in 1:length(MODELS[,1])){
    # THE SHARED BREEDING PERIOD
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    # THE SPLIT MIGRATION PERIOD
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    EIGENVALUES.R.DOM[i]=c(eigen(Annual)$value[1])
    EIGENVALUES.R.SUB[i]=c(eigen(Annual)$value[2])
    DAMP.R[i]=EIGENVALUES.R.DOM[i]/sqrt(Re(EIGENVALUES.R.SUB[i])^2+Im(EIGENVALUES.R.SUB[i])^2)
    top2=c(0,0,0)
    mid2=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot2=c(0,MODELS[i,21],MODELS[i,22])
    BNB=rbind(top2,mid2,bot2)
    AnnualM=BNB%*%AB
    EIGENVALUES.M.DOM[i]=c(eigen(AnnualM)$value[1])
    EIGENVALUES.M.SUB[i]=c(eigen(AnnualM)$value[2])
    DAMP.M[i]=EIGENVALUES.M.DOM[i]/sqrt(Re(EIGENVALUES.M.SUB[i])^2+Im(EIGENVALUES.M.SUB[i])^2)}

	par(mfrow=c(1,2))
   	boxplot(DAMP.R,ylim=c(1,12),ylab="",xlab="")
	abline(h=DAMP.R.EXACT,lty=2,lwd=2,col="blue")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("YR Damping ratio",side=1)

   	boxplot(DAMP.M,ylim=c(1,12),ylab="",xlab="")
	abline(h=DAMP.M.EXACT,lty=2,lwd=2,col="blue")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("PY Damping ratio",side=1)
	mtext("Damping ratio",side=3,line=-3,cex.lab=1.4,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# CUMULATIVE GROWTH RATE
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  Total=matrix(0,length(MODELS[,1]),29)
  CUM=matrix(0,length(MODELS[,1]),29)
  for(i in 1:length(MODELS[,1])){
  for(j in 1:29){
    Total[i,j]=TRAJECTORY_ADULTS_JAN[i,j]+TRAJECTORY_SUBADULTS_JAN[i,j]
    CUM[i,j]=Total[i,j]/Total[i,1]
  }}
  par(mfrow=c(1,1))
  year=seq(1990,2018,1)		
  matplot(1:29,t(CUM),type="l",xlab="Time",xaxt="n",ylab="Cumulative growth",
          main="Cumulative growth in the mock trajectory",col="grey")
  axis(1, at=1:29, labels=year)
points(1:29,CUM.EXACT,col="blue",lwd=2,lty=2,type="l")

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# STOCHASTIC GROWTH RATE
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  SGR=matrix(0,length(MODELS[,1]),30)
  for (i in 1:length(MODELS[,1])){
    for (j in 1:29){
      SGR[i,j+1]=exp((1/(j+1))*log(TRAJECTORY_ADULTS_JAN[i,j+1]/TRAJECTORY_ADULTS_JAN[i,1]))}}
  par(mfrow=c(1,1))
  year=seq(1990,2018,1)		
  boxplot(SGR[,29],ylim=c(1.1,1.2),main="")
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("Stochastic growth rate in the mock trajectory",side=1)
  abline(h=SGR.EXACT[29],col="blue",lwd=2,lty=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# TRANSIENT GROWTH RATE
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
  TPGR=matrix(0,length(MODELS[,1]),30)
  for (i in 1:length(MODELS[,1])){
    for (j in 1:29){
      TPGR[i,j]=log(TRAJECTORY_ADULTS_JAN[i,j+1]/TRAJECTORY_ADULTS_JAN[i,j])}}
  par(mfrow=c(1,1))
  year=seq(1990,2018,1)		
  matplot(1:29,t(TPGR[,1:29]),type="l",xlab="Time",xaxt="n",
	ylab="Transient growth rate",ylim=c(0,.4),col="grey",
	main="Transient growth rate in the mock trajectory")
  axis(1, at=1:29, labels=year)
  points(1:29,TPGR.EXACT,col="blue",lwd=2,lty=2,type="l")

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# HARMONIC VS ARITHMETIC MEAN
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
  Ne=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Ne[i]=1/((1/29)*sum(1/TRAJECTORY_ADULTS_JAN[i,1:29]))}
  Nbar=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Nbar[i]=(1/29)*sum(TRAJECTORY_ADULTS_JAN[i,1:29])}

  par(mfrow=c(1,2))
  boxplot(Ne,main="",ylim=c(0,100))
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("Harmonic mean of SIII",side=1)
  abline(h=Ne.EXACT,col="blue",lwd=2,lty=2)
  boxplot(Nbar,main="",ylim=c(0,400))
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("Arithmetic mean of SIII",side=1)
  abline(h=Nbar.EXACT,col="blue",lwd=2,lty=2)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# LOSS OF GENETIC DIVERSITY
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt") 
  Ne=numeric(length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Ne[i]=1/((1/29)*sum(1/TRAJECTORY_ADULTS_JAN[i,1:29]))}
  par(mfrow=c(1,1))
  LGD=matrix(0,length(MODELS[,1]),30)
  for (i in 1:length(MODELS[,1])){
    for (j in 1:29){
      LGD[i,j]=(1-(1/(2*Ne[i])))^j}}
  par(mfrow=c(1,1))
  year=seq(1990,2018,1)		
  matplot(1:29,t(LGD[,1:29]),type="l",xlab="Time",
  xaxt="n",ylab="Loss of genetic diversity",col="grey",
          main="Loss of genetic diversity in each generation in the mock trajectory")
  axis(1, at=1:29, labels=year)
  points(1:29,LGD.EXACT,col="blue",lwd=2,lty=2,type="l")

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# INERTIA
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  library(popdemo)
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  InertiaR=numeric(length(MODELS[,1]))
  InertiaUpper=numeric(length(MODELS[,1]))
  InertiaLower=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    InertiaR[i]=inertia(Annual,vector=Initial[,i])
    InertiaUpper[i]=inertia(Annual,bound="upper")
    InertiaLower[i]=inertia(Annual,bound="lower")}

  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  InertiaM=numeric(length(MODELS[,1]))
  InertiaUpper=numeric(length(MODELS[,1]))
  InertiaLower=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    InertiaM[i]=inertia(Annual,vector=Initial[,i])
    InertiaUpper[i]=inertia(Annual,bound="upper")
    InertiaLower[i]=inertia(Annual,bound="lower")}

  par(mfrow=c(1,2))
  boxplot(InertiaR,main="",ylim=c(.75,1.2))
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("YR Eagles",side=1)
  abline(h=InertiaR.EXACT,col="blue",lwd=2,lty=2)
  boxplot(InertiaM,main="",ylim=c(.75,1.2)) 
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("PY Eagles",side=1)
  abline(h=InertiaM.EXACT,col="blue",lwd=2,lty=2)

	mtext("Population inertia",side=3,line=-3,cex.lab=1.4,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# REACTIVITY
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  library(popdemo)
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  ReacR=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    ReacR[i]=reac(Annual,vector=Initial[,i])}
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  ReacM=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    ReacM[i]=reac(Annual,vector=Initial[,i])}

  par(mfrow=c(1,2))
  boxplot(ReacR,main="",ylim=c(.75,1.2))
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("YR Eagles",side=1)
  abline(h=ReactR.EXACT,col="blue",lwd=2,lty=2)
  boxplot(ReacM,main="",ylim=c(.75,1.2)) 
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("PY Eagles",side=1)
  abline(h=ReactM.EXACT,col="blue",lwd=2,lty=2)

	mtext("Population reactivity",side=3,line=-3,cex.lab=1.4,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# MAX AMP
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

  library(popdemo)
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  MAXAMPR=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    MAXAMPR[i]=maxamp(Annual)}
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  MAXAMPM=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    MAXAMPM[i]=maxamp(Annual)}

  par(mfrow=c(1,2))
  boxplot(MAXAMPR,main="",ylim=c(1,2))
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("YR Eagles",side=1)
  abline(h=MaxAmpR.EXACT,col="blue",lwd=2,lty=2)
  boxplot(MAXAMPM,main="",ylim=c(1,2)) 
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("PY Eagles",side=1)
  abline(h=MaxAmpM.EXACT,col="blue",lwd=2,lty=2)

	mtext("Maximum amplification",side=3,line=-3,cex.lab=1.4,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# MAX ATT
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

 library(popdemo)
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  MAXAMPR=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,13],MODELS[i,14],MODELS[i,15])
    bot1=c(0,MODELS[i,16],MODELS[i,17])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    MAXAMPR[i]=maxatt(Annual)}
  MODELS=read.table("BestAlgorithmPredictedModelsNortheast.txt")
  TRAJECTORY_ADULTS_JAN=read.table("NEW_Adults_January_Northeast.txt")
  TRAJECTORY_SUBADULTS_JAN=read.table("NEW_Subadults_January_Northeast.txt")
  MAXAMPM=numeric(length(MODELS[,1]))
  Initial=matrix(0,2,length(MODELS[,1]))
  for (i in 1:length(MODELS[,1])){
    Initial[1,i]=TRAJECTORY_SUBADULTS_JAN[i,1]
    Initial[2,i]=TRAJECTORY_ADULTS_JAN[i,1]
    top=c(0,0,MODELS[i,7])
    mid=c(MODELS[i,8],MODELS[i,9],MODELS[i,10])
    bot=c(0,MODELS[i,11],MODELS[i,12])
    AB=rbind(top,mid,bot)
    top1=c(0,0,0)
    mid1=c(MODELS[i,18],MODELS[i,19],MODELS[i,20])
    bot1=c(0,MODELS[i,21],MODELS[i,22])
    ANB=rbind(top1,mid1,bot1)
    Annual=ANB%*%AB
    Annual=Annual[2:3,2:3]
    MAXAMPM[i]=maxatt(Annual)}

  par(mfrow=c(1,2))
  boxplot(MAXAMPR,main="",ylim=c(.5,1))
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("YR Eagles",side=1)
  abline(h=MaxAttR.EXACT,col="blue",lwd=2,lty=2)
  boxplot(MAXAMPM,main="",ylim=c(.5,1)) 
	mtext("Algorithm-prediction",side=2,line=2)
	mtext("PY Eagles",side=1)
  abline(h=MaxAttM.EXACT,col="blue",lwd=2,lty=2)

	mtext("Maximum attenuation",side=3,line=-3,cex.lab=1.4,outer=TRUE)

# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
# LIFE TABLE
# XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

Time=1:50
Prob=cbind(NEW.P1,NEW.P2,NEW.P3,NEW.P4,NEW.P5,NEW.P6,NEW.P7,
NEW.P8,NEW.P9,NEW.P10,NEW.P11,NEW.P12,NEW.P13,NEW.P14,NEW.P15,
NEW.P16,NEW.P17,NEW.P18,NEW.P19,NEW.P20,NEW.P21,NEW.P22,NEW.P23,NEW.P24,NEW.P25,
NEW.P26,NEW.P27,NEW.P28,NEW.P29,NEW.P30,NEW.P31,NEW.P32,NEW.P33,
NEW.P34,NEW.P35,NEW.P36,NEW.P37,NEW.P38,NEW.P39,NEW.P40,
NEW.P41,NEW.P42,NEW.P43,NEW.P44,NEW.P45,NEW.P46,NEW.P47,NEW.P48,NEW.P49,NEW.P50)
Prob.EXACT=cbind(P.EXACT1,P.EXACT2,P.EXACT3,P.EXACT4,P.EXACT5,P.EXACT6,P.EXACT7,P.EXACT8,
P.EXACT9,P.EXACT10,P.EXACT11,P.EXACT12,P.EXACT13,P.EXACT14,P.EXACT15,P.EXACT16,P.EXACT17,
P.EXACT18,P.EXACT19,P.EXACT20,P.EXACT21,P.EXACT22,P.EXACT23,P.EXACT24,P.EXACT25,
P.EXACT26,P.EXACT27,P.EXACT28,P.EXACT29,P.EXACT30,P.EXACT31,P.EXACT32,P.EXACT33,P.EXACT34,
P.EXACT35,P.EXACT36,P.EXACT37,P.EXACT38,P.EXACT39,P.EXACT40,P.EXACT41,P.EXACT42,P.EXACT43,
P.EXACT44,P.EXACT45,P.EXACT46,P.EXACT47,P.EXACT48,P.EXACT49,P.EXACT50)

par(mfrow=c(1,1))
matplot(Time,t(Prob),type="l",main="Life table",ylim=c(0,1),
xlab="Age",ylab="Probability of reaching that age",col="grey")
matpoints(Time,t(Prob.EXACT),type="l",lty=2,col="blue",lwd=2)
